<?php
//date functions//
///////////////////////////////////////
// sanitize.inc.php
// Sanitization functions for PHP
// by: Gavin Zuchlinski, Jamie Pratt, Hokkaido
// webpage: http://libox.net
// Last modified: September 27, 2003
//
// Many thanks to those on the webappsec list for helping me improve these functions
///////////////////////////////////////
// Function list:
// sanitize_paranoid_string($string) -- input string, returns string stripped of all non 
//           alphanumeric
// sanitize_system_string($string) -- input string, returns string stripped of special
//           characters
// sanitize_sql_string($string) -- input string, returns string with slashed out quotes
// sanitize_html_string($string) -- input string, returns string with html replacements
//           for special characters
// sanitize_int($integer) -- input integer, returns ONLY the integer (no extraneous 
//           characters
// sanitize_float($float) -- input float, returns ONLY the float (no extraneous 
//           characters)
// sanitize($input, $flags) -- input any variable, performs sanitization 
//           functions specified in flags. flags can be bitwise 
//           combination of PARANOID, SQL, SYSTEM, HTML, INT, FLOAT, LDAP, 
//           UTF8
///////////////////////////////////////
define("PARANOID", 1);
define("SQL", 2);
define("SYSTEM", 4);
define("HTML", 8);
define("INT", 16);
define("FLOAT", 32);
define("LDAP", 64);
define("UTF8", 128);

// internal function for utf8 decoding
// thanks to Jamie Pratt for noticing that PHP's function is a little 
// screwy

function my_utf8_decode($string)
{
return strtr($string, 
  "???????¥µÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏÐÑÒÓÔÕÖØÙÚÛÜÝßàáâãäåæçèéêëìíîïðñòóôõöøùúûüýÿ", 
  "SOZsozYYuAAAAAAACEEEEIIIIDNOOOOOOUUUUYsaaaaaaaceeeeiiiionoooooouuuuyy");
}

// paranoid sanitization -- only let the alphanumeric set through
function sanitize_paranoid_string($string, $min='', $max='')
{
  $string = preg_replace("/[^a-zA-Z0-9]/", "", $string);
  $len = strlen($string);
  if((($min != '') && ($len < $min)) || (($max != '') && ($len > $max)))
 return FALSE;
  return $string;
}

// sanitize a string in prep for passing a single argument to system() (or similar)
function sanitize_system_string($string, $min='', $max='')
{
  $pattern = '/(;|\||`|>|<|&|^|"|'."\n|\r|'".'|{|}|[|]|\)|\()/i'; // no piping, passing possible environment variables ($),
                        // seperate commands, nested execution, file redirection, 
                        // background processing, special commands (backspace, etc.), quotes
                        // newlines, or some other special characters
  $string = preg_replace($pattern, '', $string);
  $string = '"'.preg_replace('/\$/', '\\\$', $string).'"'; //make sure this is only interpretted as ONE argument
  $len = strlen($string);
  if((($min != '') && ($len < $min)) || (($max != '') && ($len > $max)))
 return FALSE;
  return $string;
}

// sanitize a string for SQL input (simple slash out quotes and slashes)
function sanitize_sql_string($string, $min='', $max='')
{
  $pattern[0] = '/(\\\\)/';
  $pattern[1] = "/\"/";
  $pattern[2] = "/'/";
  $replacement[0] = '\\\\\\';
  $replacement[1] = '\"';
  $replacement[2] = "\\'";
  $len = strlen($string);
  if((($min != '') && ($len < $min)) || (($max != '') && ($len > $max)))
 return FALSE;
  return preg_replace($pattern, $replacement, $string);
}

// sanitize a string for SQL input (simple slash out quotes and slashes)
function sanitize_ldap_string($string, $min='', $max='')
{
  $pattern = '/(\)|\(|\||&)/';
  $len = strlen($string);
  if((($min != '') && ($len < $min)) || (($max != '') && ($len > $max)))
 return FALSE;
  return preg_replace($pattern, '', $string);
}


// sanitize a string for HTML (make sure nothing gets interpretted!)
function sanitize_html_string($string)
{
  $pattern[0] = '/\&/';
  $pattern[1] = '/</';
  $pattern[2] = "/>/";
  $pattern[3] = '/\n/';
  $pattern[4] = '/"/';
  $pattern[5] = "/'/";
  $pattern[6] = "/%/";
  $pattern[7] = '/\(/';
  $pattern[8] = '/\)/';
  $pattern[9] = '/\+/';
  $pattern[10] = '/-/';
  $replacement[0] = '&amp;';
  $replacement[1] = '&lt;';
  $replacement[2] = '&gt;';
  $replacement[3] = '<br>';
  $replacement[4] = '&quot;';
  $replacement[5] = '&#39;';
  $replacement[6] = '&#37;';
  $replacement[7] = '&#40;';
  $replacement[8] = '&#41;';
  $replacement[9] = '&#43;';
  $replacement[10] = '&#45;';
  return preg_replace($pattern, $replacement, $string);
}

// make int int!
function sanitize_int($integer, $min='', $max='')
{
  $int = intval($integer);
  if((($min != '') && ($int < $min)) || (($max != '') && ($int > $max)))
 return FALSE;
  return $int;
}

// make float float!
function sanitize_float($float, $min='', $max='')
{
  $float = floatval($float);
  if((($min != '') && ($float < $min)) || (($max != '') && ($float > $max)))
 return FALSE;
  return $float;
}

// glue together all the other functions
function sanitize($input, $flags, $min='', $max='')
{
  if($flags & UTF8) $input = my_utf8_decode($input);
  if($flags & PARANOID) $input = sanitize_paranoid_string($input, $min, $max);
  if($flags & INT) $input = sanitize_int($input, $min, $max);
  if($flags & FLOAT) $input = sanitize_float($input, $min, $max);
  if($flags & HTML) $input = sanitize_html_string($input, $min, $max);
  if($flags & SQL) $input = sanitize_sql_string($input, $min, $max);
  if($flags & LDAP) $input = sanitize_ldap_string($input, $min, $max);
  if($flags & SYSTEM) $input = sanitize_system_string($input, $min, $max);
  return $input;
}


function DateAdd($interval, $number, $date) {

 $date_time_array = getdate($date);
 $hours = $date_time_array['hours'];
 $minutes = $date_time_array['minutes'];
 $seconds = $date_time_array['seconds'];
 $month = $date_time_array['mon'];
 $day = $date_time_array['mday'];
 $year = $date_time_array['year'];

 switch ($interval) {
 
     case 'yyyy':
         $year+=$number;
         break;
     case 'q':
         $year+=($number*3);
         break;
     case 'm':
         $month+=$number;
         break;
     case 'y':
     case 'd':
     case 'w':
         $day+=$number;
         break;
     case 'ww':
         $day+=($number*7);
         break;
     case 'h':
         $hours+=$number;
         break;
     case 'n':
         $minutes+=$number;
         break;
     case 's':
         $seconds+=$number;
         break;            
 }
    $timestamp= mktime($hours,$minutes,$seconds,$month,$day,$year);
 return $timestamp;
}

function date_calc($this_date,$num_days){

 $my_time = strtotime ($this_date); //converts date string to UNIX timestamp
 $timestamp = $my_time + ($num_days * 86400); //calculates # of days passed ($num_days) * # seconds in a day (86400)
  $return_date = date("Y/m/d",$timestamp);  //puts the UNIX timestamp back into string format

 return $return_date;//exit function and return string
}//end of function

function datediff($interval, $datefrom, $dateto, $using_timestamps = false) {
 /*
 $interval can be:
 yyyy - Number of full years
 q - Number of full quarters
 m - Number of full months
 y - Difference between day numbers
 (eg 1st Jan 2004 is "1", the first day. 2nd Feb 2003 is "33". The datediff is "-32".)
 d - Number of full days
 w - Number of full weekdays
 ww - Number of full weeks
 h - Number of full hours
 n - Number of full minutes
 s - Number of full seconds (default)
 */

 if (!$using_timestamps) {
 $datefrom = strtotime($datefrom, 0);
 $dateto = strtotime($dateto, 0);
 }
 $difference = $dateto - $datefrom; // Difference in seconds

 switch($interval) {

 case 'yyyy': // Number of full years
  
 $years_difference = floor($difference / 31536000);
 if (mktime(date("H", $datefrom), date("i", $datefrom), date("s", $datefrom), date("n", $datefrom), date("j", $datefrom), date("Y", $datefrom)+$years_difference) > $dateto) {
 $years_difference--;
 }
 if (mktime(date("H", $dateto), date("i", $dateto), date("s", $dateto), date("n", $dateto), date("j", $dateto), date("Y", $dateto)-($years_difference+1)) > $datefrom) {
 $years_difference++;
 }
 $datediff = $years_difference;
 break;
  
 case "q": // Number of full quarters
  
 $quarters_difference = floor($difference / 8035200);
 while (mktime(date("H", $datefrom), date("i", $datefrom), date("s", $datefrom), date("n", $datefrom)+($quarters_difference*3), date("j", $dateto), date("Y", $datefrom)) < $dateto) {
 $months_difference++;
 }
 $quarters_difference--;
 $datediff = $quarters_difference;
 break;
  
 case "m": // Number of full months
  
 $months_difference = floor($difference / 2678400);
 while (mktime(date("H", $datefrom), date("i", $datefrom), date("s", $datefrom), date("n", $datefrom)+($months_difference), date("j", $dateto), date("Y", $datefrom)) < $dateto) {
 $months_difference++;
 }
 $months_difference--;
 $datediff = $months_difference;
 break;
  
 case 'y': // Difference between day numbers
  
 $datediff = date("z", $dateto) - date("z", $datefrom);
 break;
  
 case "d": // Number of full days
  
 $datediff = floor($difference / 86400);
 break;
  
 case "w": // Number of full weekdays
  
 $days_difference = floor($difference / 86400);
 $weeks_difference = floor($days_difference / 7); // Complete weeks
 $first_day = date("w", $datefrom);
 $days_remainder = floor($days_difference % 7);
 $odd_days = $first_day + $days_remainder; // Do we have a Saturday or Sunday in the remainder?
 if ($odd_days > 7) { // Sunday
 $days_remainder--;
 }
 if ($odd_days > 6) { // Saturday
 $days_remainder--;
 }
 $datediff = ($weeks_difference * 5) + $days_remainder;
 break;
  
 case "ww": // Number of full weeks
  
 $datediff = floor($difference / 604800);
 break;
  
 case "h": // Number of full hours
  
 $datediff = floor($difference / 3600);
 break;
  
 case "n": // Number of full minutes
  
 $datediff = floor($difference / 60);
 break;
  
 default: // Number of full seconds (default)
  
 $datediff = $difference;
 break;
 }
  
 return $datediff;
  
 } 

function formatdate($date1,$dateformat="d-m-Y")
{

$string = $date1;   
if ($string > "1900-12-30")
{

  $string = $date1;   
  $stringArray = explode("-", $string); 
  $date = mktime(0,0,0,$stringArray[1],$stringArray[2],$stringArray[0]); 

  $converteddate = date($dateformat, $date); 
  return ($converteddate);       
}
}

function getquarter($month)
{
switch ($month)
 {
 case ($month=='Jan' || $month=='Feb' || $month=='Mar'):
     $quarter = "4";
     break;
 case ($month=='Apr' || $month=='May' || $month=='Jun'):
     $quarter = "1";
     break;
 case ($month=='Jul' || $month=='Aug' || $month=='Sep'):
     $quarter = "2";
     break;
 case ($month=='Oct' || $month=='Nov' || $month=='Dec'):
     $quarter = "3";
     break;
 } 
 return $quarter;
}

//-----------------format numbers--------------------------//

function format_number($strAmount)
{
list($OrgAmount,$DotAmount)= explode ('[.]', $strAmount);     
//  list($OrgAmount,$DotAmount)= split ('[.]', $strAmount); 
//  list($OrgAmount)= split ('[.]', $strAmount);  

// -- If Decimal Amount is Blank Then Make It '00 ---- ////

if ($DotAmount =='')
{
  $DotAmount ='00';
}
else if (strlen($DotAmount)==1)
 {
  $DotAmount .= "0"; 
 }      
 // -- End Decimal Amount
 
 $strlength  = strlen($OrgAmount);      // Length Of Amount 
     
 if ($strlength >'0')
 {
  if ($strlength == '1')
  {
    $a = substr($OrgAmount,"0","1");
    $strAm ="$a.$DotAmount";          
    return($strAm);           
  }
  else if ($strlength =='2')
  {
    $a = substr($OrgAmount,"0","2");
    $strAm ="$a.$DotAmount";          
    return($strAm);           
  }
  else if ($strlength =='3')
  {
    $a = substr($OrgAmount,"0","3");
    $strAm ="$a.$DotAmount";          
    return($strAm);         
  }
  else if ($strlength =='4')
  {
    $b = substr($OrgAmount,"1","3");
    $a = substr($OrgAmount,"0","1");
    $strAm ="$a,$b.$DotAmount";         
    return($strAm);     
  }
  else if ($strlength =='5')
  {
    $b = substr($OrgAmount,"2","3");
    $a = substr($OrgAmount,"0","2");
    $strAm ="$a,$b.$DotAmount";         
    return($strAm);         
  }
  else if ($strlength =='6')
  {
    $c = substr($OrgAmount,"3","3");
    $b = substr($OrgAmount,"1","2");
    $a = substr($OrgAmount,"0","1");
    $strAm ="$a,$b,$c.$DotAmount";          
    return($strAm);     
  }
  else if ($strlength =='7')
  {
    $c = substr($OrgAmount,"4","3");
    $b = substr($OrgAmount,"2","2");
    $a = substr($OrgAmount,"0","2");
    $strAm ="$a,$b,$c.$DotAmount";          
    return($strAm); 
            
  }
  else if ($strlength =='8')
  {
    $d = substr($OrgAmount,"5","3");
    $c = substr($OrgAmount,"3","2");
    $b = substr($OrgAmount,"1","2");
    $a = substr($OrgAmount,"0","1");
    $strAm ="$a,$b,$c,$d.$DotAmount";         
    return($strAm);     
  }
  else if ($strlength =='9')
  {
    $d = substr($OrgAmount,"6","3");
    $c = substr($OrgAmount,"4","2");
    $b = substr($OrgAmount,"2","2");
    $a = substr($OrgAmount,"0","2");
    $strAm ="$a,$b,$c,$d.$DotAmount";         
    return($strAm); 
  }
  else if ($strlength =='10')
  { 
    $e = substr($OrgAmount,"7","3");
    $d = substr($OrgAmount,"5","2");
    $c = substr($OrgAmount,"3","2");
    $b = substr($OrgAmount,"1","2");
    $a = substr($OrgAmount,"0","1");
    
    $strAm ="$a,$b,$c,$d,$e.$DotAmount";          
    return($strAm); 
  }
  else if ($strlength =='11')
  {
    $e = substr($OrgAmount,"8","3");
    $d = substr($OrgAmount,"6","2");
    $c = substr($OrgAmount,"4","2");
    $b = substr($OrgAmount,"2","2");
    $a = substr($OrgAmount,"0","2");
    $strAm ="$a,$b,$c,$d,$e.$DotAmount";          
    return($strAm); 
  }   
}
}



//------------------------------//


function replaceForLink($strToReplace)
{
  $strToReturn = str_replace(" ","_",$strToReplace);
  $strToReturn = str_replace("/","---",$strToReturn);
  return $strToReturn;
}

function replaceForNormalText($strLink)
{
  $strNormalText = str_replace("_"," ",$strLink);
  $strNormalText = str_replace("---","/",$strNormalText);
  return $strNormalText;
}

function ProperCase($strToConvert)
{
  $strToReturn = ucwords(strtolower($strToConvert));
  return $strToReturn;

}


function DeleteCacheFiles($fromdir, $tm, $recursed = 1 ) {
if ($fromdir == "" or !is_dir($fromdir)) {
  echo ('Invalid directory');
  return false;
}

$filelist = array();
$dir = opendir($fromdir);

while($file = readdir($dir)) {
  if($file == "." || $file == ".." || $file == 'readme.txt' || $file == 'index.html' || $file == 'index.htm' || $file == 'lasttime.dat' ) {
    continue;
  } elseif (is_dir($fromdir."/".$file)) {
    if ($recursed == 1) {
      $temp = DeleteCacheFiles($fromdir."/".$file, $recursed);
    }
  } elseif (file_exists($fromdir."/".$file) && filemtime($fromdir."/".$file) < $tm) {
    unlink($fromdir."/".$file);
  }
}

closedir($dir);
return true;

}


function deleteCache() {
global $config;
/* This function will delete cache files.. */
$tm = time() - $config['time_cache_expiry']*60;
$lasttime = 0;
if (is_readable(CACHE_DIR.'lasttime.dat')) 
{
  $lt = file(CACHE_DIR.'lasttime.dat');
  $lasttime = trim($lt[0]);
}
if ($lasttime < $tm) 
  {
    DeleteCacheFiles(CACHE_DIR,$tm);
    $fp = @fopen(CACHE_DIR.'lasttime.dat','wb');
    if ($fp) 
    {
      fwrite($fp, time());
      fclose($fp);
    }
  }
} 

/* convert numbers to words */

/*
  $nwords = array(  "", "One", "Two", "Three", "Four", "Five", "Six", 
          "Seven", "Eight", "Nine", "Ten", "Eleven", "Twelve", "Thirteen", 
          "Fourteen", "Fifteen", "Sixteen", "Seventeen", "Eighteen", 
        "Nineteen", "Twenty", 30 => "Thirty", 40 => "Fourty",
                  50 => "Fifty", 60 => "Sixty", 70 => "Seventy", 80 => "Eigthy",
                  90 => "Ninety" );
                  
function number_to_words ($x)
{
  global $nwords;
  if(!is_numeric($x))
  {
      $w = 'a';
  }
  else if(fmod($x, 1) != 0)
  {
     //$w = 'b';
     list($OrgAmount,$DotAmount)= split ('[.]', $x);
     if (strlen($DotAmount)==1)
     {
    $DotAmount .= "0"; 
     }
     $paise = " and paise ".number_to_words($DotAmount). " ";
     $w = number_to_words($OrgAmount);
  }
  else
  {
      if($x < 0)
      {
          $w = 'minus ';
          $x = -$x;
      }else{
          $w = '';
      }
      if($x < 21)
      {
          $w .= $nwords[$x];
      }else if($x < 100)
      {
          $w .= $nwords[10 * floor($x/10)];
          $r = fmod($x, 10);
          if($r > 0)
          {
              $w .= ' '. $nwords[$r];
          }
      } else if($x < 1000)
      {
  
            $w .= $nwords[floor($x/100)] .' hundred';
          $r = fmod($x, 100);
          if($r > 0)
          {
              $w .= ' '. number_to_words($r);
          }
      } else if($x < 100000)
      {
        $w .= number_to_words(floor($x/1000)) .' thousand';
          $r = fmod($x, 1000);
          if($r > 0)
          {
              $w .= ' ';
              if($r < 100)
              {
                  $w .= ' ';
              }
              $w .= number_to_words($r);
          }
      } else if ($x < 10000000) {
          $w .= number_to_words(floor($x/100000)) .' Lacs';
          $r = fmod($x, 100000);
          if($r > 0)
          {
              $w .= ' ';
              if($r < 100)
              {
                  $word .= ' ';
              }
              $w .= number_to_words($r);
          }
      }else  {
          $w .= number_to_words(floor($x/10000000)) .' Crore';
          $r = fmod($x, 10000000);
          if($r > 0)
          {
              $w .= ' ';
              if($r < 100)
              {
                  $word .= ' ';
              }
              $w .= number_to_words($r);
          }
      }
  }
  return $w." ".$paise;
}
*/
function splitString($strToSplit,$SplitChar,$ReturnValueNumber)
{
$strSplit = split($SplitChar,$strToSplit);
if (is_array($strSplit))
{
  $retVal = $strSplit[$ReturnValueNumber];  
}
else
{
  $retVal = $strSplit;
}
return $retVal;
}


//echo number_to_words(11875494);
// use this function to output data as csv file //

function mssafe_csv($filepath, $data, $header = array())
{
 if ( $fp = fopen($filepath, 'w') ) {
     $show_header = true;
     if ( empty($header) ) {
         $show_header = false;
         reset($data);
         $line = current($data);
         if ( !empty($line) ) {
             reset($line);
             $first = current($line);
             if ( substr($first, 0, 2) == 'ID' && !preg_match('/["\\s,]/', $first) ) {
                 array_shift($data);
                 array_shift($line);
                 if ( empty($line) ) {
                     fwrite($fp, "\"{$first}\"\r\n");
                 } else {
                     fwrite($fp, "\"{$first}\",");
                     fputcsv($fp, $line);
                     fseek($fp, -1, SEEK_CUR);
                     fwrite($fp, "\r\n");
                 }
             }
         }
     } else {
         reset($header);
         $first = current($header);
         if ( substr($first, 0, 2) == 'ID' && !preg_match('/["\\s,]/', $first) ) {
             array_shift($header);
             if ( empty($header) ) {
                 $show_header = false;
                 fwrite($fp, "\"{$first}\"\r\n");
             } else {
                 fwrite($fp, "\"{$first}\",");
             }
         }
     }
     if ( $show_header ) {
         fputcsv($fp, $header);
         fseek($fp, -1, SEEK_CUR);
         fwrite($fp, "\r\n");
     }
     foreach ( $data as $line ) {
         fputcsv($fp, $line);
         fseek($fp, -1, SEEK_CUR);
         fwrite($fp, "\r\n");
     }
     fclose($fp);
 } else {
     return false;
 }
 return true;
}


/* output to csv example 


$filename = "filename.csv";        
if (file_exists($filename)):
 if(!is_writable($filename)):
     die ("The file: $filename is not writable");
 endif;
elseif( !is_writable( getcwd() ) ):
 die("you cannot create files in this directory.  Check the permissions");
endif;
 
//open the file for APPENDING
//add the "t" terminator for windows
//if using a mac then set the ini directive
$fh = fopen($filename, "at");
//Lock the file for the write operation
flock($fh, LOCK_EX);
//loop through the recordset
while( $row = db_fetch_row($q) ) {
 //db output manipulation
 $row=array_chunk($row, 33, TRUE);
 $row[1]["cc_number"]= base64_decode ( $row[1]["cc_number"]);
 $row[1]["cc_holdername"]= base64_decode ( $row[1]["cc_holdername"]);
 $row[1]["cc_expires"]= base64_decode ( $row[1]["cc_expires"]);
 $row[1]["cc_cvv"]= base64_decode ( $row[1]["cc_cvv"]);

 //use fputcsv by preference - we can just pass the row-array
 if (function_exists("fputcsv")):
     fputcsv($fh, $row[1], ",", "\"");
 else:
     //clean up the strings for escaping and add quotes
     foreach ($row[1] as $val):
         $b[] = '"'.addslashes($val).'"';
     endforeach;
     //comma separate the values
     $string = implode(",",$b);
     //write the data to the file
     fwrite($fh, $string ."\n",strlen($string));
 endif;
}            
//close the file handle outside the loop
//this releases the lock too
fclose($fh);
echo "Download the file <a href=\"$filename\">here</a>";

*/

function get_rnd_iv($iv_len)
{
    $iv = '';
    while ($iv_len-- > 0) {
        $iv .= chr(mt_rand() & 0xff);
    }
    return $iv;
}
function md5_encrypt($plain_text, $iv_len = 16)
{
  $password  = PASSWORD_SALT;
  $plain_text .= "\x13";
  $n = strlen($plain_text);
  if ($n % 16) $plain_text .= str_repeat("\0", 16 - ($n % 16));
  $i = 0;
  $enc_text = get_rnd_iv($iv_len);
  $iv = substr($password ^ $enc_text, 0, 512);
  while ($i < $n) 
  {
    $block = substr($plain_text, $i, 16) ^ pack('H*', md5($iv));
    $enc_text .= $block;
    $iv = substr($block . $iv, 0, 512) ^ $password;
    $i += 16;
  }
  return base64_encode($enc_text);
}

function md5_decrypt($enc_text,  $iv_len = 16)
{ 
  $password  = PASSWORD_SALT;
  $enc_text = base64_decode($enc_text);
  $n = strlen($enc_text);
  $i = $iv_len;
  $plain_text = '';
  $iv = substr($password ^ substr($enc_text, 0, $iv_len), 0, 512);
  while ($i < $n) {
    $block = substr($enc_text, $i, 16);
    $plain_text .= $block ^ pack('H*', md5($iv));
    $iv = substr($block . $iv, 0, 512) ^ $password;
    $i += 16;
  }
  return preg_replace('/\\x13\\x00*$/', '', $plain_text);
}

 

/*
function findEnd($date) 
{
$dow = array("Sun" => -1,"Mon" => -2,"Tue" => -3,"Wed" => 3,"Thu" => 2,"Fri" => 1,"Sat" => 0);
$end = $date + (86400 * $dow[date("D",$date)]);
}
//In fact, if you wanted to do it mathematically, that's a possibility too. The good thing about this is that it's easily adjustible:
function findend($date) 
{
$datetime = $date-259200; // subtract 3 days;
$end = date(r,$datetime + 86400*(6-date(w,$datetime)));
}
*/


//declare the website name
//$webname = "http://www.pwdarun.com";

//declare the title of the website
//$title = "Welcome to the Public Works Department - Government of Arunachal Pradesh, India";

//declare URLs of the links

//$homeLink = "http://localhost/php/pwdarun/";
//$contactLink = $homeLink . "/contact.htm";

//$unauthorisedLink = $homeLink . "/unauthorised.php";

//Current Date
$today = gmdate("Y-m-d");

//Current Year
$CurrYear = gmdate("Y");

//Last Year
$LastYear = gmdate("Y")-1;

//Financial Year
$FinYear=gmdate("y");
/*
// Current Financial year
function FinancialYr($date='',$noofyearsback='0')
{

$monthtofind = ($date=='')?gmdate("n",mktime(null,null,null,date("n"),date("d"),date("Y"))):gmdate("n",mktime(null,null,null,substr($date,0,2),substr($date,3,2),substr($date,6,4)));

$yeartofind = ($date=='')?gmdate("Y",mktime(null,null,null,date("n"),date("d"),date("Y"))):gmdate("Y",mktime(null,null,null,substr($date,0,2),substr($date,3,2),substr($date,6,4)))-$noofyearsback;

  if ($monthtofind < 4)
  {
    // jan feb or march month so deduct one from current year
    $FnYear = ($yeartofind-1);
    $FinancialYear= $FnYear."-".$yeartofind;  
  }
  else
  {
    $FnYear = ($yeartofind+1);
    $FinancialYear= $yeartofind."-".$FnYear;
  }
  
  return $FinancialYear;
}
*/
//echo FinancialYr("04-30-2002",0)."<br/>";
// Current Financial year
function FinancialYrStartEndDates($date='',$noofyearsback= '')
{
$monthtofind = ($date=='')?gmdate("n",mktime(null,null,null,date("n"),date("d"),date("Y"))):gmdate("n",mktime(null,null,null,substr($date,0,2),substr($date,3,2),substr($date,6,4)));

$yeartofind = ($date=='')?gmdate("Y",mktime(null,null,null,date("n"),date("d"),date("Y"))):gmdate("Y",mktime(null,null,null,substr($date,0,2),substr($date,3,2),substr($date,6,4)))-$noofyearsback;

  if ($monthtofind < 4)
  {
    // jan feb or march month so deduct one from current year
    $FnYear = ($yeartofind-1);
    $FinancialYear = $FnYear.'-04-01'."|".$yeartofind.'-03-31';  
  }
  else
  {
    $FnYear = ($yeartofind+1);
    $FinancialYear = $yeartofind.'-04-01'."|".$FnYear.'-03-31';
  }
  
  return $FinancialYear;  
}



/*
function LastFinancialYr($date='')
{
//  if ((gmdate("y")) < 10)
    //{
    //$FnYear =(gmdate("y"));
    //}
  //else
    //{
    //$FnYear = (gmdate("y"));
    //}
    $LastFinancialYear = (gmdate("Y")-1)."-".(gmdate("y"));
    return $LastFinancialYear;
}
*/
//echo LastFinancialYr();
//Current Time
function getLocalTime()
{
$currenttime = localtime(); 
$mytime = $currenttime[2] . ":" . $currenttime[1] . ":" . $currenttime[0];
return $mytime;
}

//Current Month by name
function getMyMonthName($n)
{
$mymonthArray = array("01" => "January", "02" => "February", "03" => "March", "04" => "April", "05" => "May", "06" => "June", "07" => "July", "08" => "August", "09" => "September", "10" => "October", "11" => "November", "12" => "December");
return $mymonthArray[$n];
}

function GetYearYYYYMMDD($val)
{
$dateMArray = explode("-", $val);
$val = ($dateMArray[2]."-".$dateMArray[1]."-".$dateMArray[0]);
return $val;
}

function getDateDDMMYYYY($val)
{
$myDateArray = explode("-", $val);
$val = ($myDateArray[2]."-".$myDateArray[1]."-".$myDateArray[0]);
return $val;
}

// format the date so that it looks prettier(dd-MMM-yy)
function fixDate($val)
{
$dateArray = explode("-", $val);
$val = date("j-M-y", mktime(0,0,0, $dateArray[1], $dateArray[2],$dateArray[0]));
return $val;
}

// format the date so that it prints month and year(MMM/YY)
function fixMonthYear($val)
{
$monthYearArray = explode("-", $val);
$val = date("M/Y", mktime(0,0,0, $monthYearArray[1], $monthYearArray[2], $monthYearArray[0]));
return $val;
}

//Get no of days between two given dates in dd-mm-yy format(1-0-2)
function getDateDiff($ad,$dd)
{
$arrdateArray = explode("-", $ad);
$adate = mktime(0,0,0, $arrdateArray[1], $arrdateArray[0],$arrdateArray[2]);

$depdateArray = explode("-", $dd);
$ddate = mktime(0,0,0, $depdateArray[1], $depdateArray[0],$depdateArray[2]);

$val = floor(($ddate - $adate)/60/60/24);
return $val;
}

//Get the Rights assigned to a user
function myrights($no)
{
$n = $no;
if($n == 0)
  $rights = "None";
if($n == 1)
  $rights = "Add";
if($n == 2)
  $rights = "Edit";
if($n == 3)
  $rights = "Delete";
if($n == 9)
  $rights = "All";
return $rights;
}


//Decode character
function decodeMe($sText)
{
  $sEncText = "";
  for ($i = 0; $i <= strlen($sText) - 1; $i++)
  {
    // Get the character we are going to work on
    $sChar = substr($sText, $i, 1);
    // Get the ASCII value of that of that charater
    $iASCII = ord($sChar);
    
    if( ($iASCII >= 192) && ($iASCII <= 217) )
      $sNewChar = chr($iASCII - 127);
    if( ($iASCII >= 218) && ($iASCII <= 243) )
      $sNewChar = chr($iASCII - 121);       
    if( ($iASCII >= 244) && ($iASCII <= 253) )
      $sNewChar = chr($iASCII - 196);
    if( ($iASCII == 32) )
      $sNewChar = chr($iASCII);         

    $sEncText = $sEncText . $sNewChar;
     }
  return $sEncText;
}

//Encode character
function encodeMe($sText)
{
  $sEncText = "";
  for ($i = 0; $i <= strlen($sText) - 1; $i++)
  {
    // Get the character we are going to work on
    $sChar = substr($sText, $i, 1);
    // Get the ASCII value of that of that charater
    $iASCII = ord($sChar);
    
    if( ($iASCII >= 65) && ($iASCII <= 90) )
      $sNewChar = chr($iASCII + 127);
    if( ($iASCII >= 97) && ($iASCII <= 122) )
      $sNewChar = chr($iASCII + 121);       
    if( ($iASCII >= 48) && ($iASCII <= 57) )
      $sNewChar = chr($iASCII + 196);
    if( ($iASCII == 32) )
      $sNewChar = chr($iASCII);               

    $sEncText = $sEncText . $sNewChar;
     }
  return $sEncText;
}
function left($str, $length) {
return substr($str, 0, $length);
}

function right($str, $length) {
return substr($str, -$length);
}

function Documents_Combo($membershipno = '')
{
$obj = new AllTables();

$membertype_sql = "select * from mstmember where membershipno = ".$membershipno;
$membertype_result = $obj -> getInfo('',$membertype_sql);
$doc_applicable = $membertype_result[0]['isManufacturer'];

$sql = "select * from mstdocuments where is_active = 1 and doc_applicable_for = ".$doc_applicable." union select * from mstdocuments where is_active = 1 and doc_applicable_for = 2 ";
//echo $sql;
$doclist = $obj -> getInfo('',$sql);
$rowcount = count($doclist);

if ($rowcount > 0)
  {
    
    for($i=0;$i<$rowcount;$i++) 
    { 
      
      
        $strdoclist .= "<option value='".$doclist[$i]['docname']."'>".ucwords(strtolower($doclist[$i]['docname']))."</option>";
    
    }
  }
  return $strdoclist;
}

function get_Uploaded_Doc($document = '',$membershipno = '')
{
$obj = new AllTables();
$sql = "select member_docid,docfilepath from trnmember_documents where membershipno = ".$membershipno." and doc_type_name = '".$document."'";
//echo $sql;
$query_result = $obj -> getInfo('',$sql);
$filename = $query_result[0]['docfilepath'];
$docid = $query_result[0]['member_docid'];
$val = $filename."||".$docid;
return $val;
}

function display_Uploaded_Doc($membershipno = '')
{
$obj = new AllTables();
$sql = "select * from trnmember_documents where membershipno = ".$membershipno;
//echo $sql;
$query_result = $obj -> getInfo('',$sql);
$row_count = count($query_result);
for($i=0;$i<$row_count;$i++)
{ 
$filename = $query_result[$i]['docfilepath'];
$docname = $query_result[$i]['doc_type_name'];
$docdate = $query_result[$i]['doc_uploaded_date'];
$doclink = DOC_ROOT."temp_doc/".$filename;
$docid = $query_result[$i]['member_docid'];
$val .= "<tr><td><a href ='".$doclink."'><img height = '50' width = '50'  src='".IMAGE_DIR."pdf-logo.jpg'></a></td><td valign='middle'><a href ='".$doclink."'>".$docname."</a></td><td>".$docdate."</td></tr>";
$final_packet = "<table>".$val."</table>";  
}

return $final_packet;
}

function returnSelected($value1,$value2)
{
  if ($value1==$value2)
  {
    return "selected='selected'";
  } 
   else
  {
    return "";
  } 
}


//Function used for iec details display in panel, created by ketaki
function MemberDisplay($membershipno='',$for_api = '',$accessid = 3,$G_officeid = '')
{   
    
    $iecMenu='';
    $MembeApplication     = new Application7();
    $category_obj     = new Category();

    $sql = "SELECT * FROM mstmember a
    INNER JOIN memberiec d ON a.MemberID = d.memberid
    left JOIN mstcategories c ON a.isManufacturer= c.categoryid 
    where a.membershipno = '".$membershipno."'  order by a.memberid desc limit 0,1";
      //echo $sql;
    $memlist    = $MembeApplication->getApplication7('',$sql);
    //print_r($memlist);
    
        if($for_api == '') 
        {
                  $i=0;
                      $membershipno1         =  $membershipno;
                      $memberid         =   $memlist[$i]['memberid'];
                      $membername         =   $memlist[$i]['MemberName'];
                      $reg_date         =     checkIfNullDate(date("d-m-Y", strtotime($memlist[$i]['approved_date'])));
                      $Categoryid         =     $memlist[$i]['isManufacturer'];
                      $categorylist       =   $category_obj->getCategory('','SELECT category_name FROM mstcategories where categoryid = '.$Categoryid);             
                      $category           =   $categorylist[0]['category_name'];
                      $dgftid           =     $memlist[$i]['dgftid'];
                      $dgftname         =     GetDgftOfficeName($dgftid);
                      $dgftlist           =     getAllDGFTListForCombo($dgftid);
                      $panelid            =   $memlist[$i]['panelid'];
                      $panel_name         =     DisplayPanelNames($panelid);
                      $panel_name_roman     =     DisplayPanelNamesInShort($panelid);
                      $panel            =    "Panel ".$panel_name_roman." : ".$panel_name;
                      $iecno            =   $memlist[$i]['IEC'];
                      $telno              =   $memlist[$i]['head_TelNo'];
                      
                      $display_payment_data   =     InvoiceDisplayInTabularFormat($memberid);
      
      $iecMenu        .=  '
<div>
            <div class="col-lg-12">
            <div class="col-lg-6">
                <div class="panel panel-info">
                  <div class="panel-heading">
                  Member
                  </div>
                  <div class="panel-body">
                  <div class="form-group col-lg-12"> 
                    <div class="col-lg-6">
                        <label>Membership No. :</label>
                        '.$membershipno.'     
                  </div>
                    <div class="col-lg-6">
                        <label>Admission Date:</label>
                        '.$reg_date.'     
                  </div>
                  
                  </div>
                    <div class="form-group col-lg-12"> 
                      <div class="col-lg-6">
                        <label>Member:</label>
                        <div>'.$membername.'</div>
                        
                      </div>
                      <div class="col-lg-6">
                        <label>Region :</label>
                      <div>'.$dgftname.'</div>
                      <select name="txtregion" class="form-control" style="display:none;">
                           <option>Select Region</option>
                          '.$dgftlist.' 
                    </select>
                    </div>
                    </div>
                    <div class="form-group col-lg-12"> 
                      <div class="col-lg-6">
                        <label>Category :</label>
                        <div>'.$category.'</div>
                        
                    </div>
                    <div class="col-lg-6">
                        <label>Panel :</label>
                        <div>'.$panel.'</div>
                        
                      </div>
                    </div>
                    <div class="form-group col-lg-12">  
                      <div class="col-lg-6">
                        <label>IEC No :</label>
                        <div>'.$iecno.'</div>
                      </div>
                      <div class="col-lg-6">
                        <label>Tel No:</label>
                      <div>'.$telno.'</div>
                      </div>
                    </div>
                
           </div>
          </div>

              </div>
              </div>
              
              </div>
';
                  
          return $iecMenu;        
        }
        
        else if($for_api == 1) 
        {
          return $ieclist;
        }         
} 




  // Display MemberApplication starts
function MemberApplicationDataDisplay($membershipno,$applicationid='')
{
  $member_obj       = new Application();
  $member_obj1      =   new Application5(); 
    $member_obj2      =   new Application2(); 
        $member_obj3      =   new Application4();
  if($applicationid !='')
  {
      $where = "and a.applicationid = '".$applicationid."'";
  }
  /*$sql = "SELECT  a.memberid,a.applicationid,a.membershipno,a.reach_cnt_address1,a.reach_cnt_address2,a.reach_cnt_email,a.reach_cnt_statename,a.reach_cnt_pincode,
                  a.reach_companyname,a.reach_cnt_person,a.reach_cnt_designation,a.reach_cnt_iecno,a.export_house_no,a.export_house_validuptodate,
                  a.company_category, a.receipt_1,a.receipt_2,a.receipt_3,a.date_1,a.date_2,a.date_3,
                  c.substancename,c.substance_ecno,c.submissionno,c.echa_reg_date,c.tonnageband,
                    f.echa_fees,f.echa_amount_in_rs,f.loa_fees,f.loa_amount_in_rs,f.consultancy_fees,f.consultancy_amount_in_rs
                FROM `reach_trnapplication` a
                INNER join mstmember b on a.membershipno=b.MembershipNo
                INNER JOIN reach_substancesdetails c ON a.applicationid = c.applicationid
            
                  where a.membershipno = '".$membershipno."' $where order by a.applicationid desc limit 0,1";*/
                  
                  $sql = "SELECT * FROM `reach_trnapplication` a
                inner join mstmember b on a.membershipno=b.MembershipNo
                left JOIN reach_substancesdetails c ON a.applicationid = c.applicationid
            
                  where a.membershipno = '".$membershipno."' $where order by a.applicationid desc limit 0,1";
  
    
    //echo $sql;   
    $applist       =  $member_obj->getApplication('',$sql);
    
    
    $memberid       =  $applist[0]['memberid'];

    $membershipno       =  $applist[0]['membershipno'];
     $edit_applicationid      =  $applist[0]['applicationid'];
    $MemberName       = $applist[0]['reach_companyname'];
    $address1         = $applist[0]['reach_cnt_address1'];
    $address2         = $applist[0]['reach_cnt_address2'];
    $email          = $applist[0]['reach_cnt_email'];
    $mobile              = $applist[0]['reach_cnt_contactno'];
    $contactperson_name=$applist[0]['reach_cnt_person'];
    $contactperson_designation=$applist[0]['reach_cnt_designation'];
    $iec              = $applist[0]['reach_cnt_iecno'];
    $export_house_no=$applist[0]['export_house_no'];
    $export_house_validuptodate= date("d-m-Y",strtotime($applist[0]['export_house_validuptodate']));
    $category_name              = $applist[0]['company_category'];  
    $pin=$applist[0]['reach_cnt_pincode'];
    $state=$applist[0]['reach_cnt_statename'];
    $receipt_1      =  $applist[0]['receipt_1'];
    //date("d-m-Y",strtotime($sqllist2[$i]['transition_date']));  
    $date_1       =  date("d-m-Y",strtotime($applist[0]['date_1']));
    //date("Y-m-d",strtotime($_POST['textdate'][$i]));
    $receipt_2      =  $applist[0]['receipt_2'];
    $date_2       =  date("d-m-Y",strtotime($applist[0]['date_2']));
    $receipt_3      =  $applist[0]['receipt_3'];
    $date_3       =  date("d-m-Y",strtotime($applist[0]['date_3']));
    $year_1        =  $applist[0]['year_1'];
    $year_2        =  $applist[0]['year_2'];
    $year_3        =  $applist[0]['year_3'];
    $fob_last_1_year       =  $applist[0]['fob_last_1_year'];
    $fob_last_2_year       =  $applist[0]['fob_last_2_year'];
    $fob_last_3_year       =  $applist[0]['fob_last_3_year'];
    $memberstatus=$applist[0]['memberstatus'];
  
  
      if($memberstatus=='0') 
      {
          $value="pending";
      }
      else 
      {
        $value="Completed";
      } 
      

    $statusreason=$applist[0]['statusreason'];
    if($statusreason != '')
    { 
        $statusreason1="<div class='col-lg-2'>Reasons:</div>".$statusreason."</div>";
    }
$sql3="select * from reach_substancelicenseissue t where t.applicationid= $edit_applicationid";
    //echo $sql3;   
  $applist3    =  $member_obj3->getApplication4('',$sql3);
  //  echo "<pre>";
  //  print_r($applist3);
    
    
   if(is_array($applist3))
          {
            $applist3count = count($applist3);
          }
    for($k=0;$k<$applist3count;$k++)
    {

        $issue_id   = $applist3[$k]['issue_id'];
      //  print_r($issue_id);
           $applicationid     =  $edit_applicationid;
        $substance_date       = $applist3[$k]['substance_date'];
      
          $Issuing_authority  = $applist3[$k]['Issuing_authority'];
        
        $tr3 .="<tr id=$issue_id>
                <td><input type='checkbox' class='verify_text1 ' style='display:none;' name='id' rel='1' id='case8' data-emp-id=$issue_id></td>
                 <td style='text-align: center;'><span id='snum8_'+i+''>".($k+1)."</span></td>
                <td><input type='hidden' value='$substance_date' name='textdate1[]' class='total_substancename1' id='textdate11_' >$substance_date</td>
              
                <td><input type='hidden' value='$Issuing_authority' name='textIssuing1[]' class='total_submissionno1' id='textIssuing11_' >$Issuing_authority</td>
                  </tr>";
        
    
    }

  $sql2="select * from reach_substancesdetails h where h.applicationid= $applicationid";
  //  echo $sql2;   
  $applist2      =  $member_obj2->getApplication2('',$sql2);
    if(is_array($applist2))
          {
            $applist2count = count($applist2);
          }
    //echo "<pre>";
    //print_r($applist1);
    
    
    for($j=0;$j<$applist2count;$j++)
    {

        $substancesid   = $applist2[$j]['substancesid'];
           $applicationid     =  $edit_applicationid;
        $substancename        = $applist2[$j]['substancename'];
        $substance_ecno = $applist2[$j]['substance_ecno'];
        $submissionno = $applist2[$j]['submissionno'];
        
        
        $tr1 .="<tr id=$substancesid>
                <td><input type='checkbox' class='verify_text ' style='display:none;' name='id' id='case2' rel='1' data-emp-id=$substancesid></td>
                 <td style='text-align: center;'><span id='snum2_'+i+''>".($j+1)."</span></td>
                <td><input type='hidden' value='$substancename' name='textsubstancess1[]' class='total_substancename1' id='txtsubstancenames11_' >$substancename</td>
                <td><input type='hidden' value='$substance_ecno'  class='total_substance_ecno1' name='txtsubstances1[]' id='txtsubstance_ecnos11_'>$substance_ecno</td>
                <td><input type='hidden' value='$submissionno' name='txtsubmissionnos1[]' class='total_submissionno1' id='txtsubmissionnos11_' >$submissionno</td>
                  </tr>";
        
    
    }

$sql1="select * from reach_paymentdetails g where g.applicationid= $applicationid";
    //echo $sql1;   
  $applist1      =  $member_obj1->getApplication5('',$sql1);
    //echo "<pre>";
    //print_r($applist1);

   if(is_array($applist1))
          {
            $applist1count = count($applist1);
          }
    for($i=0;$i<$applist1count;$i++)
    {
        $paymentdetailsid   = $applist1[$i]['paymentdetailsid'];
           $applicationid     = $edit_applicationid;
        $echa_fees        = $applist1[$i]['echa_fees'];
        $echa_exchange_rate = $applist1[$i]['echa_exchange_rate'];
        $echa_amount_in_rs  = $applist1[$i]['echa_amount_in_rs'];
        $loa_fees       = $applist1[$i]['loa_fees'];
        $loa_exchange_rate  = $applist1[$i]['loa_exchange_rate'];
        $loa_amount_in_rs   = $applist1[$i]['loa_amount_in_rs'];
        $consultancy_fees   = $applist1[$i]['consultancy_fees'];
        $consultancy_exchange_rate  = $applist1[$i]['consultancy_exchange_rate'];
        $consultancy_amount_in_rs = $applist1[$i]['consultancy_amount_in_rs'];
        
        $tr .="<tr id=$paymentdetailsid>
                <td><input type='checkbox'  id='case1' rel='1' name='id'  style='display:none;' class='claim_text' data-emp-id=$paymentdetailsid></td>
                 <td style='text-align: center;'><span id='snum1_'+i+''>".($i+1)."</span></td>
                <td><input type='hidden' value='$echa_fees' name='txtecha_feess1[]' class='total_echa_fees1' id='txtecha_feess11_' >$echa_fees</td>
                <td><input type='hidden' value='$echa_exchange_rate'  class='total_echa_exchange_rate1' name='txtecha_exchange_ratess1[]' id='txtecha_exchange_rates11_'>$echa_exchange_rate</td>
                <td><input type='hidden' value='$echa_amount_in_rs' name='txtecha_amount_in_rss1[]' class='total_echa_amount_in_rs1' id='txtecha_amount_in_rss11_' >$echa_amount_in_rs</td>
                <td><input type='hidden' value='$loa_fees' name='txtloa_feess1[]' class='total_loa_fees1' id='txtloa_feess11_' >$loa_fees</td>
                <td><input type='hidden' value='$loa_exchange_rate'  class='total_loa_exchange_rate1' name='txtloa_exchange_rates1[]' id='txtloa_exchange_rates11_'>$loa_exchange_rate</td>
                <td><input type='hidden' value='$loa_amount_in_rs' name='txtloa_amount_in_rss1[]' class='total_loa_amount_in_rs1' id='txtloa_amount_in_rss11_' >$loa_amount_in_rs</td>
                <td><input type='hidden' value='$consultancy_fees' name='txtconsultancy_feess1[]' class='total_consultancy_fees1' id='txtconsultancy_feess11_' >$consultancy_fees</td>
                <td><input type='hidden' value='$consultancy_exchange_rate'  class='total_consultancy_exchange_rate1' name='txtconsultancy_exchange_rates1[]' id='txtconsultancy_exchange_rates11_'>$consultancy_exchange_rate</td>
                <td><input type='hidden' value='$consultancy_amount_in_rs' name='txtconsultancy_amount_in_rss1[]' class='total_consultancy_amount_in_rs1' id='txtconsultancy_amount_in_rss11_' >$consultancy_amount_in_rs</td>
            </tr>";
        
    
    }
    //echo $tr;

    $city = $applist[0]['head_CityName'];

    $FaxNo        = $applist[0]['head_FaxNo'];
    $telno        = $applist[0]['cor_telno'];
    $office_name  = $applist[0]['office_name'];

  

if($memberstatus == '0') {
      
        
        $headform0 = "'reg_headoffice00'";
        $sendurl    = "'member_membership_submit.php'";
        
        
        $edit_option_grid = '<a href="#" class="person_edit1 person_span1" rel="'.$applicationid.'" id="person_edit1" onclick="return false;">EDIT</a>
                      <a href="#" class="person_cancel1 person_text1" rel="'.$applicationid.'" id="person_cancel1"  onclick="return false;" style="display:none;">CANCEL</a>
                      <a href="#" class="person_save1 person_text1" rel="'.$applicationid.'" id="person_save1" onclick="formAjax('.$headform0.','.$sendurl.'); return false;" style="display:none;">SAVE</a>';                        

        

    
        $headform4  = "'reg_headoffice2'";
        $filename4 = "'member_application_submit5.php'";
  
        $editable_grid4 = '<a href="#" class="claim_edit claim_span" rel="'.$applicationid.'" id="claim_edit" onclick="return false;">EDIT</a>
                     <a href="#" class="claim_cancel claim_text" rel="'.$applicationid.'" id="claim_cancel" onclick="return false;" style="display:none;">CANCEL</a>
                     <a href="#" class="claim_save claim_text" rel="'.$applicationid.'" id="claim_save" onclick="formAjax('.$headform4.','.$filename4.'); return false;" style="display:none;">SAVE</a>';


        $headform5 = "'reg_headoffice3'";
        $filename5 = "'member_application_submit4.php'";

        $editable_grid5 = '<a href="#" class="verify_edit verify_span" rel="'.$applicationid.'" id="verify_edit" onclick="return false;">EDIT</a>
                     <a href="#" class="verify_cancel verify_text" rel="'.$applicationid.'" id="verify_cancel" onclick="return false;" style="display:none;">CANCEL</a>
                     <a href="#" class="verify_save verify_text" rel="'.$applicationid.'" id="verify_save" onclick="formAjax('.$headform5.','.$filename5.'); return false;" style="display:none;">SAVE</a>';
            
          $headform8 = "'reg_headoffice8'";
        $filename8 = "'member_application_submit3.php'";

        $editable_grid8 = '<a href="#" class="verify_edit1 verify_span1" rel="'.$applicationid.'" id="verify_edit1" onclick="return false;">EDIT</a>
                     <a href="#" class="verify_cancel1 verify_text1" rel="'.$applicationid.'" id="verify_cancel1" onclick="return false;" style="display:none;">CANCEL</a>
                     <a href="#" class="verify_save1 verify_text1" rel="'.$applicationid.'" id="verify_save1" onclick="formAjax('.$headform8.','.$filename8.'); return false;" style="display:none;">SAVE</a>';
    
}

$applicationlist = '';  
if($applicationid != '')
{
      $applicationlist .= '   
      
      
          
        <div class="col-lg-12">
            <div class="panel panel-info">
                <div class="panel-heading">
                Person Details
                </div>

                  <div class="panel-body">
                    <form  id="reg_headoffice00">
                        <input type="hidden" id="txteditmembershipno" name="txteditmembershipno"  value="'.$membershipno.'">
                        <input type="hidden" id="txtmemberid" name="txtmemberid"  value="'.$memberid.'" >
                        <input type="hidden" id="txtapplicationid" name="txtapplicationid"  value="'.$applicationid.'">
                      <input type="hidden" id="entered_export_count" name="entered_export_count" value="0">
                      <table width="95%"   class="table table-bordered">
                        <tr>
                          <td width="7%">1</td>
                          <td colspan="2" width="35%">Name of the Applicant Firm : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$MemberName.'</div>
                                  <input type="text" name="txtmembername" value="'.$MemberName.'"  readonly="" required=""  class="form-control person_text1" style="display:none;">
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">2</td>
                          <td colspan="2" width="35%">Address of the Applicant Firm Line 1 : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$address1.'</div>
                                  <input type="text" name="txtaddress1" value="'.$address1.'"   required=""  class="form-control person_text1" style="display:none;">
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">3</td>
                          <td colspan="2" width="35%">Address of the Applicant Firm Line 2 : </td>
                          <td colspan="3">
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$address2.'</div>
                                  <input type="text" name="txtaddress2" value="'.$address2.'"   class="form-control person_text1" style="display:none;">
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">4</td>
                          <td colspan="2" width="35%">Region of the Applicant Firm : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$office_name.'</div>
                                  <input type="text" name="txtregion" value="'.$office_name.'"  readonly="" required=""  class="form-control person_text1" style="display:none;">
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">5</td>
                          <td colspan="2" width="35%">State of the Applicant Firm : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$state.'</div>
                                  <input type="text" name="txtstate" value="'.$state.'"   required=""  class="form-control person_text1" style="display:none;">
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">6</td>
                          <td colspan="2" width="35%">City of the Applicant Firm : </td>
                          <td colspan="3">
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$city.'</div>
                                   <input type="text" name="txtcity" value="'.$city.'"   required=""  class="form-control person_text1" style="display:none;">
                                </div>
                              </td>
                        </tr>
                        <tr>
                          <td width="7%">7</td>
                          <td colspan="2" width="35%">Postcode of the Applicant Firm : </td>
                          <td colspan="3">
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$pin.'</div>
                                  <input type="text" name="txtpin" value="'.$pin.'"   required=""  class="form-control person_text1" style="display:none;">
                                 </div>
                              </td>
                        </tr>
  
                        <tr>
                          <td width="7%">8</td>
                          <td colspan="2" width="35%">Tel: (with STD Code) : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$telno.'</div>
                                  <input type="text" name="txttel" value="'.$telno.'"      required="" class="form-control person_text1" style="display:none;" >
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">9</td>
                          <td colspan="2" width="35%">Fax: (with STD Code) : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$FaxNo.'</div>
                                  <input type="text" name="txtfax" value="'.$FaxNo.'"    required="" class="form-control person_text1" style="display:none;" >
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">10</td>
                          <td colspan="2" width="35%">Mobile No : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$mobile.'</div>
                                  <input type="text" name="txtmobileno" value="'.$mobile.'"  required=""  class="form-control person_text1" style="display:none;">
                                </div>
                          </td>
                        </tr>
                        <tr>
                          <td width="7%">11</td>
                          <td colspan="2" width="35%">E-mail :</td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$email.'</div>
                                  <input type="text" name="txtemail" value="'.$email.'"   required=""  class="form-control person_text1" style="display:none;">
                              </div>
                            </td>
                        </tr>
                      <!--<tr>
                        <td width="7%">12</td>
                        <td colspan="2" width="35%">Website : </td>
                        <td colspan="3"> 
                            <div class="col-lg-15">
                                <div class="person_span1">'.$website.'</div>
                                <input type="text" name="txtwebsite" value="'.$website.'"   required="" class="form-control person_text1" style="display:none;">
                            </div>
                          </td>
                      </tr>-->
  
                      <tr>
                        <td width="7%">12</td>
                        <td colspan="2" width="35%">Name of contact person : </td>
                        <td colspan="3"> 
                            <div class="col-lg-15">
                                <div class="person_span1">'.$contactperson_name.'</div>
                                <input type="text" name="txtcntname" value="'.$contactperson_name.'"  required="" class="form-control person_text1" style="display:none;">
                              </div>
                          </td>
                      </tr>
                      <tr>
                        <td width="7%">13</td>
                        <td colspan="2" width="35%">Designation of contact person :</td>
                        <td colspan="3"> 
                            <div class="col-lg-15">
                                <div class="person_span1">'.$contactperson_designation.'</div>
                                <input type="text" name="txtcntdes" value="'.$contactperson_designation.'"   required="" class="form-control person_text1" style="display:none;">
                            </div>
                          </td>
                      </tr>
                      <tr>
                        <td width="7%">14</td>
                        <td colspan="2" width="35%">IEC No. of the firm. :</td>
                        <td colspan="3"> 
                            <div class="col-lg-15">
                                <div class="person_span1">'.$iec.'</div>
                                <input type="text" name="txtiec" value="'.$iec.'"   readonly="" required="" class="form-control person_text1" style="display:none;">
                            </div>
                          </td>
                      </tr>
                      <tr>
                        <td width="7%">15</td>
                        <td colspan="2" width="35%">Customer ID (UUID) as per ECHA Invoice :</td>
                        <td colspan="3"> 
                            <div class="col-lg-15">
                                <div class="person_span1">'.$cid.'</div>
                                <input type="text" name="txtcid" value="'.$cid.'"    required="" class="form-control person_text1" style="display:none;">
                            </div>
                          </td>
                      </tr>
        
                      <tr>
                        <td width="7%">16</td>
                        <td colspan="2" width="35%">Chemexcil Membership Code :</td>
                        <td colspan="3">
                            <div class="col-lg-15">
                                <div class="person_span1">'.$membershipno.'</div>
                                <input type="text" name="txtmembershipcode" value="'.$membershipno.'" readonly="" required=""  class="form-control person_text1" style="display:none;">
                            </div>
                          </td>
                      </tr>
                      <tr>
                        <td width="7%">17</td>
                        <td colspan="2" width="35%">Whether ( LSM/ MSM/ SSM/ MICRO SM)                                             : </td>    
                        <td colspan="3">
                            <div class="col-lg-15">
                                <div class="person_span1">'.$category_name.'</div>
                                <input type="text" name="txtwhether" value="'.$category_name.'"   required="" class="form-control person_text1" style="display:none;">              
                            </div>
                        </td>
                      </tr>
                      <tr>
                        <td width="7%">18</td>
                        <td colspan="2" width="35%">  Status of Membership subscription fees paid for 3 years:
                        <div >'.$year_1.'</div>
                        <input type="hidden"  name="textyear1"  readonly=""  value="'.$year_1.'" class="form-control person_text1" style="display:none;">
                          </div>
                          <div>'.$year_2.'</div>
                          <input type="hidden"  name="textyear2"  readonly=""  value="'.$year_2.'" class="form-control person_text1"  style="display:none;">
                          </div>
                          <div>'.$year_3.'</div>
                          <input type="hidden"  name="textyear3"  readonly=""  value="'.$year_3.'" class="form-control person_text1"  style="display:none;">
                          </div>
                          </td>
                        <td colspan="3">
                        <div class="col-lg-4">
                            <label>Receipt  No.</label>
                            <div class="person_span1">'.$receipt_1.'</div>
                            <input type="text"  name="textfees1"   value="'.$receipt_1.'"   class="form-control person_text1" style="display:none;">
                            <div class="person_span1">'.$receipt_2.'</div>
                            <input type="text" name="textfees2"  value="'.$receipt_2.'"   class="form-control person_text1" style="display:none;" >
                            <div class="person_span1">'.$receipt_3.'</div>
                            <input type="text" name="textfees3"   value="'.$receipt_3.'"    class="form-control person_text1" style="display:none;" >
                          </div>
                          <div class="col-lg-4">
                            <label>Date:</label>
                            <div class="person_span1">'.$date_1.'</div>
                              <input type="text" id="txtappdate12" name="txtappdate" required="" value="'.$date_1.'"   class="form-control person_text1" style="display:none;">
                              <div class="person_span1">'.$date_2.'</div>
                              <input type="text" id="txtappdate11" name="txtappdate1" required="" value="'.$date_2.'"  class="form-control person_text1" style="display:none;">
                              <div class="person_span1">'.$date_3.'</div>
                            <input type="text" id="txtappdate21" name="txtappdate2" required="" value="'.$date_3.'"   class="form-control person_text1" style="display:none;" >
                          </div>
                      </tr>
                      <tr>
                        <td width="7%">19</td>
                        <td colspan="2" width="35%">Export House Certificate, if applicable :</td>
                        <td colspan="3">
                          <div class="form-group col-lg-4">
                                 Certificate No :
                                      <div class="person_span1">'.$export_house_no.'</div>  
                                  <input type="text" id="txtcertificateno" name="txtcertificateno"  value="'.$export_house_no.'" class="form-control person_text1" style="display:none;"   placeholder="" >
                          </div>
                          <div class="form-group col-lg-4">                         
                              Valid Upto :
                            <div class="person_span1">'.$export_house_validuptodate.'</div>
                            <input type="text" id="txtcertificatevalidupto1" name="txtcertificatevalidupto"  value="'.$export_house_validuptodate.'"  class="form-control person_text1" style="display:none;"   placeholder="" >
                          </div>
                      </tr>

                      <tr><td width="7%">20</td>
                        <td colspan="2" width="35%"> FOB value of exports during the last 3 financial year:</td>
                        <td colspan="3">
                                            
                            <div class="col-lg-4">
                                <label>Last 1 Year ('.$year_1.'):</label>
                                <div class="person_span1">'.$fob_last_1_year.'</div>
                                <input type="text" id="txtfob_enter11" name="txtfob_enter11" value="'.$fob_last_1_year.'" class="form-control person_text1"  style="display:none;">                   
                              </div>
                              <div class="col-lg-4">
                                <label>Last 2 Year ('.$year_2.'):</label>
                                <div class="person_span1">'.$fob_last_2_year.'</div>
                              <input type="text" id="txtfob_enter21" name="txtfob_enter21" value="'.$fob_last_2_year.'" class="form-control person_text1"  style="display:none;">
                              </div>
                            <div class="col-lg-4">
                                <label>Last 3 Year ('.$year_3.'):</label>
                                <div class="person_span1">'.$fob_last_3_year.'</div>
                              <input type="text" id="txtfob_enter31" name="txtfob_enter31" value="'.$fob_last_3_year.'" class="form-control person_text1" style="display:none;">
                              </div>
                      
                      </tr>
                          <tr><td width="7%">21</td>
                            <td colspan="2" width="35%">Status </td>
                            <td colspan="3">
                                <div class="row col-lg-6 person_text1" style="display:none;">
                            
                                  <!--<label class="radio-inline"><input type="radio" name="memberstatus" class="memberstatus1"  '.(($memberstatus =='0')?'checked':'').' value="0" >Panding</label>
                                  <label class="radio-inline"><input type="radio" name="memberstatus" class="memberstatus1" '.(($memberstatus =='1')?'checked':'').' value="1">Completed</label> --> 
                                  Status:'.$value.'<br>'.$statusreason1.'
                                </div>
                            
                                <!--<div class="row col-lg-6 statusreason1 person_text1" style="display:none;">
                                  <input type="text" id="statusreason" name="statusreason" class="form-control statusreasons person_text1" style="display:none;" value="'.$statusreason.'"   placeholder="Type a reason here" /> <br> <label class="text text-danger">Please mentioned the reason for pending member only.</label>
  
                                </div>  
                                <div class="row col-lg-6 statusreason2 person_text1" style="display:none;">
                                </div>-->
                                  
                              <div class="statusreason person_span1" id="statusreason1"><div class="col-lg-2">Status:</div>'.$value.'<br>'.$statusreason1.'
                            </td>
                          </tr>

                    </table>
                  </form>'.$edit_option_grid.'
                </div>
              </div>
            </div>
            
            <div class="col-lg-12">
                <div class="panel panel-info">
                  <div class="panel-heading">
                      Details of manufacturing license issued by the Licensing Authority (in India) for the substance(to be enclosed ) 
                  </div>
                  <div class="panel-body">
                    <form id="reg_headoffice8">
                        <input type="hidden" id="txtmemberid" name="txtmemberid"  value="'.$memberid.'" >
                        <input type="hidden" id="txtapplicationid" name="txtapplicationid"  value="'.$applicationid.'">
                        <input type="hidden" id="entered_export_count8" name="entered_export_count" value="'.$k.'">             
                        <button type="button" class="btn btn-primary pull-left verify_text1"  style="display:none;" onclick="updateFormc();"/>Add Entry</button>
                        <br>
                        <br>
                        <table width="95%"  id="results8" class="table table-bordered">
                          <tr>
                            <th><input id="check_alls" class="verify_text1" style="display:none;"   type="checkbox" onclick="select_all8()"/></th>
                            <th>No.</th><td> Date</td>
                            <th>Issuing authority</th>
                          </tr>
                    
                          <tr>
                            <td width="5%"></td>
                            <td></td>
                            <td><input type="text" id="textdate1" value="" class="form-control input-md verify_text1" style="display:none;"></td>
                            <td><input type="text" id="textIssuing1" value="" class="form-control input-md verify_text1" style="display:none;"></td>
                          </tr>
                      
                          '.$tr3.'
                          <tr>
                          <!--  <td style="display: none;"><div id="fob4"></div></td>-->
                            <td style="display: none;"><div id="Date  "></div></td>
                            <td style="display: none;"><div id="Issuing"></div></td>
                          </tr>
                        </table>
                        <br>
                        <button class="btn btn-primary pull-left verify_text1" style="display:none;"  type="button" id="deleteAcc8">Delete</button>
                        <br>
                        <br>
                        <br>
                    </form>'.$editable_grid8.'
                </div>                    
              </div>
            </div>  
              
               <div class="col-lg-12">
                <div class="panel panel-info">
                  <div class="panel-heading">
                      Details of the substances registered by  your firm 
                  </div>
                  <div class="panel-body">
                    <form id="reg_headoffice3">
                        <input type="hidden" id="txtmemberid" name="txtmemberid"  value="'.$memberid.'" >
                        <input type="hidden" id="txtapplicationid" name="txtapplicationid"  value="'.$applicationid.'">
                        <input type="hidden" id="entered_export_count2" name="entered_export_count" value="'.$j.'">             
                        <button type="button" class="btn btn-primary pull-left verify_text"  style="display:none;" onclick="updateFormsa();"/>Add Entry</button>
                        <br>
                        <br>
                        <table width="95%"  id="results2" class="table table-bordered">
                          <tr>
                            <th><input id="check_all2"  class="verify_text " style="display:none;"  type="checkbox" onclick="select_all2()"/></th>
                                <th>Sr. No.</th><td> Substance Name</td>
                                        <th>EC No.</th>
                                        <th> Submission No.</th>
                          </tr>
                          <tr>  
                            <td width="7%"></td>
                            <td></td>
                            <td><input type="text" id="textsubstancess1" value="" class="form-control input-md verify_text"  style="display:none;"></td>
                          
                            
                          
                            <td><input type="number" id="textecnos1" value="" class="form-control input-md verify_text"  style="display:none;"></td>
                    
                        
                          
                            <td><input type="number"  id="textsubminos1" value="" class="form-control input-md verify_text"  style="display:none;"></td>
                        
                            
                          </tr>'.$tr1.'
                          <tr>
                          <!--  <td style="display: none;"><div id="fob4"></div></td>-->
                            <td style="display: none;"><div id="substances1"></div></td>
                            <td style="display: none;"><div id="ecno1"></div></td>
                            <td style="display: none;"><div id="submino1"></div></td>
                          </tr>
                        </table>
                        <br>
                        <button class="btn btn-primary pull-left verify_text " style="display:none;"  type="button" id="deleteAcc2">Delete</button>
                        <br>
                        <br>
                        <br>
                    </form>'.$editable_grid5.'
                </div>                    
              </div>
            </div>
            <div class="col-lg-12">
              <div class="panel panel-info">
                  <div class="panel-heading">
                  Details of Registration fees paid by your firm to ECHA
                  </div>
                  <div class="panel-body">
                  <form id="reg_headoffice2">
                        <input type="hidden" id="txtmemberid" name="txtmemberid"  value="'.$memberid.'" >
                        <input type="hidden" id="txtapplicationid" name="txtapplicationid"  value="'.$applicationid.'">
                      <input type="hidden" id="entered_export_count1" name="entered_export_count" value="'.$i.'">           
                  
                      <button type="button" class="btn btn-primary pull-left claim_text " style="display:none;"  onClick="updateForms();"/>Add Entry</button>
                      <br>
                      <br>
                      <table width="95%"  id="results1" class="table table-bordered">
                        <tr>
                          <th><input id="check_all1"  class="claim_text " style="display:none;"  type="checkbox" onclick="select_all1()"/></th>
                          <th>Sr. No.</th>
                        <!--  <td> Substance Name</td>-->
                          <td>ECHA Regn fees paid in Euro as per ECHA Invoice   </td>
                          <td> Exchange Rate as per Bank Transaction copies </td>
                          <td> (Amount in Rs ) </td>
                          <td>LOA Fees as per LR Invoice or Data fees as per Lab invoice   </td>
                          <td> Exchange Rate as per Bank Transaction copies  </td>
                          <td>(Amount in Rs )</td>
                          <td>Consultancy charges as per consultant’s invoice</td>
                          <td> Exchange Rate as per Bank Transaction copies  </td>
                          <td> (Amount in Rs )</td>
                        </tr>
                        <tr>
                          <td width="7%"></td><td></td>
                        <!--  <td><input type="number"  id="txtfob_enter4" value="" class="form-control input-md " ></td>-->
                    
                          <td><input type="number" id="txtecha_fees1" value="" class="form-control input-md claim_text " style="display:none;"></td>
                        
                          <td><input type="number"  id="txtecha_exchange_rate1" value="" class="form-control input-md claim_text" style="display:none;"></td>
                        
                          <td><input type="number" id="txtecha_amount_in_rs1" value="" class="form-control input-md claim_text" style="display:none;"></td>
                  
                          <td><input type="number" id="txtloa_fees1" value="" class="form-control input-md claim_text" style="display:none;"></td>
                        
                          <td><input type="number"  id="txtloa_exchange_rate1" value="" class="form-control input-md claim_text" style="display:none;"></td>
                      
                          <td><input type="number" id="txtloa_amount_in_rs1" value="" class="form-control input-md claim_text" style="display:none;"></td>
                  
                          <td><input type="number" id="txtconsultancy_fees1" value="" class="form-control input-md claim_text" style="display:none;"></td>
                      
                          <td><input type="number"  id="txtconsultancy_exchange_rate1" value="" class="form-control input-md claim_text" style="display:none;"></td>
                    
                          <td><input type="number" id="txtconsultancy_amount_in_rs1" value="" class="form-control input-md claim_text" style="display:none;"></td>
                        </tr>'.$tr.'
                        <tr>
                        <!--  <td style="display: none;"><div id="fob4"></div></td>-->
                          <td style="display: none;"><div id="echa_fees1"></div></td>
                          <td style="display: none;"><div id="echa_exchange_rate1"></div></td>
                          <td style="display: none;"><div id="echa_amount_in_rs1"></div></td>
                          <td style="display: none;"><div id="loa_fees1"></div></td>
                          <td style="display: none;"><div id="loa_exchange_rate1"></div></td>
                          <td style="display: none;"><div id="loa_amount_in_rs1"></div></td>
                          <td style="display: none;"><div id="consultancy_fees1"></div></td>
                          <td style="display: none;"><div id="consultancy_exchange_rate1"></div></td>
                          <td style="display: none;"><div id="consultancy_amount_in_rs1"></div></td>
                  
                        </tr>
                      </table>
                      <table  width="95%"   class="table table-bordered">
                        
                        <tr>
                          
                          <td width="10%">TOTAL</td>
                          
                  
                        
                          <!--<td><div id="totalfob4"></div></td>-->
                          <td><input type="hidden" id="echa_fees_total1" name="echa_fees_total"><div id="total_echa_fees1" ></div></td>
                          <td><input type="hidden" id="echa_exchange_rate_total1" name="echa_exchange_rate_total"><div id="total_echa_exchange_rate1"></div></td>
                          <td><input type="hidden" id="echa_amount_in_rs_total1" name="echa_amount_in_rs_total"><div id="total_echa_amount_in_rs1"></div></td>
                          <td><input type="hidden" id="loa_fees_total1" name="loa_fees_total1"><div id="total_loa_fees1"></div></td>
                          <td><input type="hidden" id="loa_exchange_rate_total1" name="loa_exchange_rate_total"><div id="total_loa_exchange_rate1"></div></td>
                          <td><input type="hidden" id="loa_amount_in_rs_total1" name="loa_amount_in_rs_total"><div id="total_loa_amount_in_rs1"></div></td>
                          <td><input type="hidden" id="consultancy_fees_total1" name="consultancy_fees_total"><div id="total_consultancy_fees1"></div></td>
                          <td><input type="hidden" id="consultancy_exchange_rate_total1" name="consultancy_exchange_rate_total"><div id="total_consultancy_exchange_rate1"></div></td>
                          <td><input type="hidden" id="consultancy_amount_in_rs_total1" name="consultancy_amount_in_rs_total"><div id="total_consultancy_amount_in_rs1"></div></td>
                        
                        </tr>
                    
                  
                        </table>
                        <br>
                        <button class="btn btn-primary pull-left claim_text " style="display:none;"  type="button" id="deleteAcc1">Delete</button>
                        <br>
                        <br>
                        <br>
                    </form>'.$editable_grid4.'
                  </div>  
                  </div>        
              </div>';
}       
  return $applicationlist;

    
} 
/*
  // Display Application starts
function ApplicationDisplay($membershipno,$applicationid='')
{
	$member_obj       = new Application();
	$member_obj1      =   new Application5(); 
	$member_obj2      =   new Application2(); 
    $member_obj3      =   new Application4();
	if($applicationid !='')
	{
		$where = "and a.applicationid = '".$applicationid."'";
	}
 
    $sql = "SELECT * FROM `reach_trnapplication` a
            INNER join mstmember b on a.membershipno=b.MembershipNo
			where a.membershipno = '".$membershipno."' $where order by a.applicationid desc limit 0,1";
  
    
    //echo $sql;   
    $membernamelist       =  $member_obj->getApplication('',$sql);
    
						$applicationid 				=  $membernamelist[0]['applicationid'];
						$memberid 			=  $membernamelist[0]['memberid'];
   						$applicationdate 			=  date("d-m-Y",strtotime($membernamelist[0]['applicationdate']));
	 					$reach_cnt_person				=  $membernamelist[0]['reach_cnt_person'];
	 					$reach_cnt_designation				=  $membernamelist[0]['reach_cnt_designation'];
	 					$reach_cnt_contactno				=  $membernamelist[0]['reach_cnt_contactno'];
	 					$reach_cnt_email				=  $membernamelist[0]['reach_cnt_email'];
	 					$reach_companyname				=  $membernamelist[0]['reach_companyname'];
	 					$reach_cnt_address1				=  $membernamelist[0]['reach_cnt_address1'];
	 					$reach_cnt_address2				=  $membernamelist[0]['reach_cnt_address2'];
	 					$reach_cnt_stateid				=  $membernamelist[0]['reach_cnt_stateid'];
	 					$reach_cnt_statename				=  $membernamelist[0]['reach_cnt_statename'];
	 					$reach_cnt_pincode				=  $membernamelist[0]['reach_cnt_pincode'];
	 					$reach_cnt_gstno				=  $membernamelist[0]['reach_cnt_gstno'];
	 					$reach_cnt_iecno				=  $membernamelist[0]['reach_cnt_iecno'];
	 					$customer_id				=  $membernamelist[0]['customer_id'];
	 					$ischemexcilmember				=  $membernamelist[0]['ischemexcilmember'];
	 					$company_category				=  $membernamelist[0]['company_category'];
	 					$export_house_no				=  $membernamelist[0]['export_house_no'];
	 					$export_house_issueddate				=  date("d-m-Y",strtotime($membernamelist[0]['export_house_issueddate']));
	 					$export_house_validuptodate				=  date("d-m-Y",strtotime($membernamelist[0]['export_house_validuptodate']));
	 					$mfg_no				=  $membernamelist[0]['mfg_no'];
	 					$mfg_date				=  $membernamelist[0]['mfg_date'];
	 					$mfg_authority				=  $membernamelist[0]['mfg_authority'];
	 					$approved_bymember				=  $membernamelist[0]['approved_bymember'];
	 					$approved_byadmin				=  $membernamelist[0]['approved_byadmin'];
	 					$membershipno				=  $membernamelist[0]['membershipno'];
	 					$memberstatus				=  $membernamelist[0]['memberstatus'];
	 					$year_1				=  $membernamelist[0]['year_1'];
	 					$receipt_1				=  $membernamelist[0]['receipt_1'];
	 					$date_1				=  date("d-m-Y",strtotime($membernamelist[0]['date_1']));
	 					$year_2				=  $membernamelist[0]['year_2'];
	 					$receipt_2				=  $membernamelist[0]['receipt_2'];
	 					$date_2				=  date("d-m-Y",strtotime($membernamelist[0]['date_2']));
	 					$year_3				=  $membernamelist[0]['year_3'];
	 					$receipt_3				=  $membernamelist[0]['receipt_3'];
	 					$date_3				=  date("d-m-Y",strtotime($membernamelist[0]['date_3']));
	 					$fob_last_1_year				=  $membernamelist[0]['fob_last_1_year'];
	 					$fob_last_2_year				=  $membernamelist[0]['fob_last_2_year'];
	 					$fob_last_3_year				=  $membernamelist[0]['fob_last_3_year'];
	 					$signature				=  $membernamelist[0]['signature'];
	 					$declaration_name				=  $membernamelist[0]['declaration_name'];
	 					$designation				=  $membernamelist[0]['designation'];
	 					$companeyseal				=  $membernamelist[0]['companeyseal'];
	 					$md_ceo_company				=  $membernamelist[0]['md_ceo_company'];
	 					$md_ceo_name				=  $membernamelist[0]['md_ceo_name'];
	 					$md_ceo_designation				=  $membernamelist[0]['md_ceo_designation'];
	 					$md_ceo_seal				=  $membernamelist[0]['md_ceo_seal'];
	 					$md_ceo_place				=  $membernamelist[0]['md_ceo_place'];
	 					$md_ceo_date				=  date("d-m-Y",strtotime($membernamelist[0]['md_ceo_date']));
	 					$terms_condition				=  $membernamelist[0]['terms_condition'];
						$reach_cnt_city				=  $membernamelist[0]['reach_cnt_city'];
						$reach_cnt_tel				=  $membernamelist[0]['reach_cnt_tel'];
						$reach_cnt_fax				=  $membernamelist[0]['reach_cnt_fax'];
						$region				=  $membernamelist[0]['region'];
						$statusreason				=  $membernamelist[0]['statusreason'];
						if($memberstatus=='0') 
						{
							$value="pending";
						}
						else 
						{
							$value="Completed";
						} 
  $sql2 = "SELECT * FROM reach_substancelicenseissue 
					  			where  applicationid= $applicationid order by issue_id ASC";
					  //die();
					  
						$stancelicenseissuelist		=	$member_obj->getApplication('',$sql2);
						for ($i=0; $i <count($stancelicenseissuelist) ; $i++) 
						{ 
							$issue_id				=  $stancelicenseissuelist[$i]['issue_id'];
	 						$substance_date			=  date("d-m-Y",strtotime($stancelicenseissuelist[$i]['substance_date']));
	 						$Issuing_authority		=  $stancelicenseissuelist[$i]['Issuing_authority'];
							$tr3 .="<tr id=$issue_id>
										<td><input type='checkbox' class='verify_text1 ' style='display:none;' name='id' rel='1' id='case8' data-emp-id=$issue_id></td>
										<td style='text-align: center;'><span id='snum8_'+i+''>".($i+1)."</span></td>
										<td><input type='hidden' value='$substance_date' name='textdate1[]' class='total_substancename1' id='textdate11_' >$substance_date</td>
										<td><input type='hidden' value='$Issuing_authority' name='textIssuing1[]' class='total_submissionno1' id='textIssuing11_' >$Issuing_authority</td>
									</tr>";
						}
						$sql3 = "SELECT * FROM reach_substancesdetails 
					  			where  applicationid= $applicationid order by substancesid ASC";
					  //die();
					  
						$substancesdetailslist		=	$member_obj->getApplication('',$sql3);
						for ($j=0; $j <count($substancesdetailslist) ; $j++) 
						{
		 					$substancesid				=  $substancesdetailslist[$j]['substancesid'];
		 					$substancename				=  $substancesdetailslist[$j]['substancename'];
		 					$substance_ecno				=  $substancesdetailslist[$j]['substance_ecno'];
		 					$submissionno				=  $substancesdetailslist[$j]['submissionno'];
		 					$tonnageband				=  $substancesdetailslist[$j]['tonnageband'];
		 					$echa_reg_date				=  date("d-m-Y",strtotime($substancesdetailslist[$j]['echa_reg_date']));
              $docmembershipimagepath        =  $substancesdetailslist[$j]['docmembershipimagepath'];
              $docexportcertimagepath        =  $substancesdetailslist[$j]['docexportcertimagepath'];
              $docissuedcertimagepath        =  $substancesdetailslist[$j]['docissuedcertimagepath'];
              $docPollutioncertimagepath       =  $substancesdetailslist[$j]['docPollutioncertimagepath'];

        
							$tr1 .="<tr id=$substancesid>
										<td><input type='checkbox' class='verify_text ' style='display:none;' name='id' id='case2' rel='1' data-emp-id=$substancesid></td>
										<td style='text-align: center;'><span id='snum2_'+i+''>".($j+1)."</span></td>
										<td><input type='hidden' value='$substancename' name='textsubstancess1[]' class='total_substancename1' id='txtsubstancenames11_' >$substancename</td>
										<td><input type='hidden' value='$substance_ecno'  class='total_substance_ecno1' name='txtsubstances1[]' id='txtsubstance_ecnos11_'>$substance_ecno</td>
										<td><input type='hidden' value='$submissionno' name='txtsubmissionnos1[]' class='total_submissionno1' id='txtsubmissionnos11_' >$submissionno</td>

                    <td><input type='hidden' value='$docmembershipimagepath' name='docmembershipimagepaths1[]' class='total_docmembershipimagepath1' id='txtdocmembershipimagepaths11_' ><a target='_blank' href ='".DISPLAY_DOC_FINAL."$docmembershipimagepath'><img src='".IMAGE_DIR."pdf-logo.jpg' id='uploadedimagesrc' style='width: 30px;''><br>$docmembershipimagepath</a></td>

                    <td><input type='hidden' value='$docexportcertimagepath' name='txtdocexportcertimagepaths1[]' class='total_docexportcertimagepath1' id='txtdocexportcertimagepath11_' ><a target='_blank' href ='".DISPLAY_DOC_FINAL."".$docexportcertimagepath."'><img src='".IMAGE_DIR."pdf-logo.jpg' id='uploadedimagesrc' style='width: 30px;''><br>$docexportcertimagepath</a></td>

                    <td><input type='hidden' value='$docissuedcertimagepath' name='txtdocissuedcertimagepaths1[]' class='total_docissuedcertimagepath1' id='txtdocissuedcertimagepaths11_' ><a target='_blank' href ='".DISPLAY_DOC_FINAL."".$docissuedcertimagepath."'><img src='".IMAGE_DIR."pdf-logo.jpg' id='uploadedimagesrc' style='width: 30px;''><br>$docissuedcertimagepath</a></td>

                    <td><input type='hidden' value='$docPollutioncertimagepath' name='txtdocPollutioncertimagepaths1[]' class='total_docPollutioncertimagepath1' id='txtdocPollutioncertimagepaths11_' ><a target='_blank' href ='".DISPLAY_DOC_FINAL."".$docPollutioncertimagepath."'><img src='".IMAGE_DIR."pdf-logo.jpg' id='uploadedimagesrc' style='width: 30px;''><br>$docPollutioncertimagepath</a></td>
									</tr>";
        
    
						}
						$sql4 = "SELECT * FROM reach_paymentdetails 
					  			where  applicationid= $applicationid order by paymentdetailsid ASC";
					  //die();
					  
						$paymentdetailslist		=	$member_obj->getApplication('',$sql4);
						for ($i=0; $i <count($paymentdetailslist) ; $i++) 
						{	
		 					$paymentdetailsid				=  $paymentdetailslist[$i]['paymentdetailsid'];
		 					$echa_fees				=  $paymentdetailslist[$i]['echa_fees'];
		 					$echa_exchange_rate				=  $paymentdetailslist[$i]['echa_exchange_rate'];
		 					$echa_amount_in_rs				=  $paymentdetailslist[$i]['echa_amount_in_rs'];
		 					$loa_fees				=  $paymentdetailslist[$i]['loa_fees'];
		 					$loa_exchange_rate				=  $paymentdetailslist[$i]['loa_exchange_rate'];
		 					$loa_amount_in_rs				=  $paymentdetailslist[$i]['loa_amount_in_rs'];
		 					$consultancy_fees				=  $paymentdetailslist[$i]['consultancy_fees'];
		 					$consultancy_exchange_rate				=  $paymentdetailslist[$i]['consultancy_exchange_rate'];
		 					$consultancy_amount_in_rs				=  $paymentdetailslist[$i]['consultancy_amount_in_rs'];

							$tr .="	<tr id=$paymentdetailsid>
										<td><input type='checkbox'  id='case1' rel='1' name='id'  style='display:none;' class='claim_text' data-emp-id=$paymentdetailsid></td>
										<td style='text-align: center;'><span id='snum1_'+i+''>".($i+1)."</span></td>
										<td><input type='hidden' value='$echa_fees' name='txtecha_feess1[]' class='total_echa_fees1' id='txtecha_feess11_' >$echa_fees</td>
										<td><input type='hidden' value='$echa_exchange_rate'  class='total_echa_exchange_rate1' name='txtecha_exchange_ratess1[]' id='txtecha_exchange_rates11_'>$echa_exchange_rate</td>
										<td><input type='hidden' value='$echa_amount_in_rs' name='txtecha_amount_in_rss1[]' class='total_echa_amount_in_rs1' id='txtecha_amount_in_rss11_' >$echa_amount_in_rs</td>
										<td><input type='hidden' value='$loa_fees' name='txtloa_feess1[]' class='total_loa_fees1' id='txtloa_feess11_' >$loa_fees</td>
										<td><input type='hidden' value='$loa_exchange_rate'  class='total_loa_exchange_rate1' name='txtloa_exchange_rates1[]' id='txtloa_exchange_rates11_'>$loa_exchange_rate</td>
										<td><input type='hidden' value='$loa_amount_in_rs' name='txtloa_amount_in_rss1[]' class='total_loa_amount_in_rs1' id='txtloa_amount_in_rss11_' >$loa_amount_in_rs</td>
										<td><input type='hidden' value='$consultancy_fees' name='txtconsultancy_feess1[]' class='total_consultancy_fees1' id='txtconsultancy_feess11_' >$consultancy_fees</td>
										<td><input type='hidden' value='$consultancy_exchange_rate'  class='total_consultancy_exchange_rate1' name='txtconsultancy_exchange_rates1[]' id='txtconsultancy_exchange_rates11_'>$consultancy_exchange_rate</td>
										<td><input type='hidden' value='$consultancy_amount_in_rs' name='txtconsultancy_amount_in_rss1[]' class='total_consultancy_amount_in_rs1' id='txtconsultancy_amount_in_rss11_' >$consultancy_amount_in_rs</td>
									</tr>";
        
    
						}
						
						$sql6 = "SELECT sum(echa_fees) as echa_fees_total,sum(echa_exchange_rate) as echa_exchange_rate_total,sum(echa_amount_in_rs) as echa_amount_in_rs_total,
										sum(loa_fees) as loa_fees_total,
										sum(loa_exchange_rate) as loa_exchange_rate_total,
										sum(loa_amount_in_rs) as loa_amount_in_rs_total,sum(consultancy_fees) as consultancy_fees_total,
										sum(consultancy_exchange_rate) as consultancy_exchange_rate_total,
										sum(consultancy_amount_in_rs) as consultancy_amount_in_rs_total
										FROM reach_paymentdetails 
										where  applicationid= $applicationid order by paymentdetailsid ASC";
					  //die();
					  
						$paymentdetailsTotallist		=	$member_obj->getApplication('',$sql6);
							$paymentdetailsid				=  $paymentdetailsTotallist[0]['paymentdetailsid'];
		 					$echa_fees_total				=  $paymentdetailsTotallist[0]['echa_fees_total'];
		 					$echa_exchange_rate_total				=  $paymentdetailsTotallist[0]['echa_exchange_rate_total'];
		 					$echa_amount_in_rs_total				=  $paymentdetailsTotallist[0]['echa_amount_in_rs_total'];
		 					$loa_fees_total				=  $paymentdetailsTotallist[0]['loa_fees_total'];
		 					$loa_exchange_rate_total				=  $paymentdetailsTotallist[0]['loa_exchange_rate_total'];
		 					$loa_amount_in_rs_total				=  $paymentdetailsTotallist[0]['loa_amount_in_rs_total'];
		 					$consultancy_fees_total				=  $paymentdetailsTotallist[0]['consultancy_fees_total'];
		 					$consultancy_exchange_rate_total				=  $paymentdetailsTotallist[0]['consultancy_exchange_rate_total'];
		 					$consultancy_amount_in_rs_total				=  $paymentdetailsTotallist[0]['consultancy_amount_in_rs_total'];
						$trpaymentdetailsTotal.="<tr>
													<td>Total</td>
													<td>".$echa_fees_total."</td>
													<td>".$echa_exchange_rate_total."</td>
													<td>".$echa_amount_in_rs_total."</td>
													<td>".$loa_fees_total."</td>
													<td>".$loa_exchange_rate_total."</td>
													<td>".$loa_amount_in_rs_total."</td>
													<td>".$consultancy_fees_total."</td>
													<td>".$consultancy_exchange_rate_total."</td>
													<td>".$consultancy_amount_in_rs_total."</td>
												</tr>";

//if($memberstatus == '0') {
      
        
        $headform0 = "'reg_headoffice00'";
        $sendurl    = "'membership_submit.php'";
        
        
        $edit_option_grid = '<a href="#" class="person_edit1 person_span1" rel="'.$applicationid.'" id="person_edit1" onclick="return false;">EDIT</a>
                      <a href="#" class="person_cancel1 person_text1" rel="'.$applicationid.'" id="person_cancel1"  onclick="return false;" style="display:none;">CANCEL</a>
                      <a href="#" class="person_save1 person_text1" rel="'.$applicationid.'" id="person_save1" onclick="formAjax('.$headform0.','.$sendurl.'); return false;" style="display:none;">SAVE</a>';                        

        

    
        $headform4  = "'reg_headoffice2'";
        $filename4 = "'application_submit5.php'";
  
        $editable_grid4 = '<a href="#" class="claim_edit claim_span" rel="'.$applicationid.'" id="claim_edit" onclick="return false;">EDIT</a>
                     <a href="#" class="claim_cancel claim_text" rel="'.$applicationid.'" id="claim_cancel" onclick="return false;" style="display:none;">CANCEL</a>
                     <a href="#" class="claim_save claim_text" rel="'.$applicationid.'" id="claim_save" onclick="formAjax('.$headform4.','.$filename4.'); return false;" style="display:none;">SAVE</a>';


        $headform5 = "'reg_headoffice3'";
        $filename5 = "'application_submit4.php'";

        $editable_grid5 = '<a href="#" class="verify_edit verify_span" rel="'.$applicationid.'" id="verify_edit" onclick="return false;">EDIT</a>
                     <a href="#" class="verify_cancel verify_text" rel="'.$applicationid.'" id="verify_cancel" onclick="return false;" style="display:none;">CANCEL</a>
                     <a href="#" class="verify_save verify_text" rel="'.$applicationid.'" id="verify_save" onclick="formAjax('.$headform5.','.$filename5.'); return false;" style="display:none;">SAVE</a>';
            
          $headform8 = "'reg_headoffice8'";
        $filename8 = "'application_submit3.php'";

        $editable_grid8 = '<a href="#" class="verify_edit1 verify_span1" rel="'.$applicationid.'" id="verify_edit1" onclick="return false;">EDIT</a>
                     <a href="#" class="verify_cancel1 verify_text1" rel="'.$applicationid.'" id="verify_cancel1" onclick="return false;" style="display:none;">CANCEL</a>
                     <a href="#" class="verify_save1 verify_text1" rel="'.$applicationid.'" id="verify_save1" onclick="formAjax('.$headform8.','.$filename8.'); return false;" style="display:none;">SAVE</a>';
    
        
//}

$applicationlist = '';  
if($applicationid != '')
{
      $applicationlist .= '   
      
      
        <div id="person_details">  
        <div class="col-lg-12">
            <div class="panel panel-info">
                <div class="panel-heading">
                Person Details
                </div>

                  <div class="panel-body">
                    <form  id="reg_headoffice00">
                        <input type="hidden" id="txteditmembershipno" name="txteditmembershipno"  value="'.$membershipno.'">
                        <input type="hidden" id="txtmemberid" name="txtmemberid"  value="'.$memberid.'" >
                        <input type="hidden" id="txtapplicationid" name="txtapplicationid"  value="'.$applicationid.'">
                      <input type="hidden" id="entered_export_count" name="entered_export_count" value="0">
                      <table width="95%"   class="table table-bordered">
                        <tr>
                          <td width="7%">1</td>
                          <td colspan="2" width="35%">Name of the Applicant Firm : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$reach_cnt_person.'</div>
                                  <input type="text" name="txtmembername" value="'.$reach_cnt_person.'"  readonly="" required=""  class="form-control person_text1" style="display:none;">
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">2</td>
                          <td colspan="2" width="35%">Address of the Applicant Firm Line 1 : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$reach_cnt_address1.'</div>
                                  <input type="text" name="txtaddress1" value="'.$reach_cnt_address1.'"   required=""  class="form-control person_text1" style="display:none;">
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">3</td>
                          <td colspan="2" width="35%">Address of the Applicant Firm Line 2 : </td>
                          <td colspan="3">
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$reach_cnt_address2.'</div>
                                  <input type="text" name="txtaddress2" value="'.$reach_cnt_address2.'"   class="form-control person_text1" style="display:none;">
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">4</td>
                          <td colspan="2" width="35%">Region of the Applicant Firm : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$region.'</div>
                                  <input type="text" name="txtregion" value="'.$region.'"  readonly="" required=""  class="form-control person_text1" style="display:none;">
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">5</td>
                          <td colspan="2" width="35%">State of the Applicant Firm : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$reach_cnt_statename.'</div>
                                  <input type="text" name="txtstate" value="'.$reach_cnt_statename.'"   required=""  class="form-control person_text1" style="display:none;">
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">6</td>
                          <td colspan="2" width="35%">City of the Applicant Firm : </td>
                          <td colspan="3">
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$reach_cnt_city.'</div>
                                   <input type="text" name="txtcity" value="'.$reach_cnt_city.'"   required=""  class="form-control person_text1" style="display:none;">
                                </div>
                              </td>
                        </tr>
                        <tr>
                          <td width="7%">7</td>
                          <td colspan="2" width="35%">Postcode of the Applicant Firm : </td>
                          <td colspan="3">
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$reach_cnt_pincode.'</div>
                                  <input type="text" name="txtpin" value="'.$reach_cnt_pincode.'"   required=""  class="form-control person_text1" style="display:none;">
                                 </div>
                              </td>
                        </tr>
  
                        <tr>
                          <td width="7%">8</td>
                          <td colspan="2" width="35%">Tel: (with STD Code) : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$reach_cnt_tel.'</div>
                                  <input type="text" name="txttel" value="'.$reach_cnt_tel.'"      required="" class="form-control person_text1" style="display:none;" >
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">9</td>
                          <td colspan="2" width="35%">Fax: (with STD Code) : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$reach_cnt_fax.'</div>
                                  <input type="text" name="txtfax" value="'.$reach_cnt_fax.'"    required="" class="form-control person_text1" style="display:none;" >
                              </div>
                            </td>
                        </tr>
						<tr>
                          <td width="7%">10</td>
                          <td colspan="2" width="35%">GST No : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$reach_cnt_gstno.'</div>
                                  <input type="text" name="txtgstno" value="'.$reach_cnt_gstno.'"    required="" class="form-control person_text1" style="display:none;" >
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">11</td>
                          <td colspan="2" width="35%">Mobile No : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$reach_cnt_contactno.'</div>
                                  <input type="text" name="txtmobileno" value="'.$reach_cnt_contactno.'"  required=""  class="form-control person_text1" style="display:none;">
                                </div>
                          </td>
                        </tr>
                        <tr>
                          <td width="7%">12</td>
                          <td colspan="2" width="35%">E-mail :</td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$reach_cnt_email.'</div>
                                  <input type="text" name="txtemail" value="'.$reach_cnt_email.'"   required=""  class="form-control person_text1" style="display:none;">
                              </div>
                            </td>
                        </tr>
                      <!--<tr>
                        <td width="7%">13</td>
                        <td colspan="2" width="35%">Website : </td>
                        <td colspan="3"> 
                            <div class="col-lg-15">
                                <div class="person_span1">'.$website.'</div>
                                <input type="text" name="txtwebsite" value="'.$website.'"   required="" class="form-control person_text1" style="display:none;">
                            </div>
                          </td>
                      </tr>-->
  
                      <tr>
                        <td width="7%">14</td>
                        <td colspan="2" width="35%">Name of contact person : </td>
                        <td colspan="3"> 
                            <div class="col-lg-15">
                                <div class="person_span1">'.$reach_cnt_person.'</div>
                                <input type="text" name="txtcntname" value="'.$reach_cnt_person.'"  required="" class="form-control person_text1" style="display:none;">
                              </div>
                          </td>
                      </tr>
                      <tr>
                        <td width="7%">15</td>
                        <td colspan="2" width="35%">Designation of contact person :</td>
                        <td colspan="3"> 
                            <div class="col-lg-15">
                                <div class="person_span1">'.$reach_cnt_designation.'</div>
                                <input type="text" name="txtcntdes" value="'.$reach_cnt_designation.'"   required="" class="form-control person_text1" style="display:none;">
                            </div>
                          </td>
                      </tr>
                      <tr>
                        <td width="7%">16</td>
                        <td colspan="2" width="35%">IEC No. of the firm. :</td>
                        <td colspan="3"> 
                            <div class="col-lg-15">
                                <div class="person_span1">'.$reach_cnt_iecno.'</div>
                                <input type="text" name="txtiec" value="'.$reach_cnt_iecno.'"   readonly="" required="" class="form-control person_text1" style="display:none;">
                            </div>
                          </td>
                      </tr>
                      <tr>
                        <td width="7%">16</td>
                        <td colspan="2" width="35%">Customer ID (UUID) as per ECHA Invoice :</td>
                        <td colspan="3"> 
                            <div class="col-lg-15">
                                <div class="person_span1">'.$customer_id.'</div>
                                <input type="text" name="txtcid" value="'.$customer_id.'"    required="" class="form-control person_text1" style="display:none;">
                            </div>
                          </td>
                      </tr>
        
                      <tr>
                        <td width="7%">17</td>
                        <td colspan="2" width="35%">Chemexcil Membership Code :</td>
                        <td colspan="3">
                            <div class="col-lg-15">
                                <div class="person_span1">'.$membershipno.'</div>
                                <input type="text" name="txtmembershipcode" value="'.$membershipno.'" readonly="" required=""  class="form-control person_text1" style="display:none;">
                            </div>
                          </td>
                      </tr>
                      <tr>
                        <td width="7%">18</td>
                        <td colspan="2" width="35%">Whether ( LSM/ MSM/ SSM/ MICRO SM)                                             : </td>    
                        <td colspan="3">
                            <div class="col-lg-15">
                                <div class="person_span1">'.$company_category.'</div>
                                <input type="text" name="txtwhether" value="'.$company_category.'"  readonly="" required="" class="form-control person_text1" style="display:none;">              
                            </div>
                        </td>
                      </tr>
                      <tr>
                        <td width="7%">19</td>
                        <td colspan="2" width="35%">  Status of Membership subscription fees paid for 3 years:
                        <div >'.$year_1.'</div>
                        <input type="hidden"  name="textyear1"  readonly=""  value="'.$year_1.'" class="form-control person_text1" style="display:none;">
                          </div>
                          <div>'.$year_2.'</div>
                          <input type="hidden"  name="textyear2"  readonly=""  value="'.$year_2.'" class="form-control person_text1"  style="display:none;">
                          </div>
                          <div>'.$year_3.'</div>
                          <input type="hidden"  name="textyear3"  readonly=""  value="'.$year_3.'" class="form-control person_text1"  style="display:none;">
                          </div>
                          </td>
                        <td colspan="3">
                        <div class="col-lg-4">
                            <label>Receipt  No.</label>
                            <div class="person_span1">'.$receipt_1.'</div>
                            <input type="text"  name="textfees1"   value="'.$receipt_1.'"   class="form-control person_text1" style="display:none;">
                            <div class="person_span1">'.$receipt_2.'</div>
                            <input type="text" name="textfees2"  value="'.$receipt_2.'"   class="form-control person_text1" style="display:none;" >
                            <div class="person_span1">'.$receipt_3.'</div>
                            <input type="text" name="textfees3"   value="'.$receipt_3.'"    class="form-control person_text1" style="display:none;" >
                          </div>
                          <div class="col-lg-4">
                            <label>Date:</label>
                            <div class="person_span1">'.$date_1.'</div>
                              <input type="text" id="txtappdate12" name="txtappdate" required="" value="'.$date_1.'"   class="form-control person_text1" style="display:none;">
                              <div class="person_span1">'.$date_2.'</div>
                              <input type="text" id="txtappdate11" name="txtappdate1" required="" value="'.$date_2.'"  class="form-control person_text1" style="display:none;">
                              <div class="person_span1">'.$date_3.'</div>
                            <input type="text" id="txtappdate21" name="txtappdate2" required="" value="'.$date_3.'"   class="form-control person_text1" style="display:none;" >
                          </div>
                      </tr>
                      <tr>
                        <td width="7%">20</td>
                        <td colspan="2" width="35%">Export House Certificate, if applicable :</td>
                        <td colspan="4">
                          <div class="form-group col-lg-4">
                                 Certificate No :
                                      <div class="person_span1">'.$export_house_no.'</div>  
                                  <input type="text" id="txtcertificateno" name="txtcertificateno"  value="'.$export_house_no.'" class="form-control person_text1" style="display:none;"   placeholder="" >
                          </div>
						  <div class="form-group col-lg-4">                         
                              Issue Date :
                            <div class="person_span1">'.$export_house_issueddate.'</div>
                            <input type="text" name="txtcertificateissueddate"  value="'.$export_house_issueddate.'"  class="form-control getdate person_text1" style="display:none;"   placeholder="" >
                          </div>
                          <div class="form-group col-lg-4">                         
                              Valid Upto :
                            <div class="person_span1">'.$export_house_validuptodate.'</div>
                            <input type="text" id="txtcertificatevalidupto1" name="txtcertificatevalidupto"  value="'.$export_house_validuptodate.'"  class="form-control person_text1" style="display:none;"   placeholder="" >
                          </div>
                      </tr>

                      <tr><td width="7%">21</td>
                        <td colspan="2" width="35%"> FOB value of exports during the last 3 financial year:</td>
                        <td colspan="3">
                                            
                            <div class="col-lg-4">
                                <label>Last 1 Year ('.$year_1.'):</label>
                                <div class="person_span1">'.$fob_last_1_year.'</div>
                                <input type="text" id="txtfob_enter11" name="txtfob_enter11"  onkeypress="return isNumberKey(event,this.id)" value="'.$fob_last_1_year.'" class="form-control person_text1"  style="display:none;">                   
                              </div>
                              <div class="col-lg-4">
                                <label>Last 2 Year ('.$year_2.'):</label>
                                <div class="person_span1">'.$fob_last_2_year.'</div>
                              <input type="text" id="txtfob_enter21" name="txtfob_enter21" onkeypress="return isNumberKey(event,this.id)" value="'.$fob_last_2_year.'" class="form-control person_text1"  style="display:none;">
                              </div>
                            <div class="col-lg-4">
                                <label>Last 3 Year ('.$year_3.'):</label>
                                <div class="person_span1">'.$fob_last_3_year.'</div>
                              <input type="text" id="txtfob_enter31" name="txtfob_enter31" onkeypress="return isNumberKey(event,this.id)" value="'.$fob_last_3_year.'" class="form-control person_text1" style="display:none;">
                              </div>
                      
                      </tr>
                          <tr><td width="7%">22</td>
                            <td colspan="2" width="35%">Status </td>
                            <td colspan="3">
                                <div class="row col-lg-6 person_text1" style="display:none;">
                            
                                  <label class="radio-inline"><input type="radio" name="memberstatus" class="memberstatus1"  '.(($memberstatus =='0')?'checked':'').' value="0" >Panding</label>
                                  <label class="radio-inline"><input type="radio" name="memberstatus" class="memberstatus1" '.(($memberstatus =='1')?'checked':'').' value="1">Completed</label>  
                                </div>
                            
                                <div class="row col-lg-6 statusreason1 person_text1" style="display:none;">
                                  <input type="text" id="statusreason" name="statusreason" class="form-control statusreasons person_text1" style="display:none;" value="'.$statusreason.'"   placeholder="Type a reason here" /> <br> <label class="text text-danger">Please mentioned the reason for pending member only.</label>
  
                                </div>  
                                <div class="row col-lg-6 statusreason2 person_text1" style="display:none;">
                                </div>
                                  
                              <div class="statusreason person_span1" id="statusreason1"><div class="col-lg-2">Status:</div>'.$value.'<br><div class="col-lg-2">Reasons:</div>'.$statusreason.'</div>
                            </td>
                          </tr>

                    </table>
                  </form>'.$edit_option_grid.'
                </div>
              </div>
            </div>
            </div>
            
            <div id="substance_license">  
            <div class="col-lg-12">
                <div class="panel panel-info">
                  <div class="panel-heading">
                      Details of manufacturing license issued by the Licensing Authority (in India) for the substance(to be enclosed ) 
                  </div>
                  <div class="panel-body">
                    <form id="reg_headoffice8">
                    <input type="hidden" id="txteditmembershipno" name="txteditmembershipno"  value="'.$membershipno.'">
                        <input type="hidden" id="txtmemberid" name="txtmemberid"  value="'.$memberid.'" >
                        <input type="hidden" id="txtapplicationid" name="txtapplicationid"  value="'.$applicationid.'">
                        <input type="hidden" id="entered_export_count8" name="entered_export_count" value="'.$k.'"> 
                        <p class="verify_text1" style="display:none;">            
                        <!--<button type="button" class="btn btn-primary pull-left"   onclick="updateFormc();"/>Add Entry</button>-->
                         <input type="button" class="btn btn-primary pull-left"   onclick="updateFormc();" value="Add Entry">
                        </p>
                        <br>
                        <br>
                        <table width="95%"  id="results8" class="table table-bordered">
                          <tr>
                            <th><input id="check_alls" class="verify_text1" style="display:none;"   type="checkbox" onclick="select_all8()"/></th>
                            <th>No.</th><td> Date</td>
                            <th>Issuing authority</th>
                          </tr>
                    
                          <tr>
                            <td width="5%"></td>
                            <td></td>
                            <td><input type="text" id="textdate1" value="" class="form-control input-md verify_text1" style="display:none;"></td>
                            <td><input type="text" id="textIssuing1" value="" class="form-control input-md verify_text1" style="display:none;"></td>
                          </tr>
                      
                          '.$tr3.'
                          <tr>
                          <!--  <td style="display: none;"><div id="fob4"></div></td>-->
                            <td style="display: none;"><div id="Date  "></div></td>
                            <td style="display: none;"><div id="Issuing"></div></td>
                          </tr>
                        </table>
                        <br>
                        <button class="btn btn-primary pull-left verify_text1" style="display:none;"  type="button" id="deleteAcc8">Delete</button>
                        <br>
                        <br>
                        <br>
                    </form>'.$editable_grid8.'
                </div>                    
              </div>
            </div>  
            </div>
              
              <div id="substance_details">  
               <div class="col-lg-12">
                <div class="panel panel-info">
                  <div class="panel-heading">
                      Details of the substances registered by  your firm 
                  </div>
                  <div class="panel-body">
                    <form id="reg_headoffice3">
                    <input type="hidden" id="txteditmembershipno" name="txteditmembershipno"  value="'.$membershipno.'">
                        <input type="hidden" id="txtmemberid" name="txtmemberid"  value="'.$memberid.'" >
                        <input type="hidden" id="txtapplicationid" name="txtapplicationid"  value="'.$applicationid.'">
                        <input type="hidden" id="entered_export_count2" name="entered_export_count" value="'.$j.'">   
                        <p class="verify_text" style="display:none;">          
                        <!--<button type="button" class="btn btn-primary pull-left"   onclick="updateFormsa();"/>Add Entry</button>-->
                        <input type="button" class="btn btn-primary pull-left"   onclick="updateFormsa();" value="Add Entry">

                        </p>
                        <br>
                        <br>
                        <table width="95%"  id="results2" class="table table-bordered">
                          <tr>
                            <th><input id="check_all2"  class="verify_text " style="display:none;"  type="checkbox" onclick="select_all2()"/></th>
                                <th>Sr. No.</th>
                                <th> Substance Name</th>
                                <th>EC No.</th>
                                <th> Submission No.</th>
                                <th>Chemexcil Membership Certificate – RCMC</th>
                                <th>Export House certificate, if applicable</th>
                                <th> Manufacturing license for the substance issued by the Licensing Authority (in India) - SIA, Entrepreneurs Memorandum, Udyog Adhaar, Udyam Registration </th>
                                <th>State Pollution Control Board license</th>
                          </tr>
                          <tr>  
                            <td width="7%"></td>
                            <td></td>
                            <td><input type="text" id="textsubstancess1" value="" class="form-control input-md verify_text"  style="display:none;"></td>
                          
                            
                          
                            <td><input type="text" id="textecnos1" value="" onkeypress="return isNumberKey(event,this.id)" class="form-control input-md verify_text" style="display:none;"></td>
                    
                        
                          
                            <td><input type="text"  id="textsubminos1" value="" onkeypress="return isNumberKey(event,this.id)" class="form-control input-md verify_text"  style="display:none;"></td>
                                
                              <td>
                                <div class="form-group">
                                  <div id="uploadedmembershipimages">
                                        
                                  </div>
                                  <!--<input name="docimagepath[]" id="docimagepath" type="hidden" value="" required>-->
                                  <input id="txtdocmembershipimagepath" type="text" value="" class="form-control input-md verify_text" style="display:none;">
                                  <input type="file" class="form-control btn btn-default input-md verify_text" name="uploadmembershipdoc" id="uploadmembershipdoc" style="display:none;">
                                </div>
                              </td> 

                              <td>
                                <div class="form-group">
                                  <div id="uploadedexportcertimages">
                                        
                                  </div>
                                  <!--<input name="docimagepath[]" id="docimagepath" type="hidden" value="" required>-->
                                  <input id="txtdocexportcertimagepath" type="text" value=""  class="form-control input-md verify_text" style="display:none;" >
                                  <input type="file" class="form-control btn btn-default input-md verify_text" name="uploadexportcertdoc" id="uploadexportcertdoc" style="display:none;">
                                </div>
                              </td>

                              <td>
                                <div class="form-group">
                                  <div id="uploadedissuedcertimages">
                                        
                                  </div>
                                  <!--<input name="docimagepath[]" id="docimagepath" type="hidden" value="" required>-->
                                  <input id="txtdocissuedcertimagepath" type="text" value=""  class="form-control input-md verify_text" style="display:none;">
                                  <input type="file" class="form-control btn btn-default input-md verify_text" name="uploadissuedcertdoc" id="uploadissuedcertdoc" style="display:none;">
                                </div>
                              </td>

                              <td>
                                <div class="form-group">
                                  <div id="uploadedPollutioncertimages">
                                        
                                  </div>
                                  <!--<input name="docimagepath[]" id="docimagepath" type="hidden" value="" required>-->
                                  <input id="txtdocPollutioncertimagepath" type="text" value="" class="form-control input-md verify_text" style="display:none;" >
                                  <input type="file" class="form-control btn btn-default input-md verify_text" name="uploadPollutioncertdoc" id="uploadPollutioncertdoc" style="display:none;">
                                </div>
                              </td>  
                            
                          </tr>'.$tr1.'
                         <tr>
                          <!--  <td style="display: none;"><div id="fob4"></div></td>-->
                            <td style="display: none;"><div id="substances1"></div></td>
                            <td style="display: none;"><div id="ecno1"></div></td>
                            <td style="display: none;"><div id="submino1"></div></td>
                            <td style="display: none;"><div id="submino1"></div></td>
                            <td style="display: none;"><div id="submino1"></div></td>
                            <td style="display: none;"><div id="submino1"></div></td>
                            <td style="display: none;"><div id="submino1"></div></td>
                          </tr>
                        </table>
                        <br>
                        <button class="btn btn-primary pull-left verify_text " style="display:none;"  type="button" id="deleteAcc2">Delete</button>
                        <br>
                        <br>
                        <br>
                    </form>'.$editable_grid5.'
                </div>                    
              </div>
            </div>
            </div>

            <div id="payment_details">  
            <div class="col-lg-12">
              <div class="panel panel-info">
                  <div class="panel-heading">
                  Details of Registration fees paid by your firm to ECHA
                  </div>
                  <div class="panel-body">
                  <form id="reg_headoffice2">
                  <input type="hidden" id="txteditmembershipno" name="txteditmembershipno"  value="'.$membershipno.'">
                        <input type="hidden" id="txtmemberid" name="txtmemberid"  value="'.$memberid.'" >
                        <input type="hidden" id="txtapplicationid" name="txtapplicationid"  value="'.$applicationid.'">
                      <input type="hidden" id="entered_export_count1" name="entered_export_count" value="'.$i.'">           
                      <p class="claim_text1" style="display:none;">
                      <!--<button type="button" class="btn btn-primary pull-left"   onClick="updateForms();"/>Add Entry</button>-->
                      <input type="button" class="btn btn-primary pull-left"   onclick="updateForms();" value="Add Entry">
                      </p>
                      <br>
                      <br>
                      <table width="95%"  id="results1" class="table table-bordered">
                        <tr>
                          <th><input id="check_all1"  class="claim_text " style="display:none;"  type="checkbox" onclick="select_all1()"/></th>
                          <th>Sr. No.</th>
                        <!--  <td> Substance Name</td>-->
                          <td>ECHA Regn fees paid in Euro as per ECHA Invoice   </td>
                          <td> Exchange Rate as per Bank Transaction copies </td>
                          <td> (Amount in Rs ) </td>
                          <td>LOA Fees as per LR Invoice or Data fees as per Lab invoice   </td>
                          <td> Exchange Rate as per Bank Transaction copies  </td>
                          <td>(Amount in Rs )</td>
                          <td>Consultancy charges as per consultant’s invoice</td>
                          <td> Exchange Rate as per Bank Transaction copies  </td>
                          <td> (Amount in Rs )</td>
                        </tr>
                        <tr>
                          <td width="7%"></td><td></td>
                        <!--  <td><input type="text"  id="txtfob_enter4" value="" class="form-control input-md " ></td>-->
                    
                          <td><input type="text" id="txtecha_fees1" value="" class="form-control input-md claim_text " onkeypress="return isNumberKey(event,this.id)" onInput="echaamount()" style="display:none;"></td>
                        
                          <td><input type="text"  id="txtecha_exchange_rate1" value="" class="form-control input-md claim_text" onkeypress="return isNumberKey(event,this.id)" onInput="echaamount()" style="display:none;"></td>
                        
                          <td><input type="text" id="txtecha_amount_in_rs1" readonly="" onkeypress="return isNumberKey(event,this.id)" value="" class="form-control input-md claim_text" style="display:none;"></td>
                  
                          <td><input type="text" id="txtloa_fees1" value="" onkeypress="return isNumberKey(event,this.id)" class="form-control input-md claim_text" onInput="loaamount()" style="display:none;"></td>
                        
                          <td><input type="text"  id="txtloa_exchange_rate1" value="" class="form-control input-md claim_text" onkeypress="return isNumberKey(event,this.id)" onInput="loaamount()" style="display:none;"></td>
                      
                          <td><input type="text" id="txtloa_amount_in_rs1" value="" class="form-control input-md claim_text" readonly="" onkeypress="return isNumberKey(event,this.id)" style="display:none;"></td>
                  
                          <td><input type="text" id="txtconsultancy_fees1" value="" class="form-control input-md claim_text" onkeypress="return isNumberKey(event,this.id)" onInput="consultancyamount()" style="display:none;"></td>
                      
                          <td><input type="text"  id="txtconsultancy_exchange_rate1" value="" class="form-control input-md claim_text" onkeypress="return isNumberKey(event,this.id)" onInput="consultancyamount()" style="display:none;"></td>
                    
                          <td><input type="text" id="txtconsultancy_amount_in_rs1" readonly="" value="" class="form-control input-md claim_text" onkeypress="return isNumberKey(event,this.id)" style="display:none;"></td>
                        </tr>'.$tr.'
                        <tr>
                        <!--  <td style="display: none;"><div id="fob4"></div></td>-->
                          <td style="display: none;"><div id="echa_fees1"></div></td>
                          <td style="display: none;"><div id="echa_exchange_rate1"></div></td>
                          <td style="display: none;"><div id="echa_amount_in_rs1"></div></td>
                          <td style="display: none;"><div id="loa_fees1"></div></td>
                          <td style="display: none;"><div id="loa_exchange_rate1"></div></td>
                          <td style="display: none;"><div id="loa_amount_in_rs1"></div></td>
                          <td style="display: none;"><div id="consultancy_fees1"></div></td>
                          <td style="display: none;"><div id="consultancy_exchange_rate1"></div></td>
                          <td style="display: none;"><div id="consultancy_amount_in_rs1"></div></td>
                  
                        </tr>
                      </table>
                      <table  width="95%"   class="table table-bordered">
                        
                        <tr>
                          
                          <td width="10%">TOTAL</td>
                          
                  
                        
                          <!--<td><div id="totalfob4"></div></td>-->
                          <td><input type="hidden" id="echa_fees_total1" name="echa_fees_total"><div id="total_echa_fees1" >'.$echa_fees_total.'</div></td>
                          <td><input type="hidden" id="echa_exchange_rate_total1" name="echa_exchange_rate_total"><div id="total_echa_exchange_rate1">'.$echa_exchange_rate_total.'</div></td>
                          <td><input type="hidden" id="echa_amount_in_rs_total1" name="echa_amount_in_rs_total"><div id="total_echa_amount_in_rs1">'.$echa_amount_in_rs_total.'</div></td>
                          <td><input type="hidden" id="loa_fees_total1" name="loa_fees_total1"><div id="total_loa_fees1">'.$loa_fees_total.'</div></td>
                          <td><input type="hidden" id="loa_exchange_rate_total1" name="loa_exchange_rate_total"><div id="total_loa_exchange_rate1">'.$loa_exchange_rate_total.'</div></td>
                          <td><input type="hidden" id="loa_amount_in_rs_total1" name="loa_amount_in_rs_total"><div id="total_loa_amount_in_rs1">'.$loa_amount_in_rs_total.'</div></td>
                          <td><input type="hidden" id="consultancy_fees_total1" name="consultancy_fees_total"><div id="total_consultancy_fees1">'.$consultancy_fees_total.'</div></td>
                          <td><input type="hidden" id="consultancy_exchange_rate_total1" name="consultancy_exchange_rate_total"><div id="total_consultancy_exchange_rate1">'.$consultancy_exchange_rate_total.'</div></td>
                          <td><input type="hidden" id="consultancy_amount_in_rs_total1" name="consultancy_amount_in_rs_total"><div id="total_consultancy_amount_in_rs1">'.$consultancy_amount_in_rs_total.'</div></td>
                        
                        </tr>
                    
                  
                        </table>
                        <br>
                        <button class="btn btn-primary pull-left claim_text " style="display:none;"  type="button" id="deleteAcc1">Delete</button>
                        <br>
                        <br>
                        <br>
                    </form>'.$editable_grid4.'
                  </div>  
                  </div>        
              </div>
              </div>';
}       
  return $applicationlist;

    
} 
*/


function MemberApplicationDisplay($membershipno,$applicationid='')
{
  $member_obj       = new Application();
  $member_obj1      =   new Application5(); 
    $member_obj2      =   new Application2(); 
        $member_obj3      =   new Application4();
  if($applicationid !='')
  {
      $where = "and a.applicationid = '".$applicationid."'";
  }
  /*$sql = "SELECT  a.memberid,a.applicationid,a.membershipno,a.reach_cnt_address1,a.reach_cnt_address2,a.reach_cnt_email,a.reach_cnt_statename,a.reach_cnt_pincode,
                  a.reach_companyname,a.reach_cnt_person,a.reach_cnt_designation,a.reach_cnt_iecno,a.export_house_no,a.export_house_validuptodate,
                  a.company_category, a.receipt_1,a.receipt_2,a.receipt_3,a.date_1,a.date_2,a.date_3,
                  c.substancename,c.substance_ecno,c.submissionno,c.echa_reg_date,c.tonnageband,
                    f.echa_fees,f.echa_amount_in_rs,f.loa_fees,f.loa_amount_in_rs,f.consultancy_fees,f.consultancy_amount_in_rs
                FROM `reach_trnapplication` a
                INNER join mstmember b on a.membershipno=b.MembershipNo
                INNER JOIN reach_substancesdetails c ON a.applicationid = c.applicationid
            
                  where a.membershipno = '".$membershipno."' $where order by a.applicationid desc limit 0,1";*/
                  
                  $sql = "SELECT * FROM `reach_trnapplication` a
                left join mstmember b on a.membershipno=b.MembershipNo
                left JOIN reach_substancesdetails c ON a.applicationid = c.applicationid
            
                  where a.membershipno = '".$membershipno."' $where order by a.applicationid desc limit 0,1";
  
    
    //echo $sql;   
    $applist       =  $member_obj->getApplication('',$sql);
    
    
    $memberid       =  $applist[0]['memberid'];

    $membershipno       =  $applist[0]['membershipno'];
     $edit_applicationid      =  $applist[0]['applicationid'];
    $MemberName       = $applist[0]['reach_companyname'];
    $address1         = $applist[0]['reach_cnt_address1'];
    $address2         = $applist[0]['reach_cnt_address2'];
    $email          = $applist[0]['reach_cnt_email'];
    $mobile              = $applist[0]['reach_cnt_contactno'];
    $contactperson_name=$applist[0]['reach_cnt_person'];
    $contactperson_designation=$applist[0]['reach_cnt_designation'];
    $iec              = $applist[0]['reach_cnt_iecno'];
    $export_house_no=$applist[0]['export_house_no'];
    $export_house_validuptodate=$applist[0]['export_house_validuptodate'];
    $category_name              = $applist[0]['company_category'];  
    $pin=$applist[0]['reach_cnt_pincode'];
    $state=$applist[0]['reach_cnt_statename'];
    $receipt_1      =  $applist[0]['receipt_1'];
    $date_1       =  $applist[0]['date_1'];
    $receipt_2      =  $applist[0]['receipt_2'];
    $date_2       =  $applist[0]['date_2'];
    $receipt_3      =  $applist[0]['receipt_3'];
    $date_3       =  $applist[0]['date_3'];
    $year_1        =  $applist[0]['year_1'];
    $year_2        =  $applist[0]['year_2'];
    $year_3        =  $applist[0]['year_3'];
    $fob_last_1_year       =  $applist[0]['fob_last_1_year'];
    $fob_last_2_year       =  $applist[0]['fob_last_2_year'];
    $fob_last_3_year       =  $applist[0]['fob_last_3_year'];
    $memberstatus=$applist[0]['memberstatus'];
  
  
      if($memberstatus=='0') 
      {
          $value="panding";
      }
      else 
      {
        $value="Completed";
      } 
      

    $statusreason=$applist[0]['statusreason'];
$sql3="select * from reach_substancelicenseissue t where t.applicationid= $edit_applicationid";
    //echo $sql3;   
  $applist3    =  $member_obj3->getApplication4('',$sql3);
  //  echo "<pre>";
  //  print_r($applist3);
    
    
    for($k=0;$k<count($applist3);$k++)
    {

        $issue_id   = $applist3[$k]['issue_id'];
      //  print_r($issue_id);
           $applicationid     =  $edit_applicationid;
        $substance_date       = $applist3[$k]['substance_date'];
      
          $Issuing_authority  = $applist3[$k]['Issuing_authority'];
        
        $tr3 .="<tr id=$issue_id>
                <td><input type='checkbox' class='verify_text1 ' style='display:none;' name='id' rel='1' id='case8' data-emp-id=$issue_id></td>
                 <td style='text-align: center;'><span id='snum8_'+i+''>".($k+1)."</span></td>
                <td><input type='hidden' value='$substance_date' name='textdate1[]' class='total_substancename1' id='textdate11_' >$substance_date</td>
              
                <td><input type='hidden' value='$Issuing_authority' name='textIssuing1[]' class='total_submissionno1' id='textIssuing11_' >$Issuing_authority</td>
                  </tr>";
        
    
    }

  $sql2="select * from reach_substancesdetails h where h.applicationid= $applicationid";
  //  echo $sql2;   
  $applist2      =  $member_obj2->getApplication2('',$sql2);
    //echo "<pre>";
    //print_r($applist1);
    
    
    for($j=0;$j<count($applist2);$j++)
    {

        $substancesid   = $applist2[$j]['substancesid'];
           $applicationid     =  $edit_applicationid;
        $substancename        = $applist2[$j]['substancename'];
        $substance_ecno = $applist2[$j]['substance_ecno'];
        $submissionno = $applist2[$j]['submissionno'];
        
        
        $tr1 .="<tr id=$substancesid>
                <td><input type='checkbox' class='verify_text ' style='display:none;' name='id' id='case2' rel='1' data-emp-id=$substancesid></td>
                 <td style='text-align: center;'><span id='snum2_'+i+''>".($j+1)."</span></td>
                <td><input type='hidden' value='$substancename' name='textsubstancess1[]' class='total_substancename1' id='txtsubstancenames11_' >$substancename</td>
                <td><input type='hidden' value='$substance_ecno'  class='total_substance_ecno1' name='txtsubstances1[]' id='txtsubstance_ecnos11_'>$substance_ecno</td>
                <td><input type='hidden' value='$submissionno' name='txtsubmissionnos1[]' class='total_submissionno1' id='txtsubmissionnos11_' >$submissionno</td>
                  </tr>";
        
    
    }

$sql1="select * from reach_paymentdetails g where g.applicationid= $applicationid";
    //echo $sql1;   
  $applist1      =  $member_obj1->getApplication5('',$sql1);
    //echo "<pre>";
    //print_r($applist1);
    for($i=0;$i<count($applist1);$i++)
    {
        $paymentdetailsid   = $applist1[$i]['paymentdetailsid'];
           $applicationid     = $edit_applicationid;
        $echa_fees        = $applist1[$i]['echa_fees'];
        $echa_exchange_rate = $applist1[$i]['echa_exchange_rate'];
        $echa_amount_in_rs  = $applist1[$i]['echa_amount_in_rs'];
        $loa_fees       = $applist1[$i]['loa_fees'];
        $loa_exchange_rate  = $applist1[$i]['loa_exchange_rate'];
        $loa_amount_in_rs   = $applist1[$i]['loa_amount_in_rs'];
        $consultancy_fees   = $applist1[$i]['consultancy_fees'];
        $consultancy_exchange_rate  = $applist1[$i]['consultancy_exchange_rate'];
        $consultancy_amount_in_rs = $applist1[$i]['consultancy_amount_in_rs'];
        
        $tr .="<tr id=$paymentdetailsid>
                <td><input type='checkbox'  id='case1' rel='1' name='id'  style='display:none;' class='claim_text' data-emp-id=$paymentdetailsid></td>
                 <td style='text-align: center;'><span id='snum1_'+i+''>".($i+1)."</span></td>
                <td><input type='hidden' value='$echa_fees' name='txtecha_feess1[]' class='total_echa_fees1' id='txtecha_feess11_' >$echa_fees</td>
                <td><input type='hidden' value='$echa_exchange_rate'  class='total_echa_exchange_rate1' name='txtecha_exchange_ratess1[]' id='txtecha_exchange_rates11_'>$echa_exchange_rate</td>
                <td><input type='hidden' value='$echa_amount_in_rs' name='txtecha_amount_in_rss1[]' class='total_echa_amount_in_rs1' id='txtecha_amount_in_rss11_' >$echa_amount_in_rs</td>
                <td><input type='hidden' value='$loa_fees' name='txtloa_feess1[]' class='total_loa_fees1' id='txtloa_feess11_' >$loa_fees</td>
                <td><input type='hidden' value='$loa_exchange_rate'  class='total_loa_exchange_rate1' name='txtloa_exchange_rates1[]' id='txtloa_exchange_rates11_'>$loa_exchange_rate</td>
                <td><input type='hidden' value='$loa_amount_in_rs' name='txtloa_amount_in_rss1[]' class='total_loa_amount_in_rs1' id='txtloa_amount_in_rss11_' >$loa_amount_in_rs</td>
                <td><input type='hidden' value='$consultancy_fees' name='txtconsultancy_feess1[]' class='total_consultancy_fees1' id='txtconsultancy_feess11_' >$consultancy_fees</td>
                <td><input type='hidden' value='$consultancy_exchange_rate'  class='total_consultancy_exchange_rate1' name='txtconsultancy_exchange_rates1[]' id='txtconsultancy_exchange_rates11_'>$consultancy_exchange_rate</td>
                <td><input type='hidden' value='$consultancy_amount_in_rs' name='txtconsultancy_amount_in_rss1[]' class='total_consultancy_amount_in_rs1' id='txtconsultancy_amount_in_rss11_' >$consultancy_amount_in_rs</td>
            </tr>";
        
    
    }
    //echo $tr;

    $city = $applist[0]['head_CityName'];

    $FaxNo        = $applist[0]['head_FaxNo'];
    $telno        = $applist[0]['cor_telno'];
    $office_name  = $applist[0]['office_name'];

  

if($memberstatus == '0') {
      
        
        $headform0 = "'reg_headoffice00'";
        $sendurl    = "'membership_submit.php'";
        
        
        $edit_option_grid = '<a href="#" class="person_edit1 person_span1" rel="'.$applicationid.'" id="person_edit1" onclick="return false;">EDIT</a>
                      <a href="#" class="person_cancel1 person_text1" rel="'.$applicationid.'" id="person_cancel1"  onclick="return false;" style="display:none;">CANCEL</a>
                      <a href="#" class="person_save1 person_text1" rel="'.$applicationid.'" id="person_save1" onclick="formAjax('.$headform0.','.$sendurl.'); return false;" style="display:none;">SAVE</a>';                        

        

    
        $headform4  = "'reg_headoffice2'";
        $filename4 = "'application_submit5.php'";
  
        $editable_grid4 = '<a href="#" class="claim_edit claim_span" rel="'.$applicationid.'" id="claim_edit" onclick="return false;">EDIT</a>
                     <a href="#" class="claim_cancel claim_text" rel="'.$applicationid.'" id="claim_cancel" onclick="return false;" style="display:none;">CANCEL</a>
                     <a href="#" class="claim_save claim_text" rel="'.$applicationid.'" id="claim_save" onclick="formAjax('.$headform4.','.$filename4.'); return false;" style="display:none;">SAVE</a>';


        $headform5 = "'reg_headoffice3'";
        $filename5 = "'application_submit4.php'";

        $editable_grid5 = '<a href="#" class="verify_edit verify_span" rel="'.$applicationid.'" id="verify_edit" onclick="return false;">EDIT</a>
                     <a href="#" class="verify_cancel verify_text" rel="'.$applicationid.'" id="verify_cancel" onclick="return false;" style="display:none;">CANCEL</a>
                     <a href="#" class="verify_save verify_text" rel="'.$applicationid.'" id="verify_save" onclick="formAjax('.$headform5.','.$filename5.'); return false;" style="display:none;">SAVE</a>';
            
          $headform8 = "'reg_headoffice8'";
        $filename8 = "'application_submit3.php'";

        $editable_grid8 = '<a href="#" class="verify_edit1 verify_span1" rel="'.$applicationid.'" id="verify_edit1" onclick="return false;">EDIT</a>
                     <a href="#" class="verify_cancel1 verify_text1" rel="'.$applicationid.'" id="verify_cancel1" onclick="return false;" style="display:none;">CANCEL</a>
                     <a href="#" class="verify_save1 verify_text1" rel="'.$applicationid.'" id="verify_save1" onclick="formAjax('.$headform8.','.$filename8.'); return false;" style="display:none;">SAVE</a>';
    
        
}

$applicationlist = '';  
if($applicationid != '')
{
      $applicationlist .= '   
      
      
          
        <div class="col-lg-12">
            <div class="panel panel-info">
                <div class="panel-heading">
                Person Details
                </div>

                  <div class="panel-body">
                    <form  id="reg_headoffice00">
                        <input type="hidden" id="txteditmembershipno" name="txteditmembershipno"  value="'.$membershipno.'">
                        <input type="hidden" id="txtmemberid" name="txtmemberid"  value="'.$memberid.'" >
                        <input type="hidden" id="txtapplicationid" name="txtapplicationid"  value="'.$applicationid.'">
                      <input type="hidden" id="entered_export_count" name="entered_export_count" value="0">
                      <table width="95%"   class="table table-bordered">
                        <tr>
                          <td width="7%">1</td>
                          <td colspan="2" width="35%">Name of the Applicant Firm : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$MemberName.'</div>
                                  <input type="text" name="txtmembername" value="'.$MemberName.'"  readonly="" required=""  class="form-control person_text1" style="display:none;">
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">2</td>
                          <td colspan="2" width="35%">Address of the Applicant Firm Line 1 : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$address1.'</div>
                                  <input type="text" name="txtaddress1" value="'.$address1.'"   required=""  class="form-control person_text1" style="display:none;">
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">3</td>
                          <td colspan="2" width="35%">Address of the Applicant Firm Line 2 : </td>
                          <td colspan="3">
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$address2.'</div>
                                  <input type="text" name="txtaddress2" value="'.$address2.'"   class="form-control person_text1" style="display:none;">
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">4</td>
                          <td colspan="2" width="35%">Region of the Applicant Firm : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$office_name.'</div>
                                  <input type="text" name="txtregion" value="'.$office_name.'"  readonly="" required=""  class="form-control person_text1" style="display:none;">
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">5</td>
                          <td colspan="2" width="35%">State of the Applicant Firm : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$state.'</div>
                                  <input type="text" name="txtstate" value="'.$state.'"   required=""  class="form-control person_text1" style="display:none;">
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">6</td>
                          <td colspan="2" width="35%">City of the Applicant Firm : </td>
                          <td colspan="3">
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$city.'</div>
                                   <input type="text" name="txtcity" value="'.$city.'"   required=""  class="form-control person_text1" style="display:none;">
                                </div>
                              </td>
                        </tr>
                        <tr>
                          <td width="7%">7</td>
                          <td colspan="2" width="35%">Postcode of the Applicant Firm : </td>
                          <td colspan="3">
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$pin.'</div>
                                  <input type="text" name="txtpin" value="'.$pin.'"   required=""  class="form-control person_text1" style="display:none;">
                                 </div>
                              </td>
                        </tr>
  
                        <tr>
                          <td width="7%">8</td>
                          <td colspan="2" width="35%">Tel: (with STD Code) : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$telno.'</div>
                                  <input type="text" name="txttel" value="'.$telno.'"      required="" class="form-control person_text1" style="display:none;" >
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">9</td>
                          <td colspan="2" width="35%">Fax: (with STD Code) : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$FaxNo.'</div>
                                  <input type="text" name="txtfax" value="'.$FaxNo.'"    required="" class="form-control person_text1" style="display:none;" >
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">10</td>
                          <td colspan="2" width="35%">Mobile No : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$mobile.'</div>
                                  <input type="text" name="txtmobileno" value="'.$mobile.'"  required=""  class="form-control person_text1" style="display:none;">
                                </div>
                          </td>
                        </tr>
                        <tr>
                          <td width="7%">11</td>
                          <td colspan="2" width="35%">E-mail :</td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$email.'</div>
                                  <input type="text" name="txtemail" value="'.$email.'"   required=""  class="form-control person_text1" style="display:none;">
                              </div>
                            </td>
                        </tr>
                      <!--<tr>
                        <td width="7%">12</td>
                        <td colspan="2" width="35%">Website : </td>
                        <td colspan="3"> 
                            <div class="col-lg-15">
                                <div class="person_span1">'.$website.'</div>
                                <input type="text" name="txtwebsite" value="'.$website.'"   required="" class="form-control person_text1" style="display:none;">
                            </div>
                          </td>
                      </tr>-->
  
                      <tr>
                        <td width="7%">12</td>
                        <td colspan="2" width="35%">Name of contact person : </td>
                        <td colspan="3"> 
                            <div class="col-lg-15">
                                <div class="person_span1">'.$contactperson_name.'</div>
                                <input type="text" name="txtcntname" value="'.$contactperson_name.'"  required="" class="form-control person_text1" style="display:none;">
                              </div>
                          </td>
                      </tr>
                      <tr>
                        <td width="7%">13</td>
                        <td colspan="2" width="35%">Designation of contact person :</td>
                        <td colspan="3"> 
                            <div class="col-lg-15">
                                <div class="person_span1">'.$contactperson_designation.'</div>
                                <input type="text" name="txtcntdes" value="'.$contactperson_designation.'"   required="" class="form-control person_text1" style="display:none;">
                            </div>
                          </td>
                      </tr>
                      <tr>
                        <td width="7%">14</td>
                        <td colspan="2" width="35%">IEC No. of the firm. :</td>
                        <td colspan="3"> 
                            <div class="col-lg-15">
                                <div class="person_span1">'.$iec.'</div>
                                <input type="text" name="txtiec" value="'.$iec.'"   readonly="" required="" class="form-control person_text1" style="display:none;">
                            </div>
                          </td>
                      </tr>
                      <tr>
                        <td width="7%">15</td>
                        <td colspan="2" width="35%">Customer ID (UUID) as per ECHA Invoice :</td>
                        <td colspan="3"> 
                            <div class="col-lg-15">
                                <div class="person_span1">'.$cid.'</div>
                                <input type="text" name="txtcid" value="'.$cid.'"   readonly="" required="" class="form-control person_text1" style="display:none;">
                            </div>
                          </td>
                      </tr>
        
                      <tr>
                        <td width="7%">16</td>
                        <td colspan="2" width="35%">CAPEXIL Membership Code :</td>
                        <td colspan="3">
                            <div class="col-lg-15">
                                <div class="person_span1">'.$membershipno.'</div>
                                <input type="text" name="txtmembershipcode" value="'.$membershipno.'" readonly="" required=""  class="form-control person_text1" style="display:none;">
                            </div>
                          </td>
                      </tr>
                      <tr>
                        <td width="7%">17</td>
                        <td colspan="2" width="35%">Whether ( LSM/ MSM/ SSM/ MICRO SM)                                             : </td>    
                        <td colspan="3">
                            <div class="col-lg-15">
                                <div class="person_span1">'.$category_name.'</div>
                                <input type="text" name="txtwhether" value="'.$category_name.'"   required="" class="form-control person_text1" style="display:none;">              
                            </div>
                        </td>
                      </tr>
                      <tr>
                        <td width="7%">18</td>
                        <td colspan="2" width="35%">  Status of Membership subscription fees paid for 3 years:
                        <div >2016-2017</div>
                        <input type="hidden"  name="textyear1"  readonly=""  value="2016-2017" class="form-control person_text1" style="display:none;">
                          </div>
                          <div>2017-2018</div>
                          <input type="hidden"  name="textyear2"  readonly=""  value="2017-2018" class="form-control person_text1"  style="display:none;">
                          </div>
                          <div>2018-2019</div>
                          <input type="hidden"  name="textyear3"  readonly=""  value="2018-2019" class="form-control person_text1"  style="display:none;">
                          </div>
                          </td>
                        <td colspan="3">
                        <div class="col-lg-4">
                            <label>Receipt  No.</label>
                            <div class="person_span1">'.$receipt_1.'</div>
                            <input type="text"  name="textfees1"  readonly="" value="'.$receipt_1.'"   class="form-control person_text1" style="display:none;">
                            <div class="person_span1">'.$receipt_2.'</div>
                            <input type="test" name="textfees3"  readonly="" value="'.$receipt_2.'"   class="form-control person_text1" style="display:none;" >
                            <div class="person_span1">'.$receipt_3.'</div>
                            <input type="test" name="textfees3"  readonly="" value="'.$receipt_3.'"    class="form-control person_text1" style="display:none;" >
                          </div>
                          <div class="col-lg-4">
                            <label>Date:</label>
                            <div class="person_span1">'.$date_1.'</div>
                              <input type="text" id="txtappdate12" name="txtappdate" required="" value="'.$date_1.'"   class="form-control person_text1" style="display:none;">
                              <div class="person_span1">'.$date_2.'</div>
                              <input type="text" id="txtappdate11" name="txtappdate1" required="" value="'.$date_2.'"  class="form-control person_text1" style="display:none;">
                              <div class="person_span1">'.$date_3.'</div>
                            <input type="text" id="txtappdate21" name="txtappdate2" required="" value="'.$date_3.'"   class="form-control person_text1" style="display:none;" >
                          </div>
                      </tr>
                      <tr>
                        <td width="7%">19</td>
                        <td colspan="2" width="35%">Export House Certificate, if applicable :</td>
                        <td colspan="3">
                          <div class="form-group col-lg-4">
                                 Certificate No :
                                      <div class="person_span1">'.$export_house_no.'</div>  
                                  <input type="text" id="txtcertificateno" name="txtcertificateno"  value="'.$export_house_no.'" class="form-control person_text1" style="display:none;"   placeholder="" >
                          </div>
                          <div class="form-group col-lg-4">                         
                              Valid Upto :
                            <div class="person_span1">'.$export_house_validuptodate.'</div>
                            <input type="text" id="txtcertificatevalidupto1" name="txtcertificatevalidupto"  value="'.$export_house_validuptodate.'"  class="form-control person_text1" style="display:none;"   placeholder="" >
                          </div>
                      </tr>

                      <tr><td width="7%">20</td>
                        <td colspan="2" width="35%"> FOB value of exports during the last 3 financial year:</td>
                        <td colspan="3">
                                            
                            <div class="col-lg-4">
                                <label>Last 1 Year ('.$year_1.'):</label>
                                <div class="person_span1">'.$fob_last_1_year.'</div>
                                <input type="text" id="txtfob_enter11" name="txtfob_enter11" value="'.$fob_last_1_year.'" class="form-control person_text1"  style="display:none;">                   
                              </div>
                              <div class="col-lg-4">
                                <label>Last 2 Year ('.$year_2.'):</label>
                                <div class="person_span1">'.$fob_last_2_year.'</div>
                              <input type="text" id="txtfob_enter21" name="txtfob_enter21" value="'.$fob_last_2_year.'" class="form-control person_text1"  style="display:none;">
                              </div>
                            <div class="col-lg-4">
                                <label>Last 3 Year ('.$year_3.'):</label>
                                <div class="person_span1">'.$fob_last_3_year.'</div>
                              <input type="text" id="txtfob_enter31" name="txtfob_enter31" value="'.$fob_last_3_year.'" class="form-control person_text1" style="display:none;">
                              </div>
                      
                      </tr>
                          <tr><td width="7%">21</td>
                            <td colspan="2" width="35%">Status </td>
                            <td colspan="3">
                                <div class="row col-lg-6 person_text1" style="display:none;">
                            
                                  <!--<label class="radio-inline"><input type="radio" name="memberstatus" class="memberstatus1"  '.(($memberstatus =='0')?'checked':'').' value="0" >Pending</label>
                                  <label class="radio-inline"><input type="radio" name="memberstatus" class="memberstatus1" '.(($memberstatus =='1')?'checked':'').' value="1">Completed</label>  -->
                                  Status: '.$value.'<br>Reasons: '.$statusreason.'
                                </div>
                            
                                <!--<div class="row col-lg-6 statusreason1 person_text1" style="display:none;">
                                  <input type="text" id="statusreason" name="statusreason" class="form-control statusreasons person_text1" style="display:none;" value="'.$statusreason.'"   placeholder="Type a reason here" /> <br> <label class="text text-danger">Please mentioned the reason for pending member only.</label>
  
                                </div>  
                                <div class="row col-lg-6 statusreason2 person_text1" style="display:none;">
                                </div>-->
                                  
                              <div class="statusreason person_span1" id="statusreason1"><div class="col-lg-2">Status:</div>'.$value.'<br><div class="col-lg-2">Reasons:</div>'.$statusreason.'</div>
                            </td>
                          </tr>

                    </table>
                   </form>'.$edit_option_grid.'
                  <!--</form>-->
                </div>
              </div>
            </div>
            
            <div class="col-lg-12">
                <div class="panel panel-info">
                  <div class="panel-heading">
                      Details of manufacturing license issued by the Licensing Authority (in India) for the substance(to be enclosed ) 
                  </div>
                  <div class="panel-body">
                    <form id="reg_headoffice8">
                        <input type="hidden" id="txtmemberid" name="txtmemberid"  value="'.$memberid.'" >
                        <input type="hidden" id="txtapplicationid" name="txtapplicationid"  value="'.$applicationid.'">
                        <input type="hidden" id="entered_export_count8" name="entered_export_count" value="'.$k.'"> 
                        <p class="verify_text1" style="display:none;">            
                        
                        <input type="button" class="btn btn-primary pull-left"   onclick="updateFormc();" value="Add Entry">
                        </p>
                        <br>
                        <br>
                        <table width="95%"  id="results8" class="table table-bordered">
                          <tr>
                            <th><input id="check_alls" class="verify_text1" style="display:none;"   type="checkbox" onclick="select_all8()"/></th>
                            <th>No.</th><td> Date</td>
                            <th>Issuing authority</th>
                          </tr>
                    
                          <tr>
                            <td width="5%"></td>
                            <td></td>
                            <td><input type="text" id="textdate1" value="" class="form-control input-md verify_text1" style="display:none;"></td>
                            <td><input type="text" id="textIssuing1" value="" class="form-control input-md verify_text1" style="display:none;"></td>
                          </tr>
                      
                          '.$tr3.'
                          <tr>
                          <!--  <td style="display: none;"><div id="fob4"></div></td>-->
                            <td style="display: none;"><div id="Date  "></div></td>
                            <td style="display: none;"><div id="Issuing"></div></td>
                          </tr>
                        </table>
                        <br>
                        <button class="btn btn-primary pull-left verify_text1" style="display:none;"  type="button" id="deleteAcc8">Delete</button>
                        <br>
                        <br>
                        <br>
                   <!-- </form>'.$editable_grid8.'-->
                     </form>
                </div>                    
              </div>
            </div>  
              
               <div class="col-lg-12">
                <div class="panel panel-info">
                  <div class="panel-heading">
                      Details of the substances registered by  your firm 
                  </div>
                  <div class="panel-body">
                    <form id="reg_headoffice3">
                        <input type="hidden" id="txtmemberid" name="txtmemberid"  value="'.$memberid.'" >
                        <input type="hidden" id="txtapplicationid" name="txtapplicationid"  value="'.$applicationid.'">
                        <input type="hidden" id="entered_export_count2" name="entered_export_count" value="'.$j.'">             
                        <button type="button" class="btn btn-primary pull-left verify_text"  style="display:none;" onclick="updateFormsa();"/>Add Entry</button>
                        <br>
                        <br>
                        <table width="95%"  id="results2" class="table table-bordered">
                          <tr>
                            <th><input id="check_all2"  class="verify_text " style="display:none;"  type="checkbox" onclick="select_all2()"/></th>
                                <th>Sr. No.</th><td> Substance Name</td>
                                        <th>EC No.</th>
                                        <th> Submission No.</th>
                          </tr>
                          <tr>  
                            <td width="7%"></td>
                            <td></td>
                            <td><input type="text" id="textsubstancess1" value="" class="form-control input-md verify_text"  style="display:none;"></td>
                          
                            
                          
                            <td><input type="number" id="textecnos1" value="" class="form-control input-md verify_text"  style="display:none;"></td>
                    
                        
                          
                            <td><input type="number"  id="textsubminos1" value="" class="form-control input-md verify_text"  style="display:none;"></td>
                        
                            
                          </tr>'.$tr1.'
                          <tr>
                          <!--  <td style="display: none;"><div id="fob4"></div></td>-->
                            <td style="display: none;"><div id="substances1"></div></td>
                            <td style="display: none;"><div id="ecno1"></div></td>
                            <td style="display: none;"><div id="submino1"></div></td>
                          </tr>
                        </table>
                        <br>
                        <button class="btn btn-primary pull-left verify_text " style="display:none;"  type="button" id="deleteAcc2">Delete</button>
                        <br>
                        <br>
                        <br>
                   <!-- </form>'.$editable_grid5.'-->
                     </form>
                </div>                    
              </div>
            </div>
            <div class="col-lg-12">
              <div class="panel panel-info">
                  <div class="panel-heading">
                  Details of Registration fees paid by your firm to ECHA
                  </div>
                  <div class="panel-body">
                  <form id="reg_headoffice2">
                        <input type="hidden" id="txtmemberid" name="txtmemberid"  value="'.$memberid.'" >
                        <input type="hidden" id="txtapplicationid" name="txtapplicationid"  value="'.$applicationid.'">
                      <input type="hidden" id="entered_export_count1" name="entered_export_count" value="'.$i.'">           
                  
                      <button type="button" class="btn btn-primary pull-left claim_text1 " style="display:none;"  onClick="updateForms();"/>Add Entry</button>
                      <br>
                      <br>
                      <table width="95%"  id="results1" class="table table-bordered">
                        <tr>
                          <th><input id="check_all1"  class="claim_text " style="display:none;"  type="checkbox" onclick="select_all1()"/></th>
                          <th>Sr. No.</th>
                        <!--  <td> Substance Name</td>-->
                          <td>ECHA Regn fees paid in Euro as per ECHA Invoice   </td>
                          <td> Exchange Rate as per Bank Transaction copies </td>
                          <td> (Amount in Rs ) </td>
                          <td>LOA Fees as per LR Invoice or Data fees as per Lab invoice   </td>
                          <td> Exchange Rate as per Bank Transaction copies  </td>
                          <td>(Amount in Rs )</td>
                          <td>Consultancy charges as per consultant’s invoice</td>
                          <td> Exchange Rate as per Bank Transaction copies  </td>
                          <td> (Amount in Rs )</td>
                        </tr>
                        <tr>
                          <td width="7%"></td><td></td>
                        <!--  <td><input type="number"  id="txtfob_enter4" value="" class="form-control input-md " ></td>-->
                    
                          <td><input type="number" id="txtecha_fees1" value="" class="form-control input-md claim_text " style="display:none;"></td>
                        
                          <td><input type="number"  id="txtecha_exchange_rate1" value="" class="form-control input-md claim_text" style="display:none;"></td>
                        
                          <td><input type="number" id="txtecha_amount_in_rs1" value="" class="form-control input-md claim_text" style="display:none;"></td>
                  
                          <td><input type="number" id="txtloa_fees1" value="" class="form-control input-md claim_text" style="display:none;"></td>
                        
                          <td><input type="number"  id="txtloa_exchange_rate1" value="" class="form-control input-md claim_text" style="display:none;"></td>
                      
                          <td><input type="number" id="txtloa_amount_in_rs1" value="" class="form-control input-md claim_text" style="display:none;"></td>
                  
                          <td><input type="number" id="txtconsultancy_fees1" value="" class="form-control input-md claim_text" style="display:none;"></td>
                      
                          <td><input type="number"  id="txtconsultancy_exchange_rate1" value="" class="form-control input-md claim_text" style="display:none;"></td>
                    
                          <td><input type="number" id="txtconsultancy_amount_in_rs1" value="" class="form-control input-md claim_text" style="display:none;"></td>
                        </tr>'.$tr.'
                        <tr>
                        <!--  <td style="display: none;"><div id="fob4"></div></td>-->
                          <td style="display: none;"><div id="echa_fees1"></div></td>
                          <td style="display: none;"><div id="echa_exchange_rate1"></div></td>
                          <td style="display: none;"><div id="echa_amount_in_rs1"></div></td>
                          <td style="display: none;"><div id="loa_fees1"></div></td>
                          <td style="display: none;"><div id="loa_exchange_rate1"></div></td>
                          <td style="display: none;"><div id="loa_amount_in_rs1"></div></td>
                          <td style="display: none;"><div id="consultancy_fees1"></div></td>
                          <td style="display: none;"><div id="consultancy_exchange_rate1"></div></td>
                          <td style="display: none;"><div id="consultancy_amount_in_rs1"></div></td>
                  
                        </tr>
                      </table>
                      <table  width="95%"   class="table table-bordered">
                        
                        <tr>
                          
                          <td width="10%">TOTAL</td>
                          
                  
                        
                          <!--<td><div id="totalfob4"></div></td>-->
                          <td><input type="hidden" id="echa_fees_total1" name="echa_fees_total"><div id="total_echa_fees1" ></div></td>
                          <td><input type="hidden" id="echa_exchange_rate_total1" name="echa_exchange_rate_total"><div id="total_echa_exchange_rate1"></div></td>
                          <td><input type="hidden" id="echa_amount_in_rs_total1" name="echa_amount_in_rs_total"><div id="total_echa_amount_in_rs1"></div></td>
                          <td><input type="hidden" id="loa_fees_total1" name="loa_fees_total1"><div id="total_loa_fees1"></div></td>
                          <td><input type="hidden" id="loa_exchange_rate_total1" name="loa_exchange_rate_total"><div id="total_loa_exchange_rate1"></div></td>
                          <td><input type="hidden" id="loa_amount_in_rs_total1" name="loa_amount_in_rs_total"><div id="total_loa_amount_in_rs1"></div></td>
                          <td><input type="hidden" id="consultancy_fees_total1" name="consultancy_fees_total"><div id="total_consultancy_fees1"></div></td>
                          <td><input type="hidden" id="consultancy_exchange_rate_total1" name="consultancy_exchange_rate_total"><div id="total_consultancy_exchange_rate1"></div></td>
                          <td><input type="hidden" id="consultancy_amount_in_rs_total1" name="consultancy_amount_in_rs_total"><div id="total_consultancy_amount_in_rs1"></div></td>
                        
                        </tr>
                    
                  
                        </table>
                        <br>
                        <button class="btn btn-primary pull-left claim_text " style="display:none;"  type="button" id="deleteAcc1">Delete</button>
                        <br>
                        <br>
                        <br>
                   <!-- </form>'.$editable_grid4.'-->
                     </form>
                  </div>  
                  </div>        
              </div>';
}       
  return $applicationlist;

    
} 







function PropSubmit($membershipno = '',$for_api = '',$accessid = 3,$G_officeid = '')  
{
  $member_obj       = new Application();  //mstexhibtions
          
    $sql="select a.exhibitionname,a.country,a.fromdate,a.todate from mstexhibtions  a 
        INNER JOIN  trnexhbitiondetails  b ON a.exhibitionid=b.exhibitionid where b.membershipno  = '$membershipno' order by exhibtiondetailid desc";
      
    
  
    $proplist    =  $member_obj->getApplication('',$sql);



            $count    = count($proplist);
  for($i=0;$i<$count;$i++) 
  { 
    $membershipno             = $proplist[$i]['membershipno'];
    $fair               = $proplist[$i]['exhibitionname'];
    $country            = $proplist[$i]['country'];
    $fromdate             = checkIfNullDate(date("d-m-Y", strtotime($proplist[$i]['fromdate'])));
    $todate               = checkIfNullDate(date("d-m-Y", strtotime($proplist[$i]['todate'])));

    
    $propsubmitlist         .= '<tr>
                                <td>'.($i+1).'</td>
                                <td>'.$fair.'</td>
                                <td>'.$country.'</td>
                                <td>'.$fromdate.'</td>
                                <td>'.$todate.'</td>

                            </tr>';
    
  }

    $table_head = '<table class="table table-striped table-bordered table-hover">
              <thead>
                        <tr>
                          <th>Sr. No.</th>
                          <th>Fair/Exh.</th>
                          <th>Country</th>
                          <th>From_Date</th>
                          <th>To_Date</th>
                       
                        </tr>
                    </thead>
                <tbody>';
   $table_end = '</tbody></table>';
   
  $returntable = $table_head.$propsubmitlist.$table_end;

  return $returntable;

}

function DocumentsList($membershipno = '',$membermdaid='',$for_api = '',$accessid = 3,$G_officeid = '')
{
    $member_obj       = new Application();  //mstexhibtions
    $member_obj2        = new Application2(); //mstexhibtions 
      $A_obj      =  new Application7();
                
    $sql="select * from mstclaimlist ";
    $claimlist     =  $member_obj->getApplication('',$sql);
     $claimlistcount    = count($claimlist);
    //echo $sql;
    if($membermdaid == '')
    {
$s                = "Select membermdaid from mstmembermda where membershipno= '".$membershipno."' order by membermdaid desc limit 0,1";
$arr                = $A_obj->getApplication7('',$s);
$membermdaid          = $arr[0]['membermdaid'];
    }

  
    $sql1="select a.claimlistname,a.claimlistid from mstclaimlist a
        INNER JOIN trnmember_claimed b ON a.claimlistid=b.claimlistid
        INNER JOIN mstmembermda c ON b.membermdaid=c.membermdaid where c.membershipno='".$membershipno."' and c.membermdaid=".$membermdaid." order by b.claimlistid,b.membermdaid desc";
    $doclist1    =  $member_obj2->getApplication2('',$sql1);
    $AdminUser = new AdminUser();
    //echo $sql1;

  $count1     = count($doclist1);
  for($i=0;$i<$claimlistcount;$i++) 
  { 
    $claimlistid          = $claimlist[$i]['claimlistid'];
     $claimlistname         = $claimlist[$i]['claimlistname'];
    for($j=0;$j<$count1;$j++)
    {
        
    
      if($claimlistid==$doclist1[$j]['claimlistid']) 
      {
        $checked = "checked";
        break;                    
      }
      else 
      {
        $checked = "unchecked";
        continue;
      }
    }
    $docsubmitlist1         .= '<tr>
      <td><input type="checkbox"  name="txtdocument[]" id="ch-'.$claimlistid.'" class="ads_Checkbox" value='.$claimlistid.' '.$checked.'></td>
                                            <td><label>'.$claimlistname.'</label></td>
                                        </tr>';   

  }
    
  $table_head = '
            <input type="hidden" id="txtcount" name="txtcount" value="'.$claimlistcount.'">
            <input type="hidden" id="txtmembershipno" name="txtmembershipno" value="'.$membershipno.'">
            <input type="hidden" id="txtmembermdaid" name="txtmembermdaid" value="'.$membermdaid.'">
            <table class="table table-striped table-bordered table-hover">
            <thead>
                     
                  </thead>
                <tbody>';
   $table_end = '</tbody></table>';
   
  $returntable = $table_head.$docsubmitlist1.$table_end;
  
  return $returntable;    
} 

function DocumentsDisplay($membershipno,$membermdaid='')
{
    $member_obj       = new Application();  //mstexhibtions 
    if($membermdaid != '')
    {
      $where = " and membermdaid= $membermdaid ";
      
    $sql="select a.claimlistname from mstclaimlist a
        INNER JOIN trnmember_claimed b ON a.claimlistid=b.claimlistid
        INNER JOIN mstmembermda c ON b.membermdaid=c.membermdaid where c.membershipno='".$membershipno."' $where order by b.claimlistid,c.membermdaid desc";
    
//  echo $sql;
  $doclist     =  $member_obj->getApplication('',$sql);
  $rowcount     = count($doclist);
  for($i=0;$i<$rowcount;$i++) 
  { 

    $claimlist            = $doclist[$i]['claimlistid'];    
    $claimlistname        = $doclist[$i]['claimlistname'];
    $counter            = $i+1;
    
        $returntable .= $counter.' ] '.$claimlistname."<br>";
  }
  return $returntable;    
//  } 
  }
} 

function PaymentDetails($membershipno = '',$for_api = '',$accessid = 3,$G_officeid = '')  
{
    
    $app_obj      = new Application6();
          
      $AdminUser = new AdminUser();   

    $sql = "SELECT * FROM trnmdapaymentdisbursement where membershipno = $membershipno group by membershipno order by membermdaid desc limit 0,1 ";
      
    $banklist   = $app_obj->getApplication6('',$sql);
  
if($for_api == '') 
        {
                  $rowcount     =   count($banklist);
        for($i=0;$i<$rowcount;$i++)
        {
        $membershipno       =   $banklist[$i]['membershipno'];
        $paymentdisbursmentid = $banklist[$i]['paymentdisbursmentid'];
        $cheq1        =   $banklist[$i]['chequeno1'];
        $cheq2        =   $banklist[$i]['chequeno2'];
        $cheqdate1      =   date("d-m-Y", strtotime($banklist[$i]['chequedate1']));
        $cheqdate2      =   date("d-m-Y", strtotime($banklist[$i]['chequedate2']));
        $cheqamt1     =   $banklist[$i]['chequeamount1'];
        $cheqamt2     =   $banklist[$i]['chequeamount2'];
        $totalamt       = $banklist[$i]['totalchequeamount'];
        $recdate        =   date("d-m-Y", strtotime($banklist[$i]['mdaprocrecdate']));
        $recamt       =   $banklist[$i]['mdaprocreceivedamount'];
        $recno        = $banklist[$i]['mdaprocrecno'];  
        
      
              $headform = "'reg_headoffic'";
              $filename6 = "'application_submit6.php'";
              
            
            $editable_grid6 = '<a href="#" class="payment_edit payment_span" rel="'.$membershipno.'" id="payment_edit" onclick="return false;">EDIT</a>
                        <a href="#" class="payment_cancel payment_text" rel="'.$membershipno.'" id="payment_cancel" onclick="return false;" style="display:none;">CANCEL</a>
                        <a href="#" class="payment_save payment_text" rel="'.$membershipno.'" id="payment_save" onclick="formAjax('.$headform.','.$filename6.'); return false;" style="display:none;">SAVE</a>';

              
                    
              $bankMenu       .=  '

        <div class="col-lg-12">
            
            <div class="panel panel-info">
                  <div class="panel-heading">
                  Payement Disbursed Details 
                  </div>
            <div class="panel-body">
            <form id="reg_headoffic">
                  <input type="hidden" id="txtmembershipno" name="txtmembershipno" value="'.$membershipno.'" class="form-control">
                <input type="hidden" id="txtpaymentdisbursmentid" name="txtpaymentdisbursmentid" value="'.$paymentdisbursmentid.'" class="form-control">  
                <input type="hidden" id="operation" name="operation" value="edit1" class="form-control">                              
                  <div class="form-group col-lg-12"> 
                      <div class="col-lg-6">
                        <label>Cheque No 1 :</label>
                        <div class="payment_span">'.$cheq1.'</div>
                          <input type="text" id="txtche1" name="txtche1" value="'.$cheq1.'" class="form-control payment_text"  style="display:none;">                   
                      </div>
                        <div class="col-lg-6">
                        <label>Cheque No 2 :</label>
                        <div class="payment_span">'.$cheq2.'</div>
                          <input type="text" id="txtche2" name="txtche2" value="'.$cheq2.'" class="form-control payment_text"  style="display:none;">
                      </div>
                    </div>
                    <div class="form-group col-lg-12"> 
                      <div class="col-lg-6">
                        <label>Cheque Date 1 :</label>
                        <div class="payment_span">'.$cheqdate1.'</div>
                          <input type="text" id="txtchedate1" name="txtchedate1" value="'.$cheqdate1.'" class="form-control payment_text getdate"  style="display:none;">                   
                      </div>
                        <div class="col-lg-6">
                        <label>Cheque Date  2 :</label> 
                        <div class="payment_span">'.$cheqdate2.'</div>
                          <input type="text" id="txtchedate2" name="txtchedate2" value="'.$cheqdate2.'" class="form-control payment_text getdate"  style="display:none;">
                      </div>
                    </div>
                    <div class="form-group col-lg-12"> 
                      <div class="col-lg-6">
                        <label>Cheque Amount 1 :</label>
                        <div class="payment_span">'.$cheqamt1.'</div>
                          <input type="text" id="txtcheamt1" name="txtcheamt1" value="'.$cheqamt1.'" class="form-control payment_text"  style="display:none;">                    
                      </div>
                      <div class="col-lg-6">
                        <label>Cheque Amount 2 :</label>
                        <div class="payment_span">'.$cheqamt2.'</div>
                          <input type="text" id="txtcheamt2" name="txtcheamt2" value="'.$cheqamt2.'" class="form-control payment_text"  style="display:none;">
                      </div>
                    </div>
                    <div class="form-group col-lg-12">                      
                  <div class="col-lg-6">                                      
                      <label>Total cheque Amount : </label>   
                  </div>
                  <div class="col-lg-6">                                      
                    <div class="payment_span">'.$totalamt.'</div>
                  </div>
                  </div>
                  <div class="form-group col-lg-12"> 
                      <div class="col-lg-6">
                        <label>MAI Proc. Rec. No.:</label>
                        <div class="payment_span">'.$recno.'</div>
                          <input type="text" id="txtprocno" name="txtprocno" value="'.$recno.'" class="form-control payment_text" style="display:none;">                    
                      </div>
                      <div class="col-lg-6">
                        <label>MAI Proc. Rec. Amount:</label>
                        <div class="payment_span">'.$recamt.'</div>
                          <input type="text" id="txtprocamt" name="txtprocamt" value="'.$recamt.'" class="form-control payment_text" style="display:none;">
                      </div>
                    </div>
                  <div class="form-group col-lg-12"> 
                      <div class="col-lg-6">
                        <label>Rec Date :</label>
                        <div class="payment_span">'.$recdate.'</div>
                          <input type="text" id="txtrecdate" name="txtrecdate" value="'.$recdate.'" class="form-control payment_text getdate" style="display:none;">                
                      </div>
                        <div class="col-lg-6">
                        </div>
                  </div>
          </form>'.$editable_grid6.'
          </div>
          </div>
        </div>    
          ';
          }
          return $bankMenu;       
        }
        
        else if($for_api == 1) 
        {
          return $banklist;
        }         
    

}


function VerifyAndPayment($membershipno = '',$for_api = '',$accessid = 3,$G_officeid = '')
{
    $member_obj       = new Application5();
    $sql        = "select * from trnmdaverificationdetails where membershipno =" .$membershipno." group by membershipno order by membermdaid desc limit 0,1";
    
    $applist       =  $member_obj->getApplication5("",$sql);
if(is_array($applist))
    {
        $rowcount     =   count($applist);
        for($i=0;$i<$rowcount;$i++)
        {
        $membershipno     = $applist[$i]['membershipno'];
        
        $verificationdetailsid = $applist[$i]['verificationdetailsid'];
        $verifydate     =   date("d-m-Y", strtotime($applist[$i]['verificationdate']));
        $airtravel      =   $applist[$i]['airtravel'];
        $stalltravel    =   $applist[$i]['stalltravel'];
        $fareclaim      =   $applist[$i]['Flatclaimsanctioned'];
        $reasonverify   =   $applist[$i]['verifyreasonforrejection'];
        $approv         = $applist[$i]['verificationstatus'];         
        if($approv==1) 
        {
          $approvchecked = "checked";
        }
        else if($approv==0)
        {
          $rejectchecked = "checked";
        }         
        if($fareclaim==1) 
        {
          $fair = "checked";
        }
        elseif($fareclaim==0) 
        {
          $fair = "unchecked";
        }
    
        
         $headform = "'reg_headoffice'";
        
        $filename5 = "'application_submit5.php'";


            
        
        $AdminUser = new AdminUser();

    
        $editable_grid5 = '<a href="#" class="verify_edit verify_span" rel="'.$membershipno.'" id="verify_edit" onclick="return false;">EDIT</a>
                        <a href="#" class="verify_cancel verify_text" rel="'.$membershipno.'" id="verify_cancel" onclick="return false;" style="display:none;">CANCEL</a>
                        <a href="#" class="verify_save verify_text" rel="'.$membershipno.'" id="verify_save" onclick="formAjax('.$headform.','.$filename5.'); return false;" style="display:none;">SAVE</a>';

        

        $verifypayment = '
        
          <div class="col-lg-6">
          <div class="panel panel-info">
                  <div class="panel-heading">
                  Verification Details
                  </div>
          <div class="panel-body">
          <form id="reg_headoffice">
                  <input type="hidden" id="txtmembershipno" name="txtmembershipno" value="'.$membershipno.'" class="form-control">
                <input type="hidden" id="txtverificationdetailsid" name="txtverificationdetailsid" value="'.$verificationdetailsid.'" class="form-control">           
                <input type="hidden" id="operation" name="operation" value="edit1" class="form-control">
                    <div class="form-group col-lg-12"> 
                        <div class="col-lg-6">
                        <label>Verification Date :</label>
                        </div>
                        <div class="col-lg-6">
                        <div class="verify_span">'.$verifydate.'</div>
                        <input type="text" id="txtverifydate" name="txtverifydate" value="'.$verifydate.'" class="form-control verify_text getdate"  style="display:none;">
                      </div>
                    </div>
                    <div class="panel-heading">
                        <b> Amount Recommended :- </b> 
                    </div> 
                    
                    <div class="form-group col-lg-12"> 
                      <div class="col-lg-6">
                        <label>a.Air Travel :</label>
                     </div>
                     <div class="col-lg-6">
                            <div class="verify_span">'.$airtravel.'</div>
                              <input type="text" id="txtverifyair" name="txtverifyair" value="'.$airtravel.'" class="form-control verify_text"  style="display:none;" >
                      </div>
                      
                  </div>
                  <div class="form-group col-lg-12"> 
                      <div class="col-lg-6">
                        <label>b. Stall Charges part in fair/cash : </label>                    
                    </div>
                    <div class="col-lg-6">
                            <div class="verify_span">'.$stalltravel.'</div>
                              <input type="text" id="txtverifystall" name="txtverifystall" value="'.$stalltravel.'" class="form-control verify_text"  style="display:none;">
                      </div>
                  </div>
                  <div class="form-group col-lg-12"> 
                      <div class="col-lg-6">
                        <label>Fare Claim Sanction </label>
                     </div>
                     <div class="col-lg-6">
                              <input type="checkbox" id="txtclaimsanction" name="txtclaimsanction" value="1" '.$fair.'>
                      </div>
                   </div>
                  <div class="form-group col-lg-12"> 
                        <label>Reason Of Rejection :</label>
                        <div class="verify_span">'.$reasonverify.'</div>
                        <textarea id="txtreason" name="txtreason" class="form-control verify_text" style="display:none;" rows="3">'.$reasonverify.'</textarea>
                  </div>
                    
                  <div class="form-group col-lg-12">                      
                    <div class="col-lg-6">                                      
                        <label>Verification Status</label>
                    </div>
                    <div class="col-lg-6">                                          
                      <input type="radio" name="verificationstatus" value="1" '.$approvchecked.'> Accepted &emsp; <input type="radio" name="verificationstatus" value="0" '.$rejectchecked.'> Rejected 
                    </div>
                  </div>
            </form>'.$editable_grid5.'
              </div>                  
              </div>
              </div>
  ';
        }
  return $verifypayment;
  }

    
} 
// Display All Printing Option

function PrintDetails($membershipno,$membermdaid='')
{
//  echo $membermdaid;
    $member_obj     = new Application7();
    
    if($membermdaid !='')
  {
      $where = "and b.membermdaid = '".$membermdaid."'";
  }
  
  
    $query1 ="select * from mstmember a 
           INNER JOIN mstmembermda b ON a.membershipno = b.membershipno
           where b.membershipno = '".$membershipno."' $where 
           order by b.membermdaid desc limit 0,1";
  //  echo $query1;       
    $printlist    = $member_obj->getApplication7('',$query1);
    
       
    
        $rowcount = count($printlist);
        
        $membershipno     = $printlist[0]['membershipno'];
        $memberid       = $printlist[0]['memberid'];
        $membermdaid        =  $printlist[0]['membermdaid'];
      //  $membermdaid    = $printlist[0]['membermdaid'];

      
      
    /*    $headform = "'reg_headoffice'";
        $corform = "'reg_correspondace_address'";
        $filename = "'address_submit.php'";   
        
         $printicon = "<img height = '100' width = '100'  src='".IMAGE_DIR."print.jpeg'>";
        $emailicon = "<img height = '50' width = '50'  src='".IMAGE_DIR."email.jpeg'>";
      */  
$print_form = '<a href="download-pdf-gst-form.php?membermdaid='.$membermdaid.'&membershipno='.$membershipno.'" target="_blank" style="text-align:right;">Print Individual Export Detail </a>';
$print_checklist = '<a href="download-pdf-gst-checklist.php?membermdaid='.$membermdaid.'&membershipno='.$membershipno.'" target="_blank" style="text-align:right;">Print Checklist form</a>';
$print_chequeissueletter = '<a href="download-pdf-gst-chequeissueletter.php?membermdaid='.$membermdaid.'&membershipno='.$membershipno.'" target="_blank" style="text-align:right;">Print Cheque Issue Letter form</a>';
$print_paymentletter = '<a href="download-pdf-gst-paymentletter.php?membermdaid='.$membermdaid.'&membershipno='.$membershipno.'" target="_blank" style="text-align:right;">Print Payment Intimation Letter</a>';
$print_documentlist = '<a href="download-pdf-gst-documentlist.php?membermdaid='.$membermdaid.'" target="_blank" style="text-align:right;">Print Document List</a>';


        $addresslist = ' 
      <div class="col-lg-12" style="text-align:left;">
        <h5>•&nbsp;'.$print_form.'</h5>
      </div>
      <div class="col-lg-12" style="text-align:left;">
        <h5>•&nbsp;'.$print_checklist.'</h5>
      </div>
      <div class="col-lg-12" style="text-align:left;">
        <h5>•&nbsp;'.$print_chequeissueletter.'</h5>
      </div>
      <div class="col-lg-12" style="text-align:left;">
        <h5>•&nbsp;'.$print_paymentletter.'</h5>
      </div>
      <div class="col-lg-12" style="text-align:left;">
        <h5>•&nbsp;'.$print_documentlist.'</h5>
      </div>
<!-- <form id="reg_headoffice">               
            
                              
    <div class="col-lg-12">
      <div class="panel panel-info">
                  <div class="panel-heading">
                  Print Report 
                  </div>
  
      <div class="panel-body">
                    <div class="form-group col-lg-12"> 
                      <div class="col-lg-6">
                        <label>Verification Statement</label>
                        <div>'.$printicon.'&emsp;&emsp;&emsp;'.$emailicon.'</div>
                      </div>
                      <div class=" col-lg-6">
                        <label>Approval Letter</label><br> 
                        <input type="checkbox" name="approve" value="approve" unchecked> MAI Approved ?
                        <div>'.$printicon.'&emsp;&emsp;&emsp;'.$emailicon.'</div>
                      </div>
                    </div>
                    <div class="form-group col-lg-12"> 
                      <div class="col-lg-6">
                        <label>Ind. Exporter Claim</label>
                        <div>'.$printicon.'&emsp;&emsp;&emsp;'.$emailicon.'</div>
                    </div>
                    <div class="col-lg-6">
                        <label>Checklist</label>
                      <div>'.$printicon.'&emsp;&emsp;&emsp;'.$emailicon.'</div>
                      </div>
                    </div>
                    <div class="form-group col-lg-12"> 
                      <div class="col-lg-6">
                        <label>Claim Forum</label>
                        <div>'.$printicon.'&emsp;&emsp;&emsp;'.$emailicon.'</div>
                    </div>  
                      <div class="col-lg-6">
                        <label>Government Letter</label>
                      <div>'.$printicon.'&emsp;&emsp;&emsp;'.$emailicon.'</div>
                      </div>
                    </div>
    

                      <div class="col-lg-6">
                        <label>Claim Deficeancy Letter</label><br>
                        Letter Date : <input type="text" id="txtletterdateclaim" name="txtletterdateclaim" class="form-control getdate">
                        <div>'.$printicon.'&emsp;&emsp;&emsp;'.$emailicon.'</div>
                        
                      </div>
                      <div class=" col-lg-6">
                        <label>Application Deficeancy Letter</label><br>
                        Letter Date : <input type="text" id="txtletterdateapplication" name="txtletterdate" class="form-control  getdate">
                        <div>'.$printicon.'&emsp;&emsp;&emsp;'.$emailicon.'</div>
                        
                      </div>
                      <div class="col-lg-6">
                        <label>Payment Letter</label><br>
                        Letter Date : <input type="text" id="txtletterdatepayment" name="txtletterdatepayment" class="form-control  getdate">
                        <div>'.$printicon.'&emsp;&emsp;&emsp;'.$emailicon.'</div>
                        
                    </div>
                    <div class="col-lg-6">
                        <label>Cheque Payment Letter</label> <br>
                        Letter Date : <input type="text" id="txtletterdatecheque" name="txtletterdatecheque" class="form-control  getdate">
                      <div>'.$printicon.'&emsp;&emsp;&emsp;'.$emailicon.'</div>
                        
                      </div>
                    </div>
      </div>
      </div>        
          
</form>  -->

          ';
    
    return $addresslist;
    
} 

  //function to show documents Links according to membership starts
  function MembersDocuments($memberid='') 
  { 
    $docupload_obj  = new DocumentsUpload();
   $msql      = "select * from reach_trnmemberdocuments a inner join reach_mstdocuments b on a.docid = b.docid where a.memberid = ".$memberid;
    //echo $msql;   
    $docarray   = $docupload_obj -> getDocumentsUpload('',$msql);
    //echo $msql;
    $doc_count = count($docarray);    
    
    for($i=0;$i<$doc_count;$i++) 
    {
      $memberid     =  $docarray[$i]['memberid'];
      $member_docid   =  $docarray[$i]['member_docid'];
      $docname    =  $docarray[$i]['docname'];
      $docpath      =   $docarray[$i]['docfilepath'];
      $docupload_date = date('d-m-Y',strtotime($docarray[$i]['doc_uploaded_date']));
      $formid           =     "'document_reg_form_".$member_docid."'";
      $deleteurl        =   "'delete_document.php'";
      $doclinks .= '<a  target="_blank" href ="'.DISPLAY_DOC_FINAL.$docpath.'">'.$docname.'</a>&nbsp;&nbsp;&nbsp;&nbsp; Uploaded on :<span>'.$docupload_date.'</span>&nbsp;&nbsp;
      <form id="document_reg_form_'.$member_docid.'">
      <input type="hidden" id="txtdocumentmemberid_'.$member_docid.'" name="txtmemberid" value="'.$memberid.'" class="form-control">
      <input type="hidden" id="txtmemberdocumentid_'.$member_docid.'" name="txtmemberdocumentid" value="'.$member_docid.'" class="form-control">
      <a href="#" class="document_delete text-danger document_text_'.$member_docid.'" rel="'.$member_docid.'" id="document_delete_'.$member_docid.'" onclick="DeleteformAjax('.$formid.','.$deleteurl.'); return false;">DELETE</a>
      </form><br>';
    } 
  //function to show documents Links according to membership ends
    
    return $doclinks;
  }
  /*
function MembersDocuments($membershipno='') 
{ 
  $docupload_obj  = new DocumentsUpload1();
  $A_obj=new Application7();

$sql="Select membermdaid from mstmembermda where membershipno= ".$membershipno." order by membermdaid desc limit 0,1";
$arr=$A_obj->getApplication7('',$sql);
$membermdaid = $arr[0]['membermdaid'];      
    
  $msql       = "select * from trnmember_claimed  where membershipno = ".$membershipno." and membermdaid= ".$membermdaid;
  //echo $msql;   
  $docarray   = $docupload_obj -> getDocumentsUpload1('',$msql);
  //echo $msql;
  $doc_count = count($docarray);    
  
  for($i=0;$i<$doc_count;$i++) 
  {
    $membershipno     =  $docarray[$i]['membershipno'];
    $member_docid   =  $docarray[$i]['claimlistid'];
    $docname    =  $docarray[$i]['claimlistname'];
    $docpath      =   $docarray[$i]['claimpath'];
    $docupload_date = date('d-m-Y',strtotime($docarray[$i]['uploaded_date']));
    $formid           =     "'document_reg_form_".$member_docid."'";
//      $deleteurl        =   "'delete_document.php'";
    $doclinks .= '<a  target="_blank" href ="'.DISPLAY_DOC_FINAL.$docpath.'">'.$docname.'</a>&nbsp;&nbsp;&nbsp;&nbsp; Uploaded on :<span>'.$docupload_date.'</span>&nbsp;&nbsp;
    <form id="document_reg_form_'.$member_docid.'">
    <input type="hidden" id="txtdocumentmembershipno_'.$member_docid.'" name="txtmembershipno" value="'.$membershipno.'" class="form-control">
    <input type="hidden" id="txtmemberdocumentid_'.$member_docid.'" name="txtmemberdocumentid" value="'.$member_docid.'" class="form-control">
    </form><br>';
  } 
//function to show documents Links according to membership ends
        //<a href="#" class="document_delete text-danger document_text_'.$member_docid.'" rel="'.$member_docid.'" id="document_delete_'.$member_docid.'" onclick="DeleteformAjax('.$formid.','.$deleteurl.'); return false;">DELETE</a>
  return $doclinks;
}
*/
 function preview_text($TEXT, $LIMIT, $TAGS = 0) {

 // TRIM TEXT
 $TEXT = trim($TEXT);

 // STRIP TAGS IF PREVIEW IS WITHOUT HTML
 if ($TAGS == 0) $TEXT = preg_replace('/\s\s+/', ' ', strip_tags($TEXT));

 // IF STRLEN IS SMALLER THAN LIMIT RETURN
 if (strlen($TEXT) < $LIMIT) return $TEXT;

 if ($TAGS == 0) return substr($TEXT, 0, $LIMIT) . " ...";
 else {

     $COUNTER = 0;
     for ($i = 0; $i<= strlen($TEXT); $i++) {

         if ($TEXT{$i} == "<") $STOP = 1;

         if ($STOP != 1) {

             $COUNTER++;
         }

         if ($TEXT{$i} == ">") $STOP = 0;
         $RETURN .= $TEXT{$i};

         if ($COUNTER >= $LIMIT && $TEXT{$i} == " ") break;

     }

     return $RETURN . "...";
 }
}
 function DisplayPanelNames($panelid='') 
{ 
  $Panel_obj  = new Panel();
  $msql       = "select panel_name from mstpanels where panelid = ".$panelid;
  //echo $msql;   
  $panelarray   = $Panel_obj -> getPanel('',$msql);
  //echo $msql;
  //$doc_count = count($docarray);    
  $panelname    =  $panelarray[0]['panel_name'];
    
  return $panelname;
}

  function DisplayPanelNamesInShort($panelid='') 
{ 
  $Panel_obj  = new Panel();
  $msql       = "select panelid from mstpanels where panelid = ".$panelid;
  //echo $msql;   
  $panelarray   = $Panel_obj -> getPanel('',$msql);
  //echo $msql;
  //$doc_count = count($docarray);    
  $panelid    =  $panelarray[0]['panelid'];
  //$panelname    =  $panelarray[0]['panel_name'];
  if($panelid == 1)
  {
    $panelname ="I";
  }
  elseif($panelid == 2)
  {
    $panelname ="II";
  }
  elseif($panelid == 3)
  {
    $panelname ="III";
  }
  elseif($panelid == 4)
  {
    $panelname ="IV";
  } 
  return $panelname;
}
function DisplayCategoryNames($categoryid='') 
{ 
  $Category_obj = new Category();
  $msql       = "select category_name from mstcategories where categoryid = ".$categoryid;
  //echo $msql;   
  $categoryarray  = $Category_obj -> getCategory('',$msql);
  //echo $msql;
  //$doc_count = count($docarray);    
  $categoryname     =  $categoryarray[0]['category_name'];
    
  return $categoryname;
}

  function GetDgftOfficeName($dgftid='') 
{ 
  $member_obj = new Membership();
  $get_officeid_sql   = "select name from mst_dgft where dgftid = $dgftid";
  //echo $msql;   
  $office_array     = $member_obj-> getMembership('',$get_officeid_sql);
  $dgftname       = $office_array[0]['name'];
  $menu = $dgftname;
    
  return $menu;
}
  function checkIfNullDate($dateToCheck)
{
  $returndate='';
  if ($dateToCheck =='01-01-1970' || $dateToCheck =='0000-00-00' || $dateToCheck =='1970-01-01 00:00:00' || $dateToCheck =='0000-00-00 00:00:00' || $dateToCheck =='30-11--0001')
  {
    $returndate =NULL;
  }
  else 
  {
    $returndate =$dateToCheck;
  } 
  return $returndate;
}
  function GetRegionalOfficeIdFromDgftId($dgftid='') 
{ 
  $member_obj = new Membership();
  $get_officeid_sql   = "select officeid from mst_dgft where dgftid = $dgftid";
  //echo $msql;   
  $office_array     = $member_obj-> getMembership('',$get_officeid_sql);
  $regionid       = $office_array[0]['officeid'];
  $menu = $regionid;
    
  return $menu;
}

function GetAdminUserName($adminid='') 
{ 
  $member_obj     = new Membership();
  $get_adminuser_sql  = "select admin_name from mstadmin_users where adminid = $adminid";
  //echo $msql;   
  $adminuser_array    = $member_obj-> getMembership('',$get_adminuser_sql);
  $admin_name   = $adminuser_array[0]['admin_name'];
  return $admin_name;
        
 }
 
function ExportDisplayInTabularFormat($membershipno = '')
{
    $exportMenu='';
    $sales      = new Sales();
    $salequery = "Select year,export from member_yearwiseproductiondetails a left join mstmember b on a.memberid = b.memberid where b.membershipno='$membershipno' order by year desc";
    //echo $salequery;
    $saleslist    = $sales->getSales("",$salequery);
    if(is_array($saleslist))
    {
        $rowcount=count($saleslist);
        $export_heading = '<form>
                        <table class="table" border="2">
                      <tr>
                      <th></th>
                      <th>Year</th>
                      <th>Export ( in CR.)</th>
                      </tr>'; 
                      
        for($i=0;$i<3;$i++)
        {
            $year                     =   $saleslist[$i]['year'];
            $export                   =     $saleslist[$i]['export']; 
            $exportMenu .='<tr>
                         <td>Last '.($i+1).' Year</td>
                         <td>
                            <div>'.$year.'</div>
                         </td>
                         <td>
                            <div>'.$export.'</div>
                         </td>  
                      </tr>';
        }
        $exportfooter = '</table></form>';
        $exportMenu = $export_heading.$exportMenu.$exportfooter;
        return $exportMenu;
        
    }
          
        
}

function YearComboToAddFare($selectedyear='')
{
  $currentfinancialyear = FinancialYr();
  
  $financialinfo      = explode('-',$currentfinancialyear);
  $year1      = $financialinfo[0];
  $year2      = $financialinfo[1];
  
  $options = "";
    for($i=0;$i<5;$i++) 
    {
      $yearinrange = ($year1+$i).'-'.($year2+$i);
      if($selectedyear == $yearinrange)
      {
        $options    .='<option value="'.$yearinrange.'" selected="selected">'.$yearinrange.'</option>';
      }
      else
      {
        $options    .='<option value="'.$yearinrange.'">'.$yearinrange.'</option>';
      }
    
    }
  return $options; 
}

function checkapplytwoexhinoneyear($nextyeardate = "", $memberid = ""){
    $checkexhclass = new AllTables();
    
    //Today Date      
    $todaydate = date("d-m-Y");
    
   // $query1 ="select MembershipNo from mstmember where MemberID = $memberid"; 
    
     $query1 ="SELECT a.MemberID,a.MemberName,g.ValidUpto FROM `mstmember` a INNER JOIN trnrcmc_issue_23_06_2020 g ON a.MemberID = g.memberid where a.MemberID = $memberid group by a.MemberID ORDER BY a.MemberName ASC"; 
    
      /*select a.approved_date,a.membershipno,a.MemberName,a.MembershipNo,c.Claimstatus,c.amountclaimed,b.exhibtiondetailid,
            d.cadate, d.approvalstatus,a.MemberID,e.exhibitionname, f.yearfrmai,f.membermdaid,g.amountrecom 
            from mstmember a 
            INNER JOIN trnexhbitiondetails b ON a.membershipno=b.membershipno 
            INNER JOIN trnmdaclaimdetails c ON b.membermdaid=c.membermdaid 
            INNER JOIN trnmdaapplication d ON c.membermdaid = d.membermdaid
            INNER JOIN mstexhibtions e ON b.exhibitionid = e.exhibitionid
            INNER JOIN mstmembermda f ON b.membermdaid=f.membermdaid 
            INNER JOIN trnmdaverificationdetails g ON b.membermdaid=g.membermdaid
            INNER JOIN trnmdapaymentdisbursement i ON c.membermdaid = i.membermdaid*/
    $membernamelist   = $checkexhclass->getInfo('',$query1);
    $membershipno = $membernamelist[0]['MembershipNo'];
        $MemberName = $membernamelist[0]['MemberName'];
            $ValidUpto = $membernamelist[0]['ValidUpto'];
    $mysql = "
            
             SELECT  a.applicationid,a.membershipno,a.reach_companyname
                
                FROM `reach_trnapplication` a
                  
            where a.approved_bymember = 0 and a.memberid = $memberid group by a.applicationid ORDER BY a.reach_companyname ASC";


           
           // echo $mysql; 
    $exhlist    = $checkexhclass->getInfo('',$mysql);
//$ValidUpto = $exhlist[0]['ValidUpto'];
//echo $ValidUpto;
     $membernamelistcount = count($membernamelist);
    $exhcount = count($exhlist);
    //echo $exhcount;
    
    $cdate = date("Y-m-d", strtotime($todaydate));
    //echo $ndate = date("Y-m-d", strtotime($nextyeardate));

    //Check the condition that current date is big than member approve date after 12 month
    if($cdate < $ValidUpto){
        
        $curfinyear = FinancialYr(); // Current fin year
        $reachyearcount = 0;
        $sameexhcount = 0;
        for($i=0;$i<$membernamelistcount;$i++){
    
          $exhname      = trim($exhlist[$i]['reach_companyname']);
          $membername     = trim($membernamelist[$i]['MemberName']);
          $yearfrmai      = trim($membernamelist[$i]['ValidUpto']);
          
          if($yearfrmai < $curfinyear){
              $reachyearcount ++;
          }
          
          if($exhname == $displayexhname){
              $sameexhcount ++;
          } 
          
          $displayexhname = $exhname;
          
        }
        
        if($reachyearcount == 1 || $reachyearcount > 2){
          $response = "YEAR||Now you can't apply to more Application in this financial year";
        }else{
          
            if($sameexhcount < 1){
                $response =  "EXH||You have already apply  Application ";             
            }else{
                $response =  "SUCCESS||";             
            }
                    
        }
              
    }else{
        $response =  "DATE||You cannot apply to Application..!";     
    }
   // echo $response;
  return $response;
    
}


function InvoiceDisplayInTabularFormat($memberid='')
{
  $MembeApplication     = new Application();
  

    $sql = "select a.mailing_status,a.memberid,a.memberinvoicesid,a.invoicesrno,a.invoicedate,a.InvoiceTotalAmount,a.InvoiceBaseAmount,
      a.InvoiceServiceTaxAmount,a.InvoiceSwachhCessOnAmount,a.InvoiceKrishiKalyanCessOnAmount,
      a.igst_percentage,a.ugst_percentage,a.cgst_percentage,a.sgst_percentage,
      a.igst_amount,a.ugst_amount,a.cgst_amount,a.sgst_amount,a.LockRow ,
      a.iscancelled,a.isoldinvoice,a.cancelled_date,a.cancel_reason,
      c.package_entryfee,c.package_amount,d.memberpaymentheaderid,d.head_receipt_srno,d.head_cancelled_status,e.head_Email
      from trninvoicetomember a
      inner join mstmember e on a.memberid=e.MemberID 
      inner join trninvoicetomemberdetails b on a.memberinvoicesid=b.memberinvoicesid 
      inner join membership_packages c on b.membershippackageid=c.packageid
      left join member_payment_header d on a.memberinvoicesid=d.memberinvoicesid  
      where a.memberid = $memberid AND a.pg_status IN ('0','1')
      group by a.memberinvoicesid order by a.invoicedate desc"; 
  
  $invoicelist    = $MembeApplication->getApplication("",$sql);
    
        $rowcount     =   count($invoicelist);
        $invoiceheader = '<table border="1" class="table table-bordered">
                    <tr style="font-weight:bold;">
                      <td>Sr No</td>
                      <td>Invoice Date</td>
                      <td>Membership For Year</td>
                      <td>Entrance Fees</td>
                      <td>Membership Fees</td>
                      <td>Invoice Amt(Rs)</td>
                    </tr>';

        for($i=0;$i<$rowcount;$i++)
        {
          $counter    = $i+1;
          $memberid               =   $invoicelist[$i]['memberid'];
          $memberinvoicesid           =   $invoicelist[$i]['memberinvoicesid'];

          $invoicesrno              =   $invoicelist[$i]['invoicesrno'];
          $head_Email               =   $invoicelist[$i]['head_Email'];
          $invoicedate_for_print        =     $invoicelist[$i]['invoicedate'];
          $invoicedate              =     checkIfNullDate(date("d-m-Y", strtotime($invoicelist[$i]['invoicedate'])));
          
          $package_entryfee           =   $invoicelist[$i]['package_entryfee'];
          $details                  =   explode('||',DisplayMembershipFees($memberinvoicesid));
          $package_amount           =   $details[0];
          $membershipforyear          =   $details[1];
          $InvoiceTotalAmount         =   $invoicelist[$i]['InvoiceTotalAmount'];
          $InvoiceBaseAmount          =   $invoicelist[$i]['InvoiceBaseAmount'];
          $cancelled_status           =   $invoicelist[$i]['iscancelled'];
          $cancelled_date           =   checkIfNullDate(date("d-m-Y", strtotime($invoicelist[$i]['cancelled_date'])));
          $cancelled_reason           =   $invoicelist[$i]['cancel_reason'];
          $oldinvoice_status          =   $invoicelist[$i]['isoldinvoice'];
          
      
              
          
          $invoiceMenu        .=  '<tr id="invoice_row'.$memberinvoicesid.'">
                                  <td>'.$counter.'</td>
                                  <td id="invoicedate'.$memberinvoicesid.'">'.$invoicedate.'</td>
                                  <td>'.$membershipforyear.'</td>
                                  <td>'.$package_entryfee.'</td>
                                  <td>'.$package_amount.'</td>
                                  <td>'.$InvoiceTotalAmount.'</td>
                                  
                               </tr>';
          
        }
        $invoicefooter = '</table>';
        $menu = $invoiceheader.$invoiceMenu.$invoicefooter;
        return $menu;
}

function DisplayMembershipFees($memberinvoicesid='') 
{ 
  $MembeApplication     = new Application();
  $msql       = "select GROUP_CONCAT(c.package_amount  separator ',') as package_amount ,GROUP_CONCAT(c.membershipforyear  separator ',') as membershipforyear from trninvoicetomember a inner join trninvoicetomemberdetails b on a.memberinvoicesid=b.memberinvoicesid inner join membership_packages c on b.membershippackageid=c.packageid where a.memberinvoicesid = ".$memberinvoicesid;
  //echo $msql;   
  $paymentarray       = $MembeApplication -> getApplication('',$msql);
  $package_amount     = $paymentarray[0]['package_amount'];
  $membershipforyear  = $paymentarray[0]['membershipforyear'];
  $menu .= $package_amount.'||'.$membershipforyear;
  
  return $menu;
}
$month_names = array ("","January","February","March","April","May","June","July","August","September","October","November","December");  



  
  // Display Application starts
function ApplicationDisplay($membershipno,$applicationid='')
{
  $member_obj       = new Application();
  $member_obj1      =   new Application5(); 
  $member_obj2      =   new Application2(); 
    $member_obj3      =   new Application4();
  if($applicationid !='')
  {
    $where = "and a.applicationid = '".$applicationid."'";
  }
 
    $sql = "SELECT * FROM `reach_trnapplication` a
            INNER join mstmember b on a.membershipno=b.MembershipNo
      where a.membershipno = '".$membershipno."' $where order by a.applicationid desc limit 0,1";
  
    
    //echo $sql;   
    $membernamelist       =  $member_obj->getApplication('',$sql);
    
            $applicationid        =  $membernamelist[0]['applicationid'];
            $memberid       =  $membernamelist[0]['memberid'];
              $applicationdate      =  date("d-m-Y",strtotime($membernamelist[0]['applicationdate']));
            $reach_cnt_person       =  $membernamelist[0]['reach_cnt_person'];
            $reach_cnt_designation        =  $membernamelist[0]['reach_cnt_designation'];
            $reach_cnt_contactno        =  $membernamelist[0]['reach_cnt_contactno'];
            $reach_cnt_email        =  $membernamelist[0]['reach_cnt_email'];
            $reach_companyname        =  $membernamelist[0]['reach_companyname'];
            $reach_cnt_address1       =  $membernamelist[0]['reach_cnt_address1'];
            $reach_cnt_address2       =  $membernamelist[0]['reach_cnt_address2'];
            $reach_cnt_stateid        =  $membernamelist[0]['reach_cnt_stateid'];
            $reach_cnt_statename        =  $membernamelist[0]['reach_cnt_statename'];
            $reach_cnt_pincode        =  $membernamelist[0]['reach_cnt_pincode'];
            $reach_cnt_gstno        =  $membernamelist[0]['reach_cnt_gstno'];
            $reach_cnt_iecno        =  $membernamelist[0]['reach_cnt_iecno'];
            $customer_id        =  $membernamelist[0]['customer_id'];
            $ischemexcilmember        =  $membernamelist[0]['ischemexcilmember'];
            $company_category       =  $membernamelist[0]['company_category'];
            $export_house_no        =  $membernamelist[0]['export_house_no'];
            $export_house_issueddate        =  date("d-m-Y",strtotime($membernamelist[0]['export_house_issueddate']));
            $export_house_validuptodate       =  date("d-m-Y",strtotime($membernamelist[0]['export_house_validuptodate']));
            $mfg_no       =  $membernamelist[0]['mfg_no'];
            $mfg_date       =  $membernamelist[0]['mfg_date'];
            $mfg_authority        =  $membernamelist[0]['mfg_authority'];
            $approved_bymember        =  $membernamelist[0]['approved_bymember'];
            $approved_byadmin       =  $membernamelist[0]['approved_byadmin'];
            $membershipno       =  $membernamelist[0]['membershipno'];
            $memberstatus       =  $membernamelist[0]['memberstatus'];
            $year_1       =  $membernamelist[0]['year_1'];
            $receipt_1        =  $membernamelist[0]['receipt_1'];
            $date_1       =  date("d-m-Y",strtotime($membernamelist[0]['date_1']));
            $year_2       =  $membernamelist[0]['year_2'];
            $receipt_2        =  $membernamelist[0]['receipt_2'];
            $date_2       =  date("d-m-Y",strtotime($membernamelist[0]['date_2']));
            $year_3       =  $membernamelist[0]['year_3'];
            $receipt_3        =  $membernamelist[0]['receipt_3'];
            $date_3       =  date("d-m-Y",strtotime($membernamelist[0]['date_3']));
            $fob_last_1_year        =  $membernamelist[0]['fob_last_1_year'];
            $fob_last_2_year        =  $membernamelist[0]['fob_last_2_year'];
            $fob_last_3_year        =  $membernamelist[0]['fob_last_3_year'];
            $signature        =  $membernamelist[0]['signature'];
            $declaration_name       =  $membernamelist[0]['declaration_name'];
            $designation        =  $membernamelist[0]['designation'];
            $companeyseal       =  $membernamelist[0]['companeyseal'];
            $md_ceo_company       =  $membernamelist[0]['md_ceo_company'];
            $md_ceo_name        =  $membernamelist[0]['md_ceo_name'];
            $md_ceo_designation       =  $membernamelist[0]['md_ceo_designation'];
            $md_ceo_seal        =  $membernamelist[0]['md_ceo_seal'];
            $md_ceo_place       =  $membernamelist[0]['md_ceo_place'];
            $md_ceo_date        =  date("d-m-Y",strtotime($membernamelist[0]['md_ceo_date']));
            $terms_condition        =  $membernamelist[0]['terms_condition'];
            $reach_cnt_city       =  $membernamelist[0]['reach_cnt_city'];
            $reach_cnt_tel        =  $membernamelist[0]['reach_cnt_tel'];
            $reach_cnt_fax        =  $membernamelist[0]['reach_cnt_fax'];
            $region       =  $membernamelist[0]['region'];
            $reach_cnt_mobileno       =  $membernamelist[0]['reach_cnt_mobileno'];
              $reach_cnt_landlineno       =  $membernamelist[0]['reach_cnt_landlineno'];
               $reach_cnt_email2       =  $membernamelist[0]['reach_cnt_email2'];
          
            $statusreason       =  $membernamelist[0]['statusreason'];
            if($memberstatus=='0') 
            {
              $value="pending";
            }
            else 
            {
              $value="Completed";
            } 
  $sql2 = "SELECT * FROM reach_substancelicenseissue 
                  where  applicationid= $applicationid order by issue_id ASC";
            //die();
            
            $stancelicenseissuelist   = $member_obj->getApplication('',$sql2);
            for ($i=0; $i <count($stancelicenseissuelist) ; $i++) 
            { 
              $issue_id       =  $stancelicenseissuelist[$i]['issue_id'];
              $substance_date     =  date("d-m-Y",strtotime($stancelicenseissuelist[$i]['substance_date']));
              $stancelicensecount=$i+1;
              $Issuing_authority    =  $stancelicenseissuelist[$i]['Issuing_authority'];
             	$licenseno    =  $stancelicenseissuelist[$i]['licenseno'];
                  if ($stancelicensecount > 0) 
                  {
                    
                            $tr3 .="
                            <tr id='".$issue_id."'>
                           
                              <td>
                                  <a href='javascript:void(0);' class='btn-primary navigation_button removeauthority verify_text1' style='background: #c81c05;padding: 5px 10px;color: #ffffff;display:none;'  onclick = 'authority_table(this);'>Remove</a>
                                
                              </td>

                              <td>
                                    <span id='snum1_'+i+'' >".$stancelicensecount."</span>
                                    <input type='hidden' name='issue_id[]' id='issue_id_".$stancelicensecount."' value='".$issue_id."'>
                                
                              </td>
										<td>
                                <span class='verify_span1'>".$licenseno."</span>
                                <input type='text' name='txtlicenseno[]' value='".$licenseno."'   onkeypress='return isNumberKey(event,this.id)' class='form-control input-md  required verify_text1' style='display:none;'  required></p>
                              
                              </td>
                              <td>
                                <span class='verify_span1'>".$substance_date."</span>
                                <input type='text' name='textdate[]' value='".$substance_date."'  class='form-control input-md getdate required verify_text1' style='display:none;'  required></p>
                              
                              </td>
                              <td>
                                <span class='verify_span1' >".$Issuing_authority."</span>
                                <input type='text' name='textIssuing[]'   value='".$Issuing_authority."' class='form-control input-md required verify_text1' style='display:none;' required>
                              </td>
                            </tr>";
                  }
                  else
                  {
                    $tr3 .="<tr>
                              <td></td>
                              <td><span id='snum1_1'>1</span></td>
                              <td><input type='text' name='txtlicenseno[]' value='' id='' onkeypress='return isNumberKey(event,this.id)' class='form-control input-md  required verify_text1' style='display:none;' required=''></td>
            
                              <td><input type='text' name='textdate[]' value='' id='' class='form-control input-md getdate required verify_text1' style='display:none;' required=''></td>
            
                              <td><input type='text' name='textIssuing[]'  id='' value='' class='form-control input-md required verify_text1' style='display:none;' required='' ></td>
                            </tr>";
                  }          



            }
            $sql3 = "SELECT * FROM reach_substancesdetails 
                  where  applicationid= $applicationid order by substancesid ASC";
            //die();
            
            $substancesdetailslist    = $member_obj->getApplication('',$sql3);
            for ($j=0; $j <count($substancesdetailslist) ; $j++) 
            {
              $substancesid       =  $substancesdetailslist[$j]['substancesid'];
              $substancename        =  $substancesdetailslist[$j]['substancename'];
              $substance_ecno       =  $substancesdetailslist[$j]['substance_ecno'];
              $submissionno       =  $substancesdetailslist[$j]['submissionno'];
              $hscode        =  $substancesdetailslist[$j]['hscode'];
              $tonnageband        =  $substancesdetailslist[$j]['tonnageband'];
              $casno        =  $substancesdetailslist[$j]['casno'];
              $submissiondate        =  date("d-m-Y",strtotime($substancesdetailslist[$j]['submissiondate']));
              $echa_reg_date        =  date("d-m-Y",strtotime($substancesdetailslist[$j]['echa_reg_date']));
              $substances_docimagepath1        =  $substancesdetailslist[$j]['substances_docimagepath1'];
              $substances_docimagepath2        =  $substancesdetailslist[$j]['substances_docimagepath2'];
              $substances_docimagepath3        =  $substancesdetailslist[$j]['substances_docimagepath3'];
              $substances_docimagepath4       =  $substancesdetailslist[$j]['substances_docimagepath4'];
                $substancesdetailscount= $j+1;
               if ($substancesdetailscount > 0) 
                  {
                    

                            $tr1 .="
                            <tr>
                              <td><a href='javascript:void(0);' class='btn-primary navigation_button verify_text' style='background: #c81c05;padding: 5px 10px;color: #ffffff;display:none;'   onclick = 'substances_registered_table_deleteRow(this);dep_it_table_deleteRow(this.id);'>Remove</a>
                              </td>
                                <td><span id='snum2_".$substancesdetailscount."'>".$substancesdetailscount."</span>
                                <input type='hidden' name='substancesid[]' id='substancesid_".$substancesdetailscount."' value='".$substancesid."'>
                                </td>
                                    <td>
                                      <span class='verify_span'>".$substancename."</span>
                                      <input type='text' name='textsubstances1[]' id ='substancemain_1' value='".$substancename."' class='form-control input-md verify_text substance main required' oninput='substancesvaluefetch(this);' style='display:none;'>
                                    </td>

                                      <td>
                                        <span class='verify_span'>".$hscode."</span>
                                        <input type='text' name='texthscode1[]'  class='form-control input-md verify_text required' style='display:none;' value='".$hscode."'></td>
                           
                                    
                                    <td>
                                        <span class='verify_span'>".$casno."</span>
                                        <input type='text' name='textcasno[]' class='form-control input-md verify_text required'  style='display:none;' value='".$casno."'></td>
                                      
                         
                                    <td>
                                        <span class='verify_span'>".$tonnageband."</span>
                                       <input type='text' name='txttonnageband[]'  class='form-control input-md verify_text required' style='display:none;' value='".$tonnageband."'>
                                      
												</td>			
                                    <td>
                                      <span class='verify_span'>".$substance_ecno."</span>
                                      <input type='text' name='textecno1[]'  class='form-control input-md verify_text required'  style='display:none;' value='".$substance_ecno."'></td>
                                
                                    <td>
                                      <span class='verify_span'>".$submissionno."</span>
                                      <input type='text'  name='textsubmino1[]'  class='form-control input-md verify_text required' style='display:none;' value='".$submissionno."'></td>


                              
                                    <td>
                                      <span class='verify_span'>".$submissiondate."</span>
                                      <input type='text'  name='textsubmidate[]'  class='form-control input-md submitiondate verify_text required' style='display:none;' value='".$submissiondate."'></td>


                                    <td>
                                      <label>ECHA Invoice</label>
                                        <div id='upload1mainimagediv_1'>
                                          <a target='_blank' href ='".DISPLAY_DOC_FINAL."$substances_docimagepath1'><img src='".IMAGE_DIR."pdf-logo.jpg' id='uploadedimagesrc' style='width: 30px;''><br>$substances_docimagepath1</a>
                                        </div>
                                        <input type='hidden' class='form-control' name='txtdoc1imagepath[]' id='txtdoc1imagepath_1' value='$substances_docimagepath1'/>
                                        <input type='file' class='required verify_text' name='upload1mainimage' id='upload1mainimage_1' onclick='return upload_upload1mainimage(this);' style='display:none;'/>
                                    
                                    <label>ECHA DECISION LETTER mentioning Registration number and registration date</label>
                                    <div id='upload2mainimagediv_1'>
                                      <a target='_blank' href ='".DISPLAY_DOC_FINAL."$substances_docimagepath2'><img src='".IMAGE_DIR."pdf-logo.jpg' id='uploadedimagesrc' style='width: 30px;''><br>$substances_docimagepath2</a>
                                        
                                    </div>
                                        <input type='hidden' class='form-control' name='txtdoc2imagepath[]' id='txtdoc2imagepath_1'value='$substances_docimagepath2' />
                                          <input type='file' class='required verify_text' name='upload2mainimage' id='upload2mainimage_1' onclick='return upload_upload2mainimage(this);' style='display:none;'/>
                                    <label>REACH IT Report of Substance mentioning CAS & EC No  </label>
                                    <div id='upload3mainimagediv_1'>
                                     <a target='_blank' href ='".DISPLAY_DOC_FINAL."$substances_docimagepath3'><img src='".IMAGE_DIR."pdf-logo.jpg' id='uploadedimagesrc' style='width: 30px;''><br>$substances_docimagepath3</a>
                                        
                                    </div>
                                        <input type='hidden' class='form-control' name='txtdoc3imagepath[]' id='txtdoc3imagepath_1' value='$substances_docimagepath3' />
                                          <input type='file' class='required verify_text' name='upload3mainimage' id='upload3mainimage_1' onclick='return upload_upload3mainimage(this);' style='display:none;'/>
                                    <label>Lead Registrant Invoice</label>
                                    <div id='upload4mainimagediv_1'>
                                     <a target='_blank' href ='".DISPLAY_DOC_FINAL."$substances_docimagepath4'><img src='".IMAGE_DIR."pdf-logo.jpg' id='uploadedimagesrc' style='width: 30px;''><br>$substances_docimagepath4</a>
                                        
                                    </div>
                                        <input type='hidden' class='form-control' name='txtdoc4imagepath[]' id='txtdoc4imagepath_1' value='$substances_docimagepath4' />
                                          <input type='file' class='required verify_text' name='upload4mainimage' id='upload4mainimage_1' onclick='return upload_upload4mainimage(this);' style='display:none;'/>
                                  
                                      </td>
                            </tr>";
                  }
                  else
                  {
                    $tr1 .=" <tr>
                              <td></td>
                                <td><span id='snum_1'>1</span></td>
                                    <td><input type='text' name='textsubstances1[]' id ='substancemain_1' value=' class='form-control input-md verify_text substance main required' oninput='substancesvaluefetch(this);' style='display:none;'></td>

                                      <td><input type='text' name='texthscode1[]'  class='form-control input-md verify_text required' style='display:none;' ></td>
                                      <td><input type='text' name='textcasno[]'  class='form-control input-md verify_text required' style='display:none;' ></td>
                                      <td>	
												
                                    <td><input type='text' name='textecno1[]'  class='form-control input-md verify_text required' style='display:none;' ></td>
                                
                                    <td><input type='text'  name='textsubmino1[]'  class='form-control input-md verify_text required' style='display:none;' ></td>
                                         <td><input type='text'  name='textsubmidate[]'  class='form-control input-md submitiondate verify_text required' style='display:none;' ></td>

                                      <td>
                                      
                                <label>ECHA Invoice</label>
                                        <div id='upload1mainimagediv_1'>
                                     
                                  </div>
                                        <input type='hidden' class='form-control' name='txtdoc1imagepath[]' id='txtdoc1imagepath_1' />
                                          <input type='file' class='required verify_text' name='upload1mainimage' id='upload1mainimage_1' onclick='return upload_upload1mainimage(this);' style='display:none;'/>
                                    
                                    <label>ECHA DECISION LETTER mentioning Registration number and registration date</label>
                                    <div id='upload2mainimagediv_1'>
                                     
                                  </div>
                                        <input type='hidden' class='form-control' name='txtdoc2imagepath[]' id='txtdoc2imagepath_1' />
                                          <input type='file' class='required verify_text' name='upload2mainimage' id='upload2mainimage_1' onclick='return upload_upload2mainimage(this);' style='display:none;'/>
                                    <label>REACH IT Report of Substance mentioning CAS & EC No  </label>
                                    <div id='upload3mainimagediv_1'>
                                     
                                  </div>
                                        <input type='hidden' class='form-control' name='txtdoc3imagepath[]' id='txtdoc3imagepath_1' />
                                          <input type='file' class='required verify_text' name='upload3mainimage' id='upload3mainimage_1' onclick='return upload_upload3mainimage(this);' style='display:none;'/>
                                    <label>Lead Registrant Invoice</label>
                                    <div id='upload4mainimagediv_1'>
                                     
                                  </div>
                                        <input type='hidden' class='form-control' name='txtdoc4imagepath[]' id='txtdoc4imagepath_1' />
                                          <input type='file' class='required verify_text' name='upload4mainimage' id='upload4mainimage_1' onclick='return upload_upload4mainimage(this);' style='display:none;'/>
                                  
                                      </td>
                            </tr>";
                  } 

              
        
    
            }
            $sql4 = "SELECT * FROM reach_paymentdetails 
                  where  applicationid= $applicationid order by paymentdetailsid ASC";
            //die();
            
            $paymentdetailslist   = $member_obj->getApplication('',$sql4);
            for ($i=0; $i <count($paymentdetailslist) ; $i++) 
            { 
              $paymentdetailsid       =  $paymentdetailslist[$i]['paymentdetailsid'];
              $echa_substancename        =  $paymentdetailslist[$i]['echa_substancename'];
              $echa_fees        =  $paymentdetailslist[$i]['echa_fees'];
              $echa_exchange_rate       =  $paymentdetailslist[$i]['echa_exchange_rate'];
              $echa_amount_in_rs        =  $paymentdetailslist[$i]['echa_amount_in_rs'];
              $loa_fees       =  $paymentdetailslist[$i]['loa_fees'];
              $loa_exchange_rate        =  $paymentdetailslist[$i]['loa_exchange_rate'];
              $loa_amount_in_rs       =  $paymentdetailslist[$i]['loa_amount_in_rs'];
              $consultancy_fees       =  $paymentdetailslist[$i]['consultancy_fees'];
              $consultancy_exchange_rate        =  $paymentdetailslist[$i]['consultancy_exchange_rate'];
              $consultancy_amount_in_rs       =  $paymentdetailslist[$i]['consultancy_amount_in_rs'];
              $paymentdetailscount = $i+1;
              $paymentdetailscount1 = $i+2;
               if ($paymentdetailscount > 0) 
                  {
                    

                            $tr .="<tr id=$paymentdetailsid>
                                    
                                    <td>
                                      <span id='snum3_'+i+'' >".$paymentdetailscount."</span>
                                      <input type='hidden' name='paymentdetailsid[]' id='paymentdetailsid_".$paymentdetailscount."' value='".$paymentdetailsid."'>
                                
                                    </td>
                                    <td>
                                      <span class='verify_span'>".$echa_substancename."</span>
                                      <input type='text'  id='substancecopy_1' name='txtsubstancename[]' value='".$echa_substancename."' class='form-control input-md substance required verify_text' style='display:none;'  readonly>
                                    </td>
                                    <td>
                                      <span class='verify_span'>".$echa_fees."</span>
                                      <input type='text'  name='txtecha_fees[]' value='".$echa_fees."'  size='10' class='form-control input-md echa_fees required verify_text' style='display:none;'  onkeypress='return isNumberKey(event,this.id)' onInput='echaamount()'>
                                    </td>
                                    <td>
                                      <span class='verify_span'>".$echa_exchange_rate."</span>
                                      <input type='text' size='10'  name='txtecha_exchange_rate[]'   value='".$echa_exchange_rate."'  class='form-control input-md echa_exchange_rate required verify_text' style='display:none;'   onkeypress='return isNumberKey(event,this.id)' onInput='echaamount()'>
                                </td>
                                <td>
                                 <span class='verify_span'>".$echa_amount_in_rs."</span>
                                  <input type='text' size='10'  name='txtecha_amount_in_rs[]'   value='".$echa_amount_in_rs."'  class='form-control input-md echa_amount_in_rs required verify_text' style='display:none;'  onkeypress='return isNumberKey(event,this.id)'  readonly>
                                </td>
                                <td>
                                 <span class='verify_span'>".$loa_fees."</span>
                                <input type='text' name='txtloa_fees[]' size='10'  value='".$loa_fees."'  class='form-control input-md loa_fees required verify_text' style='display:none;'  onkeypress='return isNumberKey(event,this.id)' onInput='loaamount()' >
                                </td>
                                <td>
                                 <span class='verify_span'>".$loa_exchange_rate."</span>
                                <input type='text'  name='txtloa_exchange_rate[]'  value='".$loa_exchange_rate."'  class='form-control input-md loa_exchange_rate required verify_text' style='display:none;'  onkeypress='return isNumberKey(event,this.id)' onInput='loaamount()'>
                                </td>
                                <td>
                                 <span class='verify_span'>".$loa_amount_in_rs."</span>
                                <input type='text' name='txtloa_amount_in_rs[]' size='10'  value='".$loa_amount_in_rs."'  class='form-control input-md loa_amount_in_rs required verify_text' style='display:none;'  onkeypress='return isNumberKey(event,this.id)'  readonly>
                                </td>
                                <td>
                                 <span class='verify_span'>".$consultancy_fees."</span>
                                <input type='text' name='txtconsultancy_fees[]' size='10'  value='".$consultancy_fees."'  class='form-control input-md consultancy_fees required verify_text' style='display:none;'  onkeypress='return isNumberKey(event,this.id)' onInput='consultancyamount()' >
                                </td>
                                <td>
                                 <span class='verify_span'>".$consultancy_exchange_rate."</span>
                                <input type='text' name='txtconsultancy_exchange_rate[]' size='10'   value='".$consultancy_exchange_rate."'  class='form-control input-md consultancy_exchange_rate required verify_text' style='display:none;'  onkeypress='return isNumberKey(event,this.id)' onInput='consultancyamount()' >
                                </td>
                                <td>
                                 <span class='verify_span'>".$consultancy_amount_in_rs."</span>
                                 <input type='text' name='txtconsultancy_amount_in_rs[]' size='10'  value='".$consultancy_amount_in_rs."'  class='form-control input-md consultancy_amount_in_rs required verify_text' style='display:none;' onkeypress='return isNumberKey(event,this.id)' readonly >
                                 </td>



                        </tr>";
                  }
                  else
                  {
                    $tr .="<tr>
     
                              <td><span id='snum3_1'>1</span></td>
                              <td>
                                <input type='text'  id='substancecopy_1' name='txtsubstancenam  class='form-control input-md substance required verify_text' style='display:none;'  readonly>
                              </td>
                              <td>
                                <input type='text'  name='txtecha_fee size='10' class='form-control input-md echa_fees required verify_text' style='display:none;'  onkeypress='return isNumberKey(event,this.id)' onInput='echaamount()'>
                              </td>
                              <td>
                                <input type='text' size='10'  name='txtecha_exchange_rate[]'   class='form-control input-md echa_exchange_rate required verify_text' style='display:none;'   onkeypress='return isNumberKey(event,this.id)' onInput='echaamount()'>
                              </td>
                              <td>
                                <input type='text' size='10'  name='txtecha_amount_in_rs[]'   class='form-control input-md echa_amount_in_rs required verify_text' style='display:none;'  onkeypress='return isNumberKey(event,this.id)'  readonly>
                              </td>
                              <td><input type='text' name='txtloa_fees[]' size='10'  class='form-control input-md loa_fees required verify_text' style='display:none;'  onkeypress='return isNumberKey(event,this.id)' onInput='loaamount()' ></td>
                              <td><input type='text'  name='txtloa_exchange_rate[]'  class='form-control input-md loa_exchange_rate required verify_text' style='display:none;'  onkeypress='return isNumberKey(event,this.id)' onInput='loaamount()'></td>
                              <td><input type='text' name='txtloa_amount_in_rs[]' size='10'  class='form-control input-md loa_amount_in_rs required verify_text' style='display:none;'  onkeypress='return isNumberKey(event,this.id)'  readonly></td>
                              <td><input type='text' name='txtconsultancy_fees[]' size='10'  class='form-control input-md consultancy_fees required verify_text' style='display:none;'  onkeypress='return isNumberKey(event,this.id)' onInput='consultancyamount()' ></td>
                              <td><input type='text' name='txtconsultancy_exchange_rate[]' size='10'   class='form-control input-md consultancy_exchange_rate required verify_text' style='display:none;'  onkeypress='return isNumberKey(event,this.id)' onInput='consultancyamount()' ></td>
                              <td><input type='text' name='txtconsultancy_amount_in_rs[]' size='10'  class='form-control input-md consultancy_amount_in_rs required verify_text' onkeypress='return isNumberKey(event,this.id)' readonly ></td>



                        </tr>";
                  }  



        
    
            }
            
            $sql6 = "SELECT sum(echa_fees) as echa_fees_total,sum(echa_exchange_rate) as echa_exchange_rate_total,sum(echa_amount_in_rs) as echa_amount_in_rs_total,
                    sum(loa_fees) as loa_fees_total,
                    sum(loa_exchange_rate) as loa_exchange_rate_total,
                    sum(loa_amount_in_rs) as loa_amount_in_rs_total,sum(consultancy_fees) as consultancy_fees_total,
                    sum(consultancy_exchange_rate) as consultancy_exchange_rate_total,
                    sum(consultancy_amount_in_rs) as consultancy_amount_in_rs_total
                    FROM reach_paymentdetails 
                    where  applicationid= $applicationid order by paymentdetailsid ASC";
            //die();
            
            $paymentdetailsTotallist    = $member_obj->getApplication('',$sql6);
              $paymentdetailsid       =  $paymentdetailsTotallist[0]['paymentdetailsid'];
              $echa_fees_total        =  $paymentdetailsTotallist[0]['echa_fees_total'];
              $echa_exchange_rate_total       =  $paymentdetailsTotallist[0]['echa_exchange_rate_total'];
              $echa_amount_in_rs_total        =  $paymentdetailsTotallist[0]['echa_amount_in_rs_total'];
              $loa_fees_total       =  $paymentdetailsTotallist[0]['loa_fees_total'];
              $loa_exchange_rate_total        =  $paymentdetailsTotallist[0]['loa_exchange_rate_total'];
              $loa_amount_in_rs_total       =  $paymentdetailsTotallist[0]['loa_amount_in_rs_total'];
              $consultancy_fees_total       =  $paymentdetailsTotallist[0]['consultancy_fees_total'];
              $consultancy_exchange_rate_total        =  $paymentdetailsTotallist[0]['consultancy_exchange_rate_total'];
              $consultancy_amount_in_rs_total       =  $paymentdetailsTotallist[0]['consultancy_amount_in_rs_total'];
            	
            	
            	    $ragistartion_total = ($echa_amount_in_rs_total  +   $loa_amount_in_rs_total +  $consultancy_amount_in_rs_total);
  					 $ragistartion_total_per = ($ragistartion_total * 50) / 100;
    
    
            $trpaymentdetailsTotal.="<tr>
                                      <th>Total</th>

                                        <input type='hidden' name='wdv_name_total' value='Total'>
                                        <td></td>
                                        <td>
                                          <span class='verify_span'>".$echa_fees_total."</span>
                                          <input type='text' min='0' name='echa_fees_total' id='echa_fees_total' class='form-control verify_text' style='display:none;'onkeypress='return isNumberKey(event,this.id)' readonly value='".$echa_fees_total."'>
                                        </td>
                                        <td>
                                          <span class='verify_span'>".$echa_exchange_rate_total."</span>
                                          <input type='text' min='0' name='echa_exchange_rate_total' id='echa_exchange_rate_total' class='form-control verify_text' style='display:none;'onkeypress='return isNumberKey(event,this.id)' readonly value='".$echa_exchange_rate_total."'>
                                        </td>
                                        <td>
                                          <span class='verify_span'>".$echa_amount_in_rs_total."</span>
                                          <input type='text' min='0' name='echa_amount_in_rs_total' id='echa_amount_in_rs_total' class='form-control verify_text echa_amount_in_rs_total' style='display:none;' onkeypress='return isNumberKey(event,this.id)' readonly value='".$echa_amount_in_rs_total."'>
                                        </td>
                                        
                                        <td>
                                          <span class='verify_span'>".$loa_fees_total."</span>
                                          <input type='text' min='0' name='loa_fees_total' id='loa_fees_total' class='form-control verify_text' style='display:none;'onkeypress='return isNumberKey(event,this.id)' readonly value='".$loa_fees_total."'>
                                        </td>
                                        <td>
                                          <span class='verify_span'>".$loa_exchange_rate_total."</span>
                                          <input type='text' min='0' name='loa_exchange_rate_total' id='loa_exchange_rate_total' class='form-control verify_text' style='display:none;'onkeypress='return isNumberKey(event,this.id)' readonly value='".$loa_exchange_rate_total."'>
                                        </td>
                                        <td>
                                          <span class='verify_span'>".$loa_amount_in_rs_total."</span>
                                          <input type='text' min='0' name='loa_amount_in_rs_total' id='loa_amount_in_rs_total' class='form-control verify_text' style='display:none;'onkeypress='return isNumberKey(event,this.id)' readonly value='".$loa_amount_in_rs_total."'>
                                        </td>

                                        <td>
                                          <span class='verify_span'>".$consultancy_fees_total."</span>
                                          <input type='text' min='0' name='consultancy_fees_total' id='consultancy_fees_total' class='form-control verify_text' style='display:none;'onkeypress='return isNumberKey(event,this.id)' readonly value='".$consultancy_fees_total."'>
                                        </td>
                                        <td>
                                          <span class='verify_span'>".$consultancy_exchange_rate_total."</span>
                                          <input type='text' min='0' name='consultancy_exchange_rate_total' id='consultancy_exchange_rate_total' class='form-control verify_text' style='display:none;'onkeypress='return isNumberKey(event,this.id)' readonly value='".$consultancy_exchange_rate_total."'>
                                        </td>
                                        <td>
                                          <span class='verify_span'>".$consultancy_amount_in_rs_total."</span>
                                          <input type='text' min='0' name='consultancy_amount_in_rs_total' id='consultancy_amount_in_rs_total' class='form-control verify_text' style='display:none;' onkeypress='return isNumberKey(event,this.id)' readonly value='".$consultancy_amount_in_rs_total."'>
                                        </td>
                                      </tr>";

//if($memberstatus == '0') {
      
        
        $headform0 = "'reg_headoffice00'";
        $sendurl    = "'membership_submit.php'";
        
        
        $edit_option_grid = '<a href="#" class="person_edit1 person_span1" rel="'.$applicationid.'" id="person_edit1" onclick="return false;">EDIT</a>
                      <a href="#" class="person_cancel1 person_text1" rel="'.$applicationid.'" id="person_cancel1"  onclick="return false;" style="display:none;">CANCEL</a>
                      <a href="#" class="person_save1 person_text1" rel="'.$applicationid.'" id="person_save1" onclick="formAjax('.$headform0.','.$sendurl.'); return false;" style="display:none;">SAVE</a>';                        

        

    
        $headform4  = "'reg_headoffice2'";
        $filename4 = "'application_submit5.php'";
  
        $editable_grid4 = '<a href="#" class="claim_edit claim_span" rel="'.$applicationid.'" id="claim_edit" onclick="return false;">EDIT</a>
                     <a href="#" class="claim_cancel verify_text" rel="'.$applicationid.'" id="claim_cancel" onclick="return false;" style="display:none;">CANCEL</a>
                     <a href="#" class="claim_save verify_text" rel="'.$applicationid.'" id="claim_save" onclick="formAjax('.$headform4.','.$filename4.'); return false;" style="display:none;">SAVE</a>';


        $headform5 = "'reg_headoffice3'";
        $filename5 = "'application_submit4.php'";

        $editable_grid5 = '<a href="#" class="verify_edit verify_span" rel="'.$applicationid.'" id="verify_edit" onclick="return false;">EDIT</a>
                     <a href="#" class="verify_cancel verify_text" rel="'.$applicationid.'" id="verify_cancel" onclick="return false;" style="display:none;">CANCEL</a>
                     <a href="#" class="verify_save verify_text" rel="'.$applicationid.'" id="verify_save" onclick="formAjax('.$headform5.','.$filename5.'); return false;" style="display:none;">SAVE</a>';
            
          $headform8 = "'reg_headoffice8'";
        $filename8 = "'application_submit3.php'";

        $editable_grid8 = '<a href="#" class="verify_edit1 verify_span1" rel="'.$applicationid.'" id="verify_edit1" onclick="return false;">EDIT</a>
                     <a href="#" class="verify_cancel1 verify_text1" rel="'.$applicationid.'" id="verify_cancel1" onclick="return false;" style="display:none;">CANCEL</a>
                     <a href="#" class="verify_save1 verify_text1" rel="'.$applicationid.'" id="verify_save1" onclick="formAjax('.$headform8.','.$filename8.'); return false;" style="display:none;">SAVE</a>';
    
        
//}

$applicationlist = '';  
if($applicationid != '')
{
      $applicationlist .= '   
      
      
        <div id="person_details">  
        <div class="col-lg-12">
            <div class="panel panel-info">
                <div class="panel-heading">
                Person Details
                </div>

                  <div class="panel-body">
                    <form  id="reg_headoffice00">
                        <input type="hidden" id="txteditmembershipno" name="txteditmembershipno"  value="'.$membershipno.'">
                        <input type="hidden" id="txtmemberid" name="txtmemberid"  value="'.$memberid.'" >
                        <input type="hidden" id="txtapplicationid" name="txtapplicationid"  value="'.$applicationid.'">
                      <input type="hidden" id="entered_export_count" name="entered_export_count" value="'.$stancelicensecount.'">
                      <table width="95%"   class="table table-bordered">
                        <tr>
                          <td width="7%">1</td>
                          <td colspan="2" width="35%">Name of the Applicant Firm : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$reach_cnt_person.'</div>
                                  <input type="text" name="txtmembername" value="'.$reach_cnt_person.'"  readonly="" required=""  class="form-control person_text1" style="display:none;">
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">2</td>
                          <td colspan="2" width="35%">Address of the Applicant Firm Line 1 : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$reach_cnt_address1.'</div>
                                  <input type="text" name="txtaddress1" value="'.$reach_cnt_address1.'"   required=""  class="form-control person_text1" style="display:none;">
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">3</td>
                          <td colspan="2" width="35%">Address of the Applicant Firm Line 2 : </td>
                          <td colspan="3">
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$reach_cnt_address2.'</div>
                                  <input type="text" name="txtaddress2" value="'.$reach_cnt_address2.'"   class="form-control person_text1" style="display:none;">
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">4</td>
                          <td colspan="2" width="35%">Region of the Applicant Firm : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$region.'</div>
                                  <input type="text" name="txtregion" value="'.$region.'"  readonly="" required=""  class="form-control person_text1" style="display:none;">
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">5</td>
                          <td colspan="2" width="35%">State of the Applicant Firm : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$reach_cnt_statename.'</div>
                                  <input type="text" name="txtstate" value="'.$reach_cnt_statename.'"   required=""  class="form-control person_text1" style="display:none;">
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">6</td>
                          <td colspan="2" width="35%">City of the Applicant Firm : </td>
                          <td colspan="3">
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$reach_cnt_city.'</div>
                                   <input type="text" name="txtcity" value="'.$reach_cnt_city.'"   required=""  class="form-control person_text1" style="display:none;">
                                </div>
                              </td>
                        </tr>
                        <tr>
                          <td width="7%">7</td>
                          <td colspan="2" width="35%">Postcode of the Applicant Firm : </td>
                          <td colspan="3">
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$reach_cnt_pincode.'</div>
                                  <input type="text" name="txtpin" value="'.$reach_cnt_pincode.'"   required=""  class="form-control person_text1" style="display:none;">
                                 </div>
                              </td>
                        </tr>
  
                        <tr>
                          <td width="7%">8</td>
                          <td colspan="2" width="35%">Tel: (with STD Code) : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$reach_cnt_tel.'</div>
                                  <input type="text" name="txttel" value="'.$reach_cnt_tel.'"      required="" class="form-control person_text1" style="display:none;" >
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">9</td>
                          <td colspan="2" width="35%">Fax: (with STD Code) : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$reach_cnt_fax.'</div>
                                  <input type="text" name="txtfax" value="'.$reach_cnt_fax.'"    required="" class="form-control person_text1" style="display:none;" >
                              </div>
                            </td>
                        </tr>
            <tr>
                          <td width="7%">10</td>
                          <td colspan="2" width="35%">GST No : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$reach_cnt_gstno.'</div>
                                  <input type="text" name="txtgstno" value="'.$reach_cnt_gstno.'"    required="" class="form-control person_text1" style="display:none;" >
                              </div>
                            </td>
                        </tr>
                        <tr>
                          <td width="7%">11</td>
                          <td colspan="2" width="35%">Mobile No : </td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$reach_cnt_contactno.'</div>
                                  <input type="text" name="txtmobileno" value="'.$reach_cnt_contactno.'"  required=""  class="form-control person_text1" style="display:none;">
                                </div>
                          </td>
                        </tr>
                        <tr>
                          <td width="7%">12</td>
                          <td colspan="2" width="35%">E-mail :</td>
                          <td colspan="3"> 
                              <div class="col-lg-15">
                                  <div class="person_span1">'.$reach_cnt_email.'</div>
                                  <input type="text" name="txtemail" value="'.$reach_cnt_email.'"   required=""  class="form-control person_text1" style="display:none;">
                              </div>
                            </td>
                        </tr>
                      <!--<tr>
                        <td width="7%">13</td>
                        <td colspan="2" width="35%">Website : </td>
                        <td colspan="3"> 
                            <div class="col-lg-15">
                                <div class="person_span1">'.$website.'</div>
                                <input type="text" name="txtwebsite" value="'.$website.'"   required="" class="form-control person_text1" style="display:none;">
                            </div>
                          </td>
                      </tr>-->
  
                      <tr>
                        <td width="7%">14</td>
                        <td colspan="2" width="35%">Name of contact person : </td>
                        <td colspan="3"> 
                            <div class="col-lg-15">
                                <div class="person_span1">'.$reach_cnt_person.'</div>
                                <input type="text" name="txtcntname" value="'.$reach_cnt_person.'"  required="" class="form-control person_text1" style="display:none;">
                              </div>
                          </td>
                      </tr>
                      <tr>
                        <td width="7%">15</td>
                        <td colspan="2" width="35%">Designation of contact person :</td>
                        <td colspan="3"> 
                            <div class="col-lg-15">
                                <div class="person_span1">'.$reach_cnt_designation.'</div>
                                <input type="text" name="txtcntdes" value="'.$reach_cnt_designation.'"   required="" class="form-control person_text1" style="display:none;">
                            </div>
                          </td>
                      </tr>
                       <tr>
                        <td width="7%">15</td>
                        <td colspan="2" width="35%">Mobile No of contact person  :</td>
                        <td colspan="3"> 
                            <div class="col-lg-15">
                                <div class="person_span1">'.$reach_cnt_mobileno.'</div>
                                <input type="text" name="txtcntmob" value="'.$reach_cnt_mobileno.'"   required="" onkeypress="return isNumberKey(event,this.id)"  class="form-control person_text1" style="display:none;">
                            </div>
                          </td>
                      </tr>
                       <tr>
                        <td width="7%">15</td>
                        <td colspan="2" width="35%">Landline No of contact person :</td>
                        <td colspan="3"> 
                            <div class="col-lg-15">
                                <div class="person_span1">'.$reach_cnt_landlineno.'</div>
                                <input type="text" name="txtcntlandno" value="'.$reach_cnt_landlineno.'"   required="" onkeypress="return isNumberKey(event,this.id)"  class="form-control person_text1" style="display:none;">
                            </div>
                          </td>
                      </tr>
                       <tr>
                        <td width="7%">15</td>
                        <td colspan="2" width="35%">Email Id of contact person :</td>
                        <td colspan="3"> 
                            <div class="col-lg-15">
                                <div class="person_span1">'.$reach_cnt_email2.'</div>
                                <input type="text" name="txtcntemail" value="'.$reach_cnt_email2.'"   required="" class="form-control person_text1" style="display:none;">
                            </div>
                          </td>
                      </tr>
                      <tr>
                        <td width="7%">16</td>
                        <td colspan="2" width="35%">IEC No. of the firm. :</td>
                        <td colspan="3"> 
                            <div class="col-lg-15">
                                <div class="person_span1">'.$reach_cnt_iecno.'</div>
                                <input type="text" name="txtiec" value="'.$reach_cnt_iecno.'"   readonly="" required="" class="form-control person_text1" style="display:none;">
                            </div>
                          </td>
                      </tr>
                      <tr>
                        <td width="7%">16</td>
                        <td colspan="2" width="35%">Customer ID (UUID) as per ECHA Invoice :</td>
                        <td colspan="3"> 
                            <div class="col-lg-15">
                                <div class="person_span1">'.$customer_id.'</div>
                                <input type="text" name="txtcid" value="'.$customer_id.'"    required="" class="form-control person_text1" style="display:none;">
                            </div>
                          </td>
                      </tr>
        
                      <tr>
                        <td width="7%">17</td>
                        <td colspan="2" width="35%">Chemexcil Membership Code :</td>
                        <td colspan="3">
                            <div class="col-lg-15">
                                <div class="person_span1">'.$membershipno.'</div>
                                <input type="text" name="txtmembershipcode" value="'.$membershipno.'" readonly="" required=""  class="form-control person_text1" style="display:none;">
                            </div>
                          </td>
                      </tr>
                      <tr>
                        <td width="7%">18</td>
                        <td colspan="2" width="35%">Whether ( LSM/ MSM/ SSM/ MICRO SM)                                             : </td>    
                        <td colspan="3">
                            <div class="col-lg-15">
                                <div class="person_span1">'.$company_category.'</div>
                                <input type="text" name="txtwhether" value="'.$company_category.'"  readonly="" required="" class="form-control person_text1" style="display:none;">              
                            </div>
                        </td>
                      </tr>
                      <tr>
                        <td width="7%">19</td>
                        <td colspan="2" width="35%">  Status of Membership subscription fees paid for 3 years:
                        <div >'.$year_1.'</div>
                        <input type="hidden"  name="textyear1"  readonly=""  value="'.$year_1.'" class="form-control person_text1" style="display:none;">
                          </div>
                          <div>'.$year_2.'</div>
                          <input type="hidden"  name="textyear2"  readonly=""  value="'.$year_2.'" class="form-control person_text1"  style="display:none;">
                          </div>
                          <div>'.$year_3.'</div>
                          <input type="hidden"  name="textyear3"  readonly=""  value="'.$year_3.'" class="form-control person_text1"  style="display:none;">
                          </div>
                          </td>
                        <td colspan="3">
                        <div class="col-lg-4">
                            <label>Receipt  No.</label>
                            <div class="person_span1">'.$receipt_1.'</div>
                            <input type="text"  name="textfees1"   value="'.$receipt_1.'"   class="form-control person_text1" style="display:none;">
                            <div class="person_span1">'.$receipt_2.'</div>
                            <input type="text" name="textfees2"  value="'.$receipt_2.'"   class="form-control person_text1" style="display:none;" >
                            <div class="person_span1">'.$receipt_3.'</div>
                            <input type="text" name="textfees3"   value="'.$receipt_3.'"    class="form-control person_text1" style="display:none;" >
                          </div>
                          <div class="col-lg-4">
                            <label>Date:</label>
                            <div class="person_span1">'.$date_1.'</div>
                              <input type="text" id="txtappdate12" name="txtappdate" required="" value="'.$date_1.'"   class="form-control person_text1" style="display:none;">
                              <div class="person_span1">'.$date_2.'</div>
                              <input type="text" id="txtappdate11" name="txtappdate1" required="" value="'.$date_2.'"  class="form-control person_text1" style="display:none;">
                              <div class="person_span1">'.$date_3.'</div>
                            <input type="text" id="txtappdate21" name="txtappdate2" required="" value="'.$date_3.'"   class="form-control person_text1" style="display:none;" >
                          </div>
                      </tr>
                      <tr>
                        <td width="7%">20</td>
                        <td colspan="2" width="35%">Export House Certificate, if applicable :</td>
                        <td colspan="4">
                          <div class="form-group col-lg-4">
                                 Certificate No :
                                      <div class="person_span1">'.$export_house_no.'</div>  
                                  <input type="text" id="txtcertificateno" name="txtcertificateno"  value="'.$export_house_no.'" class="form-control person_text1" style="display:none;"   placeholder="" >
                          </div>
              <div class="form-group col-lg-4">                         
                              Issue Date :
                            <div class="person_span1">'.$export_house_issueddate.'</div>
                            <input type="text" name="txtcertificateissueddate"  value="'.$export_house_issueddate.'"  class="form-control getdate person_text1" style="display:none;"   placeholder="" >
                          </div>
                          <div class="form-group col-lg-4">                         
                              Valid Upto :
                            <div class="person_span1">'.$export_house_validuptodate.'</div>
                            <input type="text" id="txtcertificatevalidupto1" name="txtcertificatevalidupto"  value="'.$export_house_validuptodate.'"  class="form-control person_text1" style="display:none;"   placeholder="" >
                          </div>
                      </tr>

                      <tr><td width="7%">21</td>
                        <td colspan="2" width="35%"> FOB value of exports during the last 3 financial year:</td>
                        <td colspan="3">
                                            
                            <div class="col-lg-4">
                                <label>Last 1 Year ('.$year_1.'):</label>
                                <div class="person_span1">'.$fob_last_1_year.'</div>
                                <input type="text" id="txtfob_enter11" name="txtfob_enter11"  onkeypress="return isNumberKey(event,this.id)" value="'.$fob_last_1_year.'" class="form-control person_text1"  style="display:none;">                   
                              </div>
                              <div class="col-lg-4">
                                <label>Last 2 Year ('.$year_2.'):</label>
                                <div class="person_span1">'.$fob_last_2_year.'</div>
                              <input type="text" id="txtfob_enter21" name="txtfob_enter21" onkeypress="return isNumberKey(event,this.id)" value="'.$fob_last_2_year.'" class="form-control person_text1"  style="display:none;">
                              </div>
                            <div class="col-lg-4">
                                <label>Last 3 Year ('.$year_3.'):</label>
                                <div class="person_span1">'.$fob_last_3_year.'</div>
                              <input type="text" id="txtfob_enter31" name="txtfob_enter31" onkeypress="return isNumberKey(event,this.id)" value="'.$fob_last_3_year.'" class="form-control person_text1" style="display:none;">
                              </div>
                      
                      </tr>
                          <tr><td width="7%">22</td>
                            <td colspan="2" width="35%">Status </td>
                            <td colspan="3">
                                <div class="row col-lg-6 person_text1" style="display:none;">
                            
                                  <label class="radio-inline"><input type="radio" name="memberstatus" class="memberstatus1"  '.(($memberstatus =='0')?'checked':'').' value="0" >Panding</label>
                                  <label class="radio-inline"><input type="radio" name="memberstatus" class="memberstatus1" '.(($memberstatus =='1')?'checked':'').' value="1">Completed</label>  
                                </div>
                            
                                <div class="row col-lg-6 statusreason1 person_text1" style="display:none;">
                                  <input type="text" id="statusreason" name="statusreason" class="form-control statusreasons person_text1" style="display:none;" value="'.$statusreason.'"   placeholder="Type a reason here" /> <br> <label class="text text-danger">Please mentioned the reason for pending member only.</label>
  
                                </div>  
                                <div class="row col-lg-6 statusreason2 person_text1" style="display:none;">
                                </div>
                                  
                              <div class="statusreason person_span1" id="statusreason1"><div class="col-lg-2">Status:</div>'.$value.'<br><div class="col-lg-2">Reasons:</div>'.$statusreason.'</div>
                            </td>
                          </tr>

                    </table>
                  </form>'.$edit_option_grid.'
                </div>
              </div>
            </div>
            </div>
            
            <div id="substance_license">  
            <div class="col-lg-12">
                <div class="panel panel-info">
                  <div class="panel-heading">
                      Details of manufacturing license issued by the Licensing Authority (in India) for the substance(to be enclosed ) 
                  </div>
                  <div class="panel-body">
                   <h4>
                  Details of manufacturing license issued by the Licensing Authority (in India) for the substance(to be enclosed )
                  </h4>
                    <form id="reg_headoffice8">
                    <input type="hidden" id="txteditmembershipno" name="txteditmembershipno"  value="'.$membershipno.'">
                        <input type="hidden" id="txtmemberid" name="txtmemberid"  value="'.$memberid.'" >
                        <input type="hidden" id="txtapplicationid" name="txtapplicationid"  value="'.$applicationid.'">
                        <input type="hidden" id="entered_export_count8" name="entered_export_count" value="'.$stancelicensecount.'"> 
                                           <table class="table table-sm" id="authority_table">
                                              <thead>
                                                <tr>
                                                  <th> </th>
                                                  <th> Sr.No</th>
                                                     <th> License No</th>
                                                  <th> Date</th>
                                                  <th>Issuing authority</th>
                                                         
                                                </tr>
                                              </thead>
                                              <tbody>
                                              '.$tr3.'
                                              <tr id="addauthority" class="verify_text1" style="display:none;">
                                                  <td><a href="javascript:void(0)" class="btn btn-primary navigation_button"style="padding: 5px 10px;background: #337ab7;color: #fff;border-radius: 0;" onclick="addMoreauthority()"><i class="ft-plus hidden-lg-up"></i>&nbsp;Add More</a></td>
                                                <td></td><td></td>
                                              </tr>
                                              
                                              </tbody>
                                            </table>
                        <br>
                        <br>
                    </form>'.$editable_grid8.'
                </div>                    
              </div>
            </div>  
            </div>
              
              <div id="substance_details">  
               <div class="col-lg-12">
                <div class="panel panel-info">
                  <!--<div class="panel-heading">
                      Details of the substances registered by  your firm 
                  </div>-->
                  <div class="panel-heading">
                      Details of the substances 
                  </div><br>
                 <center> <h4>
                  Details of the substances registered by  your firm
                  </h4></center><br>
                  <div class="panel-body">
                    <form id="reg_headoffice3">
                    <input type="hidden" id="txteditmembershipno" name="txteditmembershipno"  value="'.$membershipno.'">
                        <input type="hidden" id="txtmemberid" name="txtmemberid"  value="'.$memberid.'" >
                        <input type="hidden" id="txtapplicationid" name="txtapplicationid"  value="'.$applicationid.'">
                        <input type="hidden" id="entered_export_count3" name="entered_export_count3" value="'.$substancesdetailscount.'">   
                        

                        <table class="table table-sm" id="substances_registered_table" style="width:100%;max-width:100%;">
                          <thead>
                            <tr>
                               <th width="3%"></th>
                                <th width="5%"> Sr.No</th>
                                      <th  width="12%"> Substance Name</th>
                                      <th width="12%">HS Code</th>
                                     <th width="12%">CAS No.</th>
              <th width="12%">Tonnage Band</th>
              <th width="12%">EC No.</th>
              <th width="12%"> Submission No.</th>
               <th width="12%"> Submission Date</th>
                                      <th width="12%">Upload</th>

                            </tr>
                          </thead>
                          <tbody>
                          '.$tr1.'
                           <tr id="addsubstances_registered" class="verify_text" style="display:none;">
                            <td><a href="javascript:void(0)" class="btn btn-primary navigation_button"style="padding: 5px 10px;background: #337ab7;color: #fff;border-radius: 0;"  onclick="addMoresubstances_registered();addMoreDepIT();"><i class="ft-plus hidden-lg-up"></i>&nbsp;Add More</a></td>
                                <td></td><td></td><td></td><td></td><td></td>
                              </tr>
                              
                            </tbody>
                          </table>
                        <br>
                        <br>
                    
                   
                    <center>
                  <h4>
                  Details of Registration fees paid by your firm to ECHA
                  </h4>
                  </center>
                  <br>
                   
                  <input type="hidden" id="txteditmembershipno" name="txteditmembershipno"  value="'.$membershipno.'">
                        <input type="hidden" id="txtmemberid" name="txtmemberid"  value="'.$memberid.'" >
                        <input type="hidden" id="txtapplicationid" name="txtapplicationid"  value="'.$applicationid.'">
                      <input type="hidden" id="entered_export_count5" name="entered_export_count5" value="'.$paymentdetailscount.'">           
                      <input type="hidden" id="entered_export_countdelete" name="entered_export_countdelete" value="">
					  <div class="table-responsive">
<table class="table table-sm" id="dep_it_table" style="width:150%;max-width:150%;">
  <thead>
    <tr>
      
        <td width="5%"> Sr.No</td>
                        <td width="9%"> Substance Name</td>
                            <td width="9%">ECHA Regn fees paid in Euro as per ECHA Invoice   </td>
                            <td width="9%"> Exchange Rate as per Bank Transaction copies </td>
                            <td width="9%"> (Amount in Rs ) </td>

                            <td width="9%">LOA Fees as per LR Invoice or Data fees as per Lab invoice   </td>
                            <td width="9%"> Exchange Rate as per Bank Transaction copies  </td>
                            <td width="9%">(Amount in Rs )</td>
                            <td width="9%">Consultancy charges as per consultant’s invoice</td>
                            <td width="9%"> Exchange Rate as per Bank Transaction copies  </td>
                            <td width="9%"> (Amount in Rs )</td>
                        </tr>
                      </thead>
                      <tbody>
                        '.$tr.' 
                        <tr id="addDepIt"></tr>
                        '.$trpaymentdetailsTotal.'
                      <tbody>
                      </table>
                      <h5><b>Ragistartion Total Amount (A+B+C) = </b><span id="ragistartion_total_dis">'.$ragistartion_total.'<input type="hidden" name="ragistartion_total" id="ragistartion_total"  value=""></span></h5>
							<h5><b>50% Of Ragistartion Amount  = </b><span id="ragistartion_total_per_dis">'.$ragistartion_total_per.'<input type="hidden" name="ragistartion_total_per" id="ragistartion_tota_perl"  value=""></span></h5>
			
                      </div>
                        <br>
                        <br>
                    </form>'.$editable_grid5.'
                </div>                    
              </div>
            </div>
            </div>

          ';
}       
  return $applicationlist;

    
} 


?>